import {
  HttpHandlerOptions as __HttpHandlerOptions,
  PaginationConfiguration,
  Paginator,
  WaiterConfiguration,
} from "@smithy/types";
import { WaiterResult } from "@smithy/util-waiter";
import {
  AddAssociationCommandInput,
  AddAssociationCommandOutput,
} from "./commands/AddAssociationCommand";
import {
  AddTagsCommandInput,
  AddTagsCommandOutput,
} from "./commands/AddTagsCommand";
import {
  AssociateTrialComponentCommandInput,
  AssociateTrialComponentCommandOutput,
} from "./commands/AssociateTrialComponentCommand";
import {
  AttachClusterNodeVolumeCommandInput,
  AttachClusterNodeVolumeCommandOutput,
} from "./commands/AttachClusterNodeVolumeCommand";
import {
  BatchAddClusterNodesCommandInput,
  BatchAddClusterNodesCommandOutput,
} from "./commands/BatchAddClusterNodesCommand";
import {
  BatchDeleteClusterNodesCommandInput,
  BatchDeleteClusterNodesCommandOutput,
} from "./commands/BatchDeleteClusterNodesCommand";
import {
  BatchDescribeModelPackageCommandInput,
  BatchDescribeModelPackageCommandOutput,
} from "./commands/BatchDescribeModelPackageCommand";
import {
  BatchRebootClusterNodesCommandInput,
  BatchRebootClusterNodesCommandOutput,
} from "./commands/BatchRebootClusterNodesCommand";
import {
  BatchReplaceClusterNodesCommandInput,
  BatchReplaceClusterNodesCommandOutput,
} from "./commands/BatchReplaceClusterNodesCommand";
import {
  CreateActionCommandInput,
  CreateActionCommandOutput,
} from "./commands/CreateActionCommand";
import {
  CreateAlgorithmCommandInput,
  CreateAlgorithmCommandOutput,
} from "./commands/CreateAlgorithmCommand";
import {
  CreateAppCommandInput,
  CreateAppCommandOutput,
} from "./commands/CreateAppCommand";
import {
  CreateAppImageConfigCommandInput,
  CreateAppImageConfigCommandOutput,
} from "./commands/CreateAppImageConfigCommand";
import {
  CreateArtifactCommandInput,
  CreateArtifactCommandOutput,
} from "./commands/CreateArtifactCommand";
import {
  CreateAutoMLJobCommandInput,
  CreateAutoMLJobCommandOutput,
} from "./commands/CreateAutoMLJobCommand";
import {
  CreateAutoMLJobV2CommandInput,
  CreateAutoMLJobV2CommandOutput,
} from "./commands/CreateAutoMLJobV2Command";
import {
  CreateClusterCommandInput,
  CreateClusterCommandOutput,
} from "./commands/CreateClusterCommand";
import {
  CreateClusterSchedulerConfigCommandInput,
  CreateClusterSchedulerConfigCommandOutput,
} from "./commands/CreateClusterSchedulerConfigCommand";
import {
  CreateCodeRepositoryCommandInput,
  CreateCodeRepositoryCommandOutput,
} from "./commands/CreateCodeRepositoryCommand";
import {
  CreateCompilationJobCommandInput,
  CreateCompilationJobCommandOutput,
} from "./commands/CreateCompilationJobCommand";
import {
  CreateComputeQuotaCommandInput,
  CreateComputeQuotaCommandOutput,
} from "./commands/CreateComputeQuotaCommand";
import {
  CreateContextCommandInput,
  CreateContextCommandOutput,
} from "./commands/CreateContextCommand";
import {
  CreateDataQualityJobDefinitionCommandInput,
  CreateDataQualityJobDefinitionCommandOutput,
} from "./commands/CreateDataQualityJobDefinitionCommand";
import {
  CreateDeviceFleetCommandInput,
  CreateDeviceFleetCommandOutput,
} from "./commands/CreateDeviceFleetCommand";
import {
  CreateDomainCommandInput,
  CreateDomainCommandOutput,
} from "./commands/CreateDomainCommand";
import {
  CreateEdgeDeploymentPlanCommandInput,
  CreateEdgeDeploymentPlanCommandOutput,
} from "./commands/CreateEdgeDeploymentPlanCommand";
import {
  CreateEdgeDeploymentStageCommandInput,
  CreateEdgeDeploymentStageCommandOutput,
} from "./commands/CreateEdgeDeploymentStageCommand";
import {
  CreateEdgePackagingJobCommandInput,
  CreateEdgePackagingJobCommandOutput,
} from "./commands/CreateEdgePackagingJobCommand";
import {
  CreateEndpointCommandInput,
  CreateEndpointCommandOutput,
} from "./commands/CreateEndpointCommand";
import {
  CreateEndpointConfigCommandInput,
  CreateEndpointConfigCommandOutput,
} from "./commands/CreateEndpointConfigCommand";
import {
  CreateExperimentCommandInput,
  CreateExperimentCommandOutput,
} from "./commands/CreateExperimentCommand";
import {
  CreateFeatureGroupCommandInput,
  CreateFeatureGroupCommandOutput,
} from "./commands/CreateFeatureGroupCommand";
import {
  CreateFlowDefinitionCommandInput,
  CreateFlowDefinitionCommandOutput,
} from "./commands/CreateFlowDefinitionCommand";
import {
  CreateHubCommandInput,
  CreateHubCommandOutput,
} from "./commands/CreateHubCommand";
import {
  CreateHubContentPresignedUrlsCommandInput,
  CreateHubContentPresignedUrlsCommandOutput,
} from "./commands/CreateHubContentPresignedUrlsCommand";
import {
  CreateHubContentReferenceCommandInput,
  CreateHubContentReferenceCommandOutput,
} from "./commands/CreateHubContentReferenceCommand";
import {
  CreateHumanTaskUiCommandInput,
  CreateHumanTaskUiCommandOutput,
} from "./commands/CreateHumanTaskUiCommand";
import {
  CreateHyperParameterTuningJobCommandInput,
  CreateHyperParameterTuningJobCommandOutput,
} from "./commands/CreateHyperParameterTuningJobCommand";
import {
  CreateImageCommandInput,
  CreateImageCommandOutput,
} from "./commands/CreateImageCommand";
import {
  CreateImageVersionCommandInput,
  CreateImageVersionCommandOutput,
} from "./commands/CreateImageVersionCommand";
import {
  CreateInferenceComponentCommandInput,
  CreateInferenceComponentCommandOutput,
} from "./commands/CreateInferenceComponentCommand";
import {
  CreateInferenceExperimentCommandInput,
  CreateInferenceExperimentCommandOutput,
} from "./commands/CreateInferenceExperimentCommand";
import {
  CreateInferenceRecommendationsJobCommandInput,
  CreateInferenceRecommendationsJobCommandOutput,
} from "./commands/CreateInferenceRecommendationsJobCommand";
import {
  CreateLabelingJobCommandInput,
  CreateLabelingJobCommandOutput,
} from "./commands/CreateLabelingJobCommand";
import {
  CreateMlflowAppCommandInput,
  CreateMlflowAppCommandOutput,
} from "./commands/CreateMlflowAppCommand";
import {
  CreateMlflowTrackingServerCommandInput,
  CreateMlflowTrackingServerCommandOutput,
} from "./commands/CreateMlflowTrackingServerCommand";
import {
  CreateModelBiasJobDefinitionCommandInput,
  CreateModelBiasJobDefinitionCommandOutput,
} from "./commands/CreateModelBiasJobDefinitionCommand";
import {
  CreateModelCardCommandInput,
  CreateModelCardCommandOutput,
} from "./commands/CreateModelCardCommand";
import {
  CreateModelCardExportJobCommandInput,
  CreateModelCardExportJobCommandOutput,
} from "./commands/CreateModelCardExportJobCommand";
import {
  CreateModelCommandInput,
  CreateModelCommandOutput,
} from "./commands/CreateModelCommand";
import {
  CreateModelExplainabilityJobDefinitionCommandInput,
  CreateModelExplainabilityJobDefinitionCommandOutput,
} from "./commands/CreateModelExplainabilityJobDefinitionCommand";
import {
  CreateModelPackageCommandInput,
  CreateModelPackageCommandOutput,
} from "./commands/CreateModelPackageCommand";
import {
  CreateModelPackageGroupCommandInput,
  CreateModelPackageGroupCommandOutput,
} from "./commands/CreateModelPackageGroupCommand";
import {
  CreateModelQualityJobDefinitionCommandInput,
  CreateModelQualityJobDefinitionCommandOutput,
} from "./commands/CreateModelQualityJobDefinitionCommand";
import {
  CreateMonitoringScheduleCommandInput,
  CreateMonitoringScheduleCommandOutput,
} from "./commands/CreateMonitoringScheduleCommand";
import {
  CreateNotebookInstanceCommandInput,
  CreateNotebookInstanceCommandOutput,
} from "./commands/CreateNotebookInstanceCommand";
import {
  CreateNotebookInstanceLifecycleConfigCommandInput,
  CreateNotebookInstanceLifecycleConfigCommandOutput,
} from "./commands/CreateNotebookInstanceLifecycleConfigCommand";
import {
  CreateOptimizationJobCommandInput,
  CreateOptimizationJobCommandOutput,
} from "./commands/CreateOptimizationJobCommand";
import {
  CreatePartnerAppCommandInput,
  CreatePartnerAppCommandOutput,
} from "./commands/CreatePartnerAppCommand";
import {
  CreatePartnerAppPresignedUrlCommandInput,
  CreatePartnerAppPresignedUrlCommandOutput,
} from "./commands/CreatePartnerAppPresignedUrlCommand";
import {
  CreatePipelineCommandInput,
  CreatePipelineCommandOutput,
} from "./commands/CreatePipelineCommand";
import {
  CreatePresignedDomainUrlCommandInput,
  CreatePresignedDomainUrlCommandOutput,
} from "./commands/CreatePresignedDomainUrlCommand";
import {
  CreatePresignedMlflowAppUrlCommandInput,
  CreatePresignedMlflowAppUrlCommandOutput,
} from "./commands/CreatePresignedMlflowAppUrlCommand";
import {
  CreatePresignedMlflowTrackingServerUrlCommandInput,
  CreatePresignedMlflowTrackingServerUrlCommandOutput,
} from "./commands/CreatePresignedMlflowTrackingServerUrlCommand";
import {
  CreatePresignedNotebookInstanceUrlCommandInput,
  CreatePresignedNotebookInstanceUrlCommandOutput,
} from "./commands/CreatePresignedNotebookInstanceUrlCommand";
import {
  CreateProcessingJobCommandInput,
  CreateProcessingJobCommandOutput,
} from "./commands/CreateProcessingJobCommand";
import {
  CreateProjectCommandInput,
  CreateProjectCommandOutput,
} from "./commands/CreateProjectCommand";
import {
  CreateSpaceCommandInput,
  CreateSpaceCommandOutput,
} from "./commands/CreateSpaceCommand";
import {
  CreateStudioLifecycleConfigCommandInput,
  CreateStudioLifecycleConfigCommandOutput,
} from "./commands/CreateStudioLifecycleConfigCommand";
import {
  CreateTrainingJobCommandInput,
  CreateTrainingJobCommandOutput,
} from "./commands/CreateTrainingJobCommand";
import {
  CreateTrainingPlanCommandInput,
  CreateTrainingPlanCommandOutput,
} from "./commands/CreateTrainingPlanCommand";
import {
  CreateTransformJobCommandInput,
  CreateTransformJobCommandOutput,
} from "./commands/CreateTransformJobCommand";
import {
  CreateTrialCommandInput,
  CreateTrialCommandOutput,
} from "./commands/CreateTrialCommand";
import {
  CreateTrialComponentCommandInput,
  CreateTrialComponentCommandOutput,
} from "./commands/CreateTrialComponentCommand";
import {
  CreateUserProfileCommandInput,
  CreateUserProfileCommandOutput,
} from "./commands/CreateUserProfileCommand";
import {
  CreateWorkforceCommandInput,
  CreateWorkforceCommandOutput,
} from "./commands/CreateWorkforceCommand";
import {
  CreateWorkteamCommandInput,
  CreateWorkteamCommandOutput,
} from "./commands/CreateWorkteamCommand";
import {
  DeleteActionCommandInput,
  DeleteActionCommandOutput,
} from "./commands/DeleteActionCommand";
import {
  DeleteAlgorithmCommandInput,
  DeleteAlgorithmCommandOutput,
} from "./commands/DeleteAlgorithmCommand";
import {
  DeleteAppCommandInput,
  DeleteAppCommandOutput,
} from "./commands/DeleteAppCommand";
import {
  DeleteAppImageConfigCommandInput,
  DeleteAppImageConfigCommandOutput,
} from "./commands/DeleteAppImageConfigCommand";
import {
  DeleteArtifactCommandInput,
  DeleteArtifactCommandOutput,
} from "./commands/DeleteArtifactCommand";
import {
  DeleteAssociationCommandInput,
  DeleteAssociationCommandOutput,
} from "./commands/DeleteAssociationCommand";
import {
  DeleteClusterCommandInput,
  DeleteClusterCommandOutput,
} from "./commands/DeleteClusterCommand";
import {
  DeleteClusterSchedulerConfigCommandInput,
  DeleteClusterSchedulerConfigCommandOutput,
} from "./commands/DeleteClusterSchedulerConfigCommand";
import {
  DeleteCodeRepositoryCommandInput,
  DeleteCodeRepositoryCommandOutput,
} from "./commands/DeleteCodeRepositoryCommand";
import {
  DeleteCompilationJobCommandInput,
  DeleteCompilationJobCommandOutput,
} from "./commands/DeleteCompilationJobCommand";
import {
  DeleteComputeQuotaCommandInput,
  DeleteComputeQuotaCommandOutput,
} from "./commands/DeleteComputeQuotaCommand";
import {
  DeleteContextCommandInput,
  DeleteContextCommandOutput,
} from "./commands/DeleteContextCommand";
import {
  DeleteDataQualityJobDefinitionCommandInput,
  DeleteDataQualityJobDefinitionCommandOutput,
} from "./commands/DeleteDataQualityJobDefinitionCommand";
import {
  DeleteDeviceFleetCommandInput,
  DeleteDeviceFleetCommandOutput,
} from "./commands/DeleteDeviceFleetCommand";
import {
  DeleteDomainCommandInput,
  DeleteDomainCommandOutput,
} from "./commands/DeleteDomainCommand";
import {
  DeleteEdgeDeploymentPlanCommandInput,
  DeleteEdgeDeploymentPlanCommandOutput,
} from "./commands/DeleteEdgeDeploymentPlanCommand";
import {
  DeleteEdgeDeploymentStageCommandInput,
  DeleteEdgeDeploymentStageCommandOutput,
} from "./commands/DeleteEdgeDeploymentStageCommand";
import {
  DeleteEndpointCommandInput,
  DeleteEndpointCommandOutput,
} from "./commands/DeleteEndpointCommand";
import {
  DeleteEndpointConfigCommandInput,
  DeleteEndpointConfigCommandOutput,
} from "./commands/DeleteEndpointConfigCommand";
import {
  DeleteExperimentCommandInput,
  DeleteExperimentCommandOutput,
} from "./commands/DeleteExperimentCommand";
import {
  DeleteFeatureGroupCommandInput,
  DeleteFeatureGroupCommandOutput,
} from "./commands/DeleteFeatureGroupCommand";
import {
  DeleteFlowDefinitionCommandInput,
  DeleteFlowDefinitionCommandOutput,
} from "./commands/DeleteFlowDefinitionCommand";
import {
  DeleteHubCommandInput,
  DeleteHubCommandOutput,
} from "./commands/DeleteHubCommand";
import {
  DeleteHubContentCommandInput,
  DeleteHubContentCommandOutput,
} from "./commands/DeleteHubContentCommand";
import {
  DeleteHubContentReferenceCommandInput,
  DeleteHubContentReferenceCommandOutput,
} from "./commands/DeleteHubContentReferenceCommand";
import {
  DeleteHumanTaskUiCommandInput,
  DeleteHumanTaskUiCommandOutput,
} from "./commands/DeleteHumanTaskUiCommand";
import {
  DeleteHyperParameterTuningJobCommandInput,
  DeleteHyperParameterTuningJobCommandOutput,
} from "./commands/DeleteHyperParameterTuningJobCommand";
import {
  DeleteImageCommandInput,
  DeleteImageCommandOutput,
} from "./commands/DeleteImageCommand";
import {
  DeleteImageVersionCommandInput,
  DeleteImageVersionCommandOutput,
} from "./commands/DeleteImageVersionCommand";
import {
  DeleteInferenceComponentCommandInput,
  DeleteInferenceComponentCommandOutput,
} from "./commands/DeleteInferenceComponentCommand";
import {
  DeleteInferenceExperimentCommandInput,
  DeleteInferenceExperimentCommandOutput,
} from "./commands/DeleteInferenceExperimentCommand";
import {
  DeleteMlflowAppCommandInput,
  DeleteMlflowAppCommandOutput,
} from "./commands/DeleteMlflowAppCommand";
import {
  DeleteMlflowTrackingServerCommandInput,
  DeleteMlflowTrackingServerCommandOutput,
} from "./commands/DeleteMlflowTrackingServerCommand";
import {
  DeleteModelBiasJobDefinitionCommandInput,
  DeleteModelBiasJobDefinitionCommandOutput,
} from "./commands/DeleteModelBiasJobDefinitionCommand";
import {
  DeleteModelCardCommandInput,
  DeleteModelCardCommandOutput,
} from "./commands/DeleteModelCardCommand";
import {
  DeleteModelCommandInput,
  DeleteModelCommandOutput,
} from "./commands/DeleteModelCommand";
import {
  DeleteModelExplainabilityJobDefinitionCommandInput,
  DeleteModelExplainabilityJobDefinitionCommandOutput,
} from "./commands/DeleteModelExplainabilityJobDefinitionCommand";
import {
  DeleteModelPackageCommandInput,
  DeleteModelPackageCommandOutput,
} from "./commands/DeleteModelPackageCommand";
import {
  DeleteModelPackageGroupCommandInput,
  DeleteModelPackageGroupCommandOutput,
} from "./commands/DeleteModelPackageGroupCommand";
import {
  DeleteModelPackageGroupPolicyCommandInput,
  DeleteModelPackageGroupPolicyCommandOutput,
} from "./commands/DeleteModelPackageGroupPolicyCommand";
import {
  DeleteModelQualityJobDefinitionCommandInput,
  DeleteModelQualityJobDefinitionCommandOutput,
} from "./commands/DeleteModelQualityJobDefinitionCommand";
import {
  DeleteMonitoringScheduleCommandInput,
  DeleteMonitoringScheduleCommandOutput,
} from "./commands/DeleteMonitoringScheduleCommand";
import {
  DeleteNotebookInstanceCommandInput,
  DeleteNotebookInstanceCommandOutput,
} from "./commands/DeleteNotebookInstanceCommand";
import {
  DeleteNotebookInstanceLifecycleConfigCommandInput,
  DeleteNotebookInstanceLifecycleConfigCommandOutput,
} from "./commands/DeleteNotebookInstanceLifecycleConfigCommand";
import {
  DeleteOptimizationJobCommandInput,
  DeleteOptimizationJobCommandOutput,
} from "./commands/DeleteOptimizationJobCommand";
import {
  DeletePartnerAppCommandInput,
  DeletePartnerAppCommandOutput,
} from "./commands/DeletePartnerAppCommand";
import {
  DeletePipelineCommandInput,
  DeletePipelineCommandOutput,
} from "./commands/DeletePipelineCommand";
import {
  DeleteProcessingJobCommandInput,
  DeleteProcessingJobCommandOutput,
} from "./commands/DeleteProcessingJobCommand";
import {
  DeleteProjectCommandInput,
  DeleteProjectCommandOutput,
} from "./commands/DeleteProjectCommand";
import {
  DeleteSpaceCommandInput,
  DeleteSpaceCommandOutput,
} from "./commands/DeleteSpaceCommand";
import {
  DeleteStudioLifecycleConfigCommandInput,
  DeleteStudioLifecycleConfigCommandOutput,
} from "./commands/DeleteStudioLifecycleConfigCommand";
import {
  DeleteTagsCommandInput,
  DeleteTagsCommandOutput,
} from "./commands/DeleteTagsCommand";
import {
  DeleteTrainingJobCommandInput,
  DeleteTrainingJobCommandOutput,
} from "./commands/DeleteTrainingJobCommand";
import {
  DeleteTrialCommandInput,
  DeleteTrialCommandOutput,
} from "./commands/DeleteTrialCommand";
import {
  DeleteTrialComponentCommandInput,
  DeleteTrialComponentCommandOutput,
} from "./commands/DeleteTrialComponentCommand";
import {
  DeleteUserProfileCommandInput,
  DeleteUserProfileCommandOutput,
} from "./commands/DeleteUserProfileCommand";
import {
  DeleteWorkforceCommandInput,
  DeleteWorkforceCommandOutput,
} from "./commands/DeleteWorkforceCommand";
import {
  DeleteWorkteamCommandInput,
  DeleteWorkteamCommandOutput,
} from "./commands/DeleteWorkteamCommand";
import {
  DeregisterDevicesCommandInput,
  DeregisterDevicesCommandOutput,
} from "./commands/DeregisterDevicesCommand";
import {
  DescribeActionCommandInput,
  DescribeActionCommandOutput,
} from "./commands/DescribeActionCommand";
import {
  DescribeAlgorithmCommandInput,
  DescribeAlgorithmCommandOutput,
} from "./commands/DescribeAlgorithmCommand";
import {
  DescribeAppCommandInput,
  DescribeAppCommandOutput,
} from "./commands/DescribeAppCommand";
import {
  DescribeAppImageConfigCommandInput,
  DescribeAppImageConfigCommandOutput,
} from "./commands/DescribeAppImageConfigCommand";
import {
  DescribeArtifactCommandInput,
  DescribeArtifactCommandOutput,
} from "./commands/DescribeArtifactCommand";
import {
  DescribeAutoMLJobCommandInput,
  DescribeAutoMLJobCommandOutput,
} from "./commands/DescribeAutoMLJobCommand";
import {
  DescribeAutoMLJobV2CommandInput,
  DescribeAutoMLJobV2CommandOutput,
} from "./commands/DescribeAutoMLJobV2Command";
import {
  DescribeClusterCommandInput,
  DescribeClusterCommandOutput,
} from "./commands/DescribeClusterCommand";
import {
  DescribeClusterEventCommandInput,
  DescribeClusterEventCommandOutput,
} from "./commands/DescribeClusterEventCommand";
import {
  DescribeClusterNodeCommandInput,
  DescribeClusterNodeCommandOutput,
} from "./commands/DescribeClusterNodeCommand";
import {
  DescribeClusterSchedulerConfigCommandInput,
  DescribeClusterSchedulerConfigCommandOutput,
} from "./commands/DescribeClusterSchedulerConfigCommand";
import {
  DescribeCodeRepositoryCommandInput,
  DescribeCodeRepositoryCommandOutput,
} from "./commands/DescribeCodeRepositoryCommand";
import {
  DescribeCompilationJobCommandInput,
  DescribeCompilationJobCommandOutput,
} from "./commands/DescribeCompilationJobCommand";
import {
  DescribeComputeQuotaCommandInput,
  DescribeComputeQuotaCommandOutput,
} from "./commands/DescribeComputeQuotaCommand";
import {
  DescribeContextCommandInput,
  DescribeContextCommandOutput,
} from "./commands/DescribeContextCommand";
import {
  DescribeDataQualityJobDefinitionCommandInput,
  DescribeDataQualityJobDefinitionCommandOutput,
} from "./commands/DescribeDataQualityJobDefinitionCommand";
import {
  DescribeDeviceCommandInput,
  DescribeDeviceCommandOutput,
} from "./commands/DescribeDeviceCommand";
import {
  DescribeDeviceFleetCommandInput,
  DescribeDeviceFleetCommandOutput,
} from "./commands/DescribeDeviceFleetCommand";
import {
  DescribeDomainCommandInput,
  DescribeDomainCommandOutput,
} from "./commands/DescribeDomainCommand";
import {
  DescribeEdgeDeploymentPlanCommandInput,
  DescribeEdgeDeploymentPlanCommandOutput,
} from "./commands/DescribeEdgeDeploymentPlanCommand";
import {
  DescribeEdgePackagingJobCommandInput,
  DescribeEdgePackagingJobCommandOutput,
} from "./commands/DescribeEdgePackagingJobCommand";
import {
  DescribeEndpointCommandInput,
  DescribeEndpointCommandOutput,
} from "./commands/DescribeEndpointCommand";
import {
  DescribeEndpointConfigCommandInput,
  DescribeEndpointConfigCommandOutput,
} from "./commands/DescribeEndpointConfigCommand";
import {
  DescribeExperimentCommandInput,
  DescribeExperimentCommandOutput,
} from "./commands/DescribeExperimentCommand";
import {
  DescribeFeatureGroupCommandInput,
  DescribeFeatureGroupCommandOutput,
} from "./commands/DescribeFeatureGroupCommand";
import {
  DescribeFeatureMetadataCommandInput,
  DescribeFeatureMetadataCommandOutput,
} from "./commands/DescribeFeatureMetadataCommand";
import {
  DescribeFlowDefinitionCommandInput,
  DescribeFlowDefinitionCommandOutput,
} from "./commands/DescribeFlowDefinitionCommand";
import {
  DescribeHubCommandInput,
  DescribeHubCommandOutput,
} from "./commands/DescribeHubCommand";
import {
  DescribeHubContentCommandInput,
  DescribeHubContentCommandOutput,
} from "./commands/DescribeHubContentCommand";
import {
  DescribeHumanTaskUiCommandInput,
  DescribeHumanTaskUiCommandOutput,
} from "./commands/DescribeHumanTaskUiCommand";
import {
  DescribeHyperParameterTuningJobCommandInput,
  DescribeHyperParameterTuningJobCommandOutput,
} from "./commands/DescribeHyperParameterTuningJobCommand";
import {
  DescribeImageCommandInput,
  DescribeImageCommandOutput,
} from "./commands/DescribeImageCommand";
import {
  DescribeImageVersionCommandInput,
  DescribeImageVersionCommandOutput,
} from "./commands/DescribeImageVersionCommand";
import {
  DescribeInferenceComponentCommandInput,
  DescribeInferenceComponentCommandOutput,
} from "./commands/DescribeInferenceComponentCommand";
import {
  DescribeInferenceExperimentCommandInput,
  DescribeInferenceExperimentCommandOutput,
} from "./commands/DescribeInferenceExperimentCommand";
import {
  DescribeInferenceRecommendationsJobCommandInput,
  DescribeInferenceRecommendationsJobCommandOutput,
} from "./commands/DescribeInferenceRecommendationsJobCommand";
import {
  DescribeLabelingJobCommandInput,
  DescribeLabelingJobCommandOutput,
} from "./commands/DescribeLabelingJobCommand";
import {
  DescribeLineageGroupCommandInput,
  DescribeLineageGroupCommandOutput,
} from "./commands/DescribeLineageGroupCommand";
import {
  DescribeMlflowAppCommandInput,
  DescribeMlflowAppCommandOutput,
} from "./commands/DescribeMlflowAppCommand";
import {
  DescribeMlflowTrackingServerCommandInput,
  DescribeMlflowTrackingServerCommandOutput,
} from "./commands/DescribeMlflowTrackingServerCommand";
import {
  DescribeModelBiasJobDefinitionCommandInput,
  DescribeModelBiasJobDefinitionCommandOutput,
} from "./commands/DescribeModelBiasJobDefinitionCommand";
import {
  DescribeModelCardCommandInput,
  DescribeModelCardCommandOutput,
} from "./commands/DescribeModelCardCommand";
import {
  DescribeModelCardExportJobCommandInput,
  DescribeModelCardExportJobCommandOutput,
} from "./commands/DescribeModelCardExportJobCommand";
import {
  DescribeModelCommandInput,
  DescribeModelCommandOutput,
} from "./commands/DescribeModelCommand";
import {
  DescribeModelExplainabilityJobDefinitionCommandInput,
  DescribeModelExplainabilityJobDefinitionCommandOutput,
} from "./commands/DescribeModelExplainabilityJobDefinitionCommand";
import {
  DescribeModelPackageCommandInput,
  DescribeModelPackageCommandOutput,
} from "./commands/DescribeModelPackageCommand";
import {
  DescribeModelPackageGroupCommandInput,
  DescribeModelPackageGroupCommandOutput,
} from "./commands/DescribeModelPackageGroupCommand";
import {
  DescribeModelQualityJobDefinitionCommandInput,
  DescribeModelQualityJobDefinitionCommandOutput,
} from "./commands/DescribeModelQualityJobDefinitionCommand";
import {
  DescribeMonitoringScheduleCommandInput,
  DescribeMonitoringScheduleCommandOutput,
} from "./commands/DescribeMonitoringScheduleCommand";
import {
  DescribeNotebookInstanceCommandInput,
  DescribeNotebookInstanceCommandOutput,
} from "./commands/DescribeNotebookInstanceCommand";
import {
  DescribeNotebookInstanceLifecycleConfigCommandInput,
  DescribeNotebookInstanceLifecycleConfigCommandOutput,
} from "./commands/DescribeNotebookInstanceLifecycleConfigCommand";
import {
  DescribeOptimizationJobCommandInput,
  DescribeOptimizationJobCommandOutput,
} from "./commands/DescribeOptimizationJobCommand";
import {
  DescribePartnerAppCommandInput,
  DescribePartnerAppCommandOutput,
} from "./commands/DescribePartnerAppCommand";
import {
  DescribePipelineCommandInput,
  DescribePipelineCommandOutput,
} from "./commands/DescribePipelineCommand";
import {
  DescribePipelineDefinitionForExecutionCommandInput,
  DescribePipelineDefinitionForExecutionCommandOutput,
} from "./commands/DescribePipelineDefinitionForExecutionCommand";
import {
  DescribePipelineExecutionCommandInput,
  DescribePipelineExecutionCommandOutput,
} from "./commands/DescribePipelineExecutionCommand";
import {
  DescribeProcessingJobCommandInput,
  DescribeProcessingJobCommandOutput,
} from "./commands/DescribeProcessingJobCommand";
import {
  DescribeProjectCommandInput,
  DescribeProjectCommandOutput,
} from "./commands/DescribeProjectCommand";
import {
  DescribeReservedCapacityCommandInput,
  DescribeReservedCapacityCommandOutput,
} from "./commands/DescribeReservedCapacityCommand";
import {
  DescribeSpaceCommandInput,
  DescribeSpaceCommandOutput,
} from "./commands/DescribeSpaceCommand";
import {
  DescribeStudioLifecycleConfigCommandInput,
  DescribeStudioLifecycleConfigCommandOutput,
} from "./commands/DescribeStudioLifecycleConfigCommand";
import {
  DescribeSubscribedWorkteamCommandInput,
  DescribeSubscribedWorkteamCommandOutput,
} from "./commands/DescribeSubscribedWorkteamCommand";
import {
  DescribeTrainingJobCommandInput,
  DescribeTrainingJobCommandOutput,
} from "./commands/DescribeTrainingJobCommand";
import {
  DescribeTrainingPlanCommandInput,
  DescribeTrainingPlanCommandOutput,
} from "./commands/DescribeTrainingPlanCommand";
import {
  DescribeTransformJobCommandInput,
  DescribeTransformJobCommandOutput,
} from "./commands/DescribeTransformJobCommand";
import {
  DescribeTrialCommandInput,
  DescribeTrialCommandOutput,
} from "./commands/DescribeTrialCommand";
import {
  DescribeTrialComponentCommandInput,
  DescribeTrialComponentCommandOutput,
} from "./commands/DescribeTrialComponentCommand";
import {
  DescribeUserProfileCommandInput,
  DescribeUserProfileCommandOutput,
} from "./commands/DescribeUserProfileCommand";
import {
  DescribeWorkforceCommandInput,
  DescribeWorkforceCommandOutput,
} from "./commands/DescribeWorkforceCommand";
import {
  DescribeWorkteamCommandInput,
  DescribeWorkteamCommandOutput,
} from "./commands/DescribeWorkteamCommand";
import {
  DetachClusterNodeVolumeCommandInput,
  DetachClusterNodeVolumeCommandOutput,
} from "./commands/DetachClusterNodeVolumeCommand";
import {
  DisableSagemakerServicecatalogPortfolioCommandInput,
  DisableSagemakerServicecatalogPortfolioCommandOutput,
} from "./commands/DisableSagemakerServicecatalogPortfolioCommand";
import {
  DisassociateTrialComponentCommandInput,
  DisassociateTrialComponentCommandOutput,
} from "./commands/DisassociateTrialComponentCommand";
import {
  EnableSagemakerServicecatalogPortfolioCommandInput,
  EnableSagemakerServicecatalogPortfolioCommandOutput,
} from "./commands/EnableSagemakerServicecatalogPortfolioCommand";
import {
  GetDeviceFleetReportCommandInput,
  GetDeviceFleetReportCommandOutput,
} from "./commands/GetDeviceFleetReportCommand";
import {
  GetLineageGroupPolicyCommandInput,
  GetLineageGroupPolicyCommandOutput,
} from "./commands/GetLineageGroupPolicyCommand";
import {
  GetModelPackageGroupPolicyCommandInput,
  GetModelPackageGroupPolicyCommandOutput,
} from "./commands/GetModelPackageGroupPolicyCommand";
import {
  GetSagemakerServicecatalogPortfolioStatusCommandInput,
  GetSagemakerServicecatalogPortfolioStatusCommandOutput,
} from "./commands/GetSagemakerServicecatalogPortfolioStatusCommand";
import {
  GetScalingConfigurationRecommendationCommandInput,
  GetScalingConfigurationRecommendationCommandOutput,
} from "./commands/GetScalingConfigurationRecommendationCommand";
import {
  GetSearchSuggestionsCommandInput,
  GetSearchSuggestionsCommandOutput,
} from "./commands/GetSearchSuggestionsCommand";
import {
  ImportHubContentCommandInput,
  ImportHubContentCommandOutput,
} from "./commands/ImportHubContentCommand";
import {
  ListActionsCommandInput,
  ListActionsCommandOutput,
} from "./commands/ListActionsCommand";
import {
  ListAlgorithmsCommandInput,
  ListAlgorithmsCommandOutput,
} from "./commands/ListAlgorithmsCommand";
import {
  ListAliasesCommandInput,
  ListAliasesCommandOutput,
} from "./commands/ListAliasesCommand";
import {
  ListAppImageConfigsCommandInput,
  ListAppImageConfigsCommandOutput,
} from "./commands/ListAppImageConfigsCommand";
import {
  ListAppsCommandInput,
  ListAppsCommandOutput,
} from "./commands/ListAppsCommand";
import {
  ListArtifactsCommandInput,
  ListArtifactsCommandOutput,
} from "./commands/ListArtifactsCommand";
import {
  ListAssociationsCommandInput,
  ListAssociationsCommandOutput,
} from "./commands/ListAssociationsCommand";
import {
  ListAutoMLJobsCommandInput,
  ListAutoMLJobsCommandOutput,
} from "./commands/ListAutoMLJobsCommand";
import {
  ListCandidatesForAutoMLJobCommandInput,
  ListCandidatesForAutoMLJobCommandOutput,
} from "./commands/ListCandidatesForAutoMLJobCommand";
import {
  ListClusterEventsCommandInput,
  ListClusterEventsCommandOutput,
} from "./commands/ListClusterEventsCommand";
import {
  ListClusterNodesCommandInput,
  ListClusterNodesCommandOutput,
} from "./commands/ListClusterNodesCommand";
import {
  ListClusterSchedulerConfigsCommandInput,
  ListClusterSchedulerConfigsCommandOutput,
} from "./commands/ListClusterSchedulerConfigsCommand";
import {
  ListClustersCommandInput,
  ListClustersCommandOutput,
} from "./commands/ListClustersCommand";
import {
  ListCodeRepositoriesCommandInput,
  ListCodeRepositoriesCommandOutput,
} from "./commands/ListCodeRepositoriesCommand";
import {
  ListCompilationJobsCommandInput,
  ListCompilationJobsCommandOutput,
} from "./commands/ListCompilationJobsCommand";
import {
  ListComputeQuotasCommandInput,
  ListComputeQuotasCommandOutput,
} from "./commands/ListComputeQuotasCommand";
import {
  ListContextsCommandInput,
  ListContextsCommandOutput,
} from "./commands/ListContextsCommand";
import {
  ListDataQualityJobDefinitionsCommandInput,
  ListDataQualityJobDefinitionsCommandOutput,
} from "./commands/ListDataQualityJobDefinitionsCommand";
import {
  ListDeviceFleetsCommandInput,
  ListDeviceFleetsCommandOutput,
} from "./commands/ListDeviceFleetsCommand";
import {
  ListDevicesCommandInput,
  ListDevicesCommandOutput,
} from "./commands/ListDevicesCommand";
import {
  ListDomainsCommandInput,
  ListDomainsCommandOutput,
} from "./commands/ListDomainsCommand";
import {
  ListEdgeDeploymentPlansCommandInput,
  ListEdgeDeploymentPlansCommandOutput,
} from "./commands/ListEdgeDeploymentPlansCommand";
import {
  ListEdgePackagingJobsCommandInput,
  ListEdgePackagingJobsCommandOutput,
} from "./commands/ListEdgePackagingJobsCommand";
import {
  ListEndpointConfigsCommandInput,
  ListEndpointConfigsCommandOutput,
} from "./commands/ListEndpointConfigsCommand";
import {
  ListEndpointsCommandInput,
  ListEndpointsCommandOutput,
} from "./commands/ListEndpointsCommand";
import {
  ListExperimentsCommandInput,
  ListExperimentsCommandOutput,
} from "./commands/ListExperimentsCommand";
import {
  ListFeatureGroupsCommandInput,
  ListFeatureGroupsCommandOutput,
} from "./commands/ListFeatureGroupsCommand";
import {
  ListFlowDefinitionsCommandInput,
  ListFlowDefinitionsCommandOutput,
} from "./commands/ListFlowDefinitionsCommand";
import {
  ListHubContentsCommandInput,
  ListHubContentsCommandOutput,
} from "./commands/ListHubContentsCommand";
import {
  ListHubContentVersionsCommandInput,
  ListHubContentVersionsCommandOutput,
} from "./commands/ListHubContentVersionsCommand";
import {
  ListHubsCommandInput,
  ListHubsCommandOutput,
} from "./commands/ListHubsCommand";
import {
  ListHumanTaskUisCommandInput,
  ListHumanTaskUisCommandOutput,
} from "./commands/ListHumanTaskUisCommand";
import {
  ListHyperParameterTuningJobsCommandInput,
  ListHyperParameterTuningJobsCommandOutput,
} from "./commands/ListHyperParameterTuningJobsCommand";
import {
  ListImagesCommandInput,
  ListImagesCommandOutput,
} from "./commands/ListImagesCommand";
import {
  ListImageVersionsCommandInput,
  ListImageVersionsCommandOutput,
} from "./commands/ListImageVersionsCommand";
import {
  ListInferenceComponentsCommandInput,
  ListInferenceComponentsCommandOutput,
} from "./commands/ListInferenceComponentsCommand";
import {
  ListInferenceExperimentsCommandInput,
  ListInferenceExperimentsCommandOutput,
} from "./commands/ListInferenceExperimentsCommand";
import {
  ListInferenceRecommendationsJobsCommandInput,
  ListInferenceRecommendationsJobsCommandOutput,
} from "./commands/ListInferenceRecommendationsJobsCommand";
import {
  ListInferenceRecommendationsJobStepsCommandInput,
  ListInferenceRecommendationsJobStepsCommandOutput,
} from "./commands/ListInferenceRecommendationsJobStepsCommand";
import {
  ListLabelingJobsCommandInput,
  ListLabelingJobsCommandOutput,
} from "./commands/ListLabelingJobsCommand";
import {
  ListLabelingJobsForWorkteamCommandInput,
  ListLabelingJobsForWorkteamCommandOutput,
} from "./commands/ListLabelingJobsForWorkteamCommand";
import {
  ListLineageGroupsCommandInput,
  ListLineageGroupsCommandOutput,
} from "./commands/ListLineageGroupsCommand";
import {
  ListMlflowAppsCommandInput,
  ListMlflowAppsCommandOutput,
} from "./commands/ListMlflowAppsCommand";
import {
  ListMlflowTrackingServersCommandInput,
  ListMlflowTrackingServersCommandOutput,
} from "./commands/ListMlflowTrackingServersCommand";
import {
  ListModelBiasJobDefinitionsCommandInput,
  ListModelBiasJobDefinitionsCommandOutput,
} from "./commands/ListModelBiasJobDefinitionsCommand";
import {
  ListModelCardExportJobsCommandInput,
  ListModelCardExportJobsCommandOutput,
} from "./commands/ListModelCardExportJobsCommand";
import {
  ListModelCardsCommandInput,
  ListModelCardsCommandOutput,
} from "./commands/ListModelCardsCommand";
import {
  ListModelCardVersionsCommandInput,
  ListModelCardVersionsCommandOutput,
} from "./commands/ListModelCardVersionsCommand";
import {
  ListModelExplainabilityJobDefinitionsCommandInput,
  ListModelExplainabilityJobDefinitionsCommandOutput,
} from "./commands/ListModelExplainabilityJobDefinitionsCommand";
import {
  ListModelMetadataCommandInput,
  ListModelMetadataCommandOutput,
} from "./commands/ListModelMetadataCommand";
import {
  ListModelPackageGroupsCommandInput,
  ListModelPackageGroupsCommandOutput,
} from "./commands/ListModelPackageGroupsCommand";
import {
  ListModelPackagesCommandInput,
  ListModelPackagesCommandOutput,
} from "./commands/ListModelPackagesCommand";
import {
  ListModelQualityJobDefinitionsCommandInput,
  ListModelQualityJobDefinitionsCommandOutput,
} from "./commands/ListModelQualityJobDefinitionsCommand";
import {
  ListModelsCommandInput,
  ListModelsCommandOutput,
} from "./commands/ListModelsCommand";
import {
  ListMonitoringAlertHistoryCommandInput,
  ListMonitoringAlertHistoryCommandOutput,
} from "./commands/ListMonitoringAlertHistoryCommand";
import {
  ListMonitoringAlertsCommandInput,
  ListMonitoringAlertsCommandOutput,
} from "./commands/ListMonitoringAlertsCommand";
import {
  ListMonitoringExecutionsCommandInput,
  ListMonitoringExecutionsCommandOutput,
} from "./commands/ListMonitoringExecutionsCommand";
import {
  ListMonitoringSchedulesCommandInput,
  ListMonitoringSchedulesCommandOutput,
} from "./commands/ListMonitoringSchedulesCommand";
import {
  ListNotebookInstanceLifecycleConfigsCommandInput,
  ListNotebookInstanceLifecycleConfigsCommandOutput,
} from "./commands/ListNotebookInstanceLifecycleConfigsCommand";
import {
  ListNotebookInstancesCommandInput,
  ListNotebookInstancesCommandOutput,
} from "./commands/ListNotebookInstancesCommand";
import {
  ListOptimizationJobsCommandInput,
  ListOptimizationJobsCommandOutput,
} from "./commands/ListOptimizationJobsCommand";
import {
  ListPartnerAppsCommandInput,
  ListPartnerAppsCommandOutput,
} from "./commands/ListPartnerAppsCommand";
import {
  ListPipelineExecutionsCommandInput,
  ListPipelineExecutionsCommandOutput,
} from "./commands/ListPipelineExecutionsCommand";
import {
  ListPipelineExecutionStepsCommandInput,
  ListPipelineExecutionStepsCommandOutput,
} from "./commands/ListPipelineExecutionStepsCommand";
import {
  ListPipelineParametersForExecutionCommandInput,
  ListPipelineParametersForExecutionCommandOutput,
} from "./commands/ListPipelineParametersForExecutionCommand";
import {
  ListPipelinesCommandInput,
  ListPipelinesCommandOutput,
} from "./commands/ListPipelinesCommand";
import {
  ListPipelineVersionsCommandInput,
  ListPipelineVersionsCommandOutput,
} from "./commands/ListPipelineVersionsCommand";
import {
  ListProcessingJobsCommandInput,
  ListProcessingJobsCommandOutput,
} from "./commands/ListProcessingJobsCommand";
import {
  ListProjectsCommandInput,
  ListProjectsCommandOutput,
} from "./commands/ListProjectsCommand";
import {
  ListResourceCatalogsCommandInput,
  ListResourceCatalogsCommandOutput,
} from "./commands/ListResourceCatalogsCommand";
import {
  ListSpacesCommandInput,
  ListSpacesCommandOutput,
} from "./commands/ListSpacesCommand";
import {
  ListStageDevicesCommandInput,
  ListStageDevicesCommandOutput,
} from "./commands/ListStageDevicesCommand";
import {
  ListStudioLifecycleConfigsCommandInput,
  ListStudioLifecycleConfigsCommandOutput,
} from "./commands/ListStudioLifecycleConfigsCommand";
import {
  ListSubscribedWorkteamsCommandInput,
  ListSubscribedWorkteamsCommandOutput,
} from "./commands/ListSubscribedWorkteamsCommand";
import {
  ListTagsCommandInput,
  ListTagsCommandOutput,
} from "./commands/ListTagsCommand";
import {
  ListTrainingJobsCommandInput,
  ListTrainingJobsCommandOutput,
} from "./commands/ListTrainingJobsCommand";
import {
  ListTrainingJobsForHyperParameterTuningJobCommandInput,
  ListTrainingJobsForHyperParameterTuningJobCommandOutput,
} from "./commands/ListTrainingJobsForHyperParameterTuningJobCommand";
import {
  ListTrainingPlansCommandInput,
  ListTrainingPlansCommandOutput,
} from "./commands/ListTrainingPlansCommand";
import {
  ListTransformJobsCommandInput,
  ListTransformJobsCommandOutput,
} from "./commands/ListTransformJobsCommand";
import {
  ListTrialComponentsCommandInput,
  ListTrialComponentsCommandOutput,
} from "./commands/ListTrialComponentsCommand";
import {
  ListTrialsCommandInput,
  ListTrialsCommandOutput,
} from "./commands/ListTrialsCommand";
import {
  ListUltraServersByReservedCapacityCommandInput,
  ListUltraServersByReservedCapacityCommandOutput,
} from "./commands/ListUltraServersByReservedCapacityCommand";
import {
  ListUserProfilesCommandInput,
  ListUserProfilesCommandOutput,
} from "./commands/ListUserProfilesCommand";
import {
  ListWorkforcesCommandInput,
  ListWorkforcesCommandOutput,
} from "./commands/ListWorkforcesCommand";
import {
  ListWorkteamsCommandInput,
  ListWorkteamsCommandOutput,
} from "./commands/ListWorkteamsCommand";
import {
  PutModelPackageGroupPolicyCommandInput,
  PutModelPackageGroupPolicyCommandOutput,
} from "./commands/PutModelPackageGroupPolicyCommand";
import {
  QueryLineageCommandInput,
  QueryLineageCommandOutput,
} from "./commands/QueryLineageCommand";
import {
  RegisterDevicesCommandInput,
  RegisterDevicesCommandOutput,
} from "./commands/RegisterDevicesCommand";
import {
  RenderUiTemplateCommandInput,
  RenderUiTemplateCommandOutput,
} from "./commands/RenderUiTemplateCommand";
import {
  RetryPipelineExecutionCommandInput,
  RetryPipelineExecutionCommandOutput,
} from "./commands/RetryPipelineExecutionCommand";
import {
  SearchCommandInput,
  SearchCommandOutput,
} from "./commands/SearchCommand";
import {
  SearchTrainingPlanOfferingsCommandInput,
  SearchTrainingPlanOfferingsCommandOutput,
} from "./commands/SearchTrainingPlanOfferingsCommand";
import {
  SendPipelineExecutionStepFailureCommandInput,
  SendPipelineExecutionStepFailureCommandOutput,
} from "./commands/SendPipelineExecutionStepFailureCommand";
import {
  SendPipelineExecutionStepSuccessCommandInput,
  SendPipelineExecutionStepSuccessCommandOutput,
} from "./commands/SendPipelineExecutionStepSuccessCommand";
import {
  StartEdgeDeploymentStageCommandInput,
  StartEdgeDeploymentStageCommandOutput,
} from "./commands/StartEdgeDeploymentStageCommand";
import {
  StartInferenceExperimentCommandInput,
  StartInferenceExperimentCommandOutput,
} from "./commands/StartInferenceExperimentCommand";
import {
  StartMlflowTrackingServerCommandInput,
  StartMlflowTrackingServerCommandOutput,
} from "./commands/StartMlflowTrackingServerCommand";
import {
  StartMonitoringScheduleCommandInput,
  StartMonitoringScheduleCommandOutput,
} from "./commands/StartMonitoringScheduleCommand";
import {
  StartNotebookInstanceCommandInput,
  StartNotebookInstanceCommandOutput,
} from "./commands/StartNotebookInstanceCommand";
import {
  StartPipelineExecutionCommandInput,
  StartPipelineExecutionCommandOutput,
} from "./commands/StartPipelineExecutionCommand";
import {
  StartSessionCommandInput,
  StartSessionCommandOutput,
} from "./commands/StartSessionCommand";
import {
  StopAutoMLJobCommandInput,
  StopAutoMLJobCommandOutput,
} from "./commands/StopAutoMLJobCommand";
import {
  StopCompilationJobCommandInput,
  StopCompilationJobCommandOutput,
} from "./commands/StopCompilationJobCommand";
import {
  StopEdgeDeploymentStageCommandInput,
  StopEdgeDeploymentStageCommandOutput,
} from "./commands/StopEdgeDeploymentStageCommand";
import {
  StopEdgePackagingJobCommandInput,
  StopEdgePackagingJobCommandOutput,
} from "./commands/StopEdgePackagingJobCommand";
import {
  StopHyperParameterTuningJobCommandInput,
  StopHyperParameterTuningJobCommandOutput,
} from "./commands/StopHyperParameterTuningJobCommand";
import {
  StopInferenceExperimentCommandInput,
  StopInferenceExperimentCommandOutput,
} from "./commands/StopInferenceExperimentCommand";
import {
  StopInferenceRecommendationsJobCommandInput,
  StopInferenceRecommendationsJobCommandOutput,
} from "./commands/StopInferenceRecommendationsJobCommand";
import {
  StopLabelingJobCommandInput,
  StopLabelingJobCommandOutput,
} from "./commands/StopLabelingJobCommand";
import {
  StopMlflowTrackingServerCommandInput,
  StopMlflowTrackingServerCommandOutput,
} from "./commands/StopMlflowTrackingServerCommand";
import {
  StopMonitoringScheduleCommandInput,
  StopMonitoringScheduleCommandOutput,
} from "./commands/StopMonitoringScheduleCommand";
import {
  StopNotebookInstanceCommandInput,
  StopNotebookInstanceCommandOutput,
} from "./commands/StopNotebookInstanceCommand";
import {
  StopOptimizationJobCommandInput,
  StopOptimizationJobCommandOutput,
} from "./commands/StopOptimizationJobCommand";
import {
  StopPipelineExecutionCommandInput,
  StopPipelineExecutionCommandOutput,
} from "./commands/StopPipelineExecutionCommand";
import {
  StopProcessingJobCommandInput,
  StopProcessingJobCommandOutput,
} from "./commands/StopProcessingJobCommand";
import {
  StopTrainingJobCommandInput,
  StopTrainingJobCommandOutput,
} from "./commands/StopTrainingJobCommand";
import {
  StopTransformJobCommandInput,
  StopTransformJobCommandOutput,
} from "./commands/StopTransformJobCommand";
import {
  UpdateActionCommandInput,
  UpdateActionCommandOutput,
} from "./commands/UpdateActionCommand";
import {
  UpdateAppImageConfigCommandInput,
  UpdateAppImageConfigCommandOutput,
} from "./commands/UpdateAppImageConfigCommand";
import {
  UpdateArtifactCommandInput,
  UpdateArtifactCommandOutput,
} from "./commands/UpdateArtifactCommand";
import {
  UpdateClusterCommandInput,
  UpdateClusterCommandOutput,
} from "./commands/UpdateClusterCommand";
import {
  UpdateClusterSchedulerConfigCommandInput,
  UpdateClusterSchedulerConfigCommandOutput,
} from "./commands/UpdateClusterSchedulerConfigCommand";
import {
  UpdateClusterSoftwareCommandInput,
  UpdateClusterSoftwareCommandOutput,
} from "./commands/UpdateClusterSoftwareCommand";
import {
  UpdateCodeRepositoryCommandInput,
  UpdateCodeRepositoryCommandOutput,
} from "./commands/UpdateCodeRepositoryCommand";
import {
  UpdateComputeQuotaCommandInput,
  UpdateComputeQuotaCommandOutput,
} from "./commands/UpdateComputeQuotaCommand";
import {
  UpdateContextCommandInput,
  UpdateContextCommandOutput,
} from "./commands/UpdateContextCommand";
import {
  UpdateDeviceFleetCommandInput,
  UpdateDeviceFleetCommandOutput,
} from "./commands/UpdateDeviceFleetCommand";
import {
  UpdateDevicesCommandInput,
  UpdateDevicesCommandOutput,
} from "./commands/UpdateDevicesCommand";
import {
  UpdateDomainCommandInput,
  UpdateDomainCommandOutput,
} from "./commands/UpdateDomainCommand";
import {
  UpdateEndpointCommandInput,
  UpdateEndpointCommandOutput,
} from "./commands/UpdateEndpointCommand";
import {
  UpdateEndpointWeightsAndCapacitiesCommandInput,
  UpdateEndpointWeightsAndCapacitiesCommandOutput,
} from "./commands/UpdateEndpointWeightsAndCapacitiesCommand";
import {
  UpdateExperimentCommandInput,
  UpdateExperimentCommandOutput,
} from "./commands/UpdateExperimentCommand";
import {
  UpdateFeatureGroupCommandInput,
  UpdateFeatureGroupCommandOutput,
} from "./commands/UpdateFeatureGroupCommand";
import {
  UpdateFeatureMetadataCommandInput,
  UpdateFeatureMetadataCommandOutput,
} from "./commands/UpdateFeatureMetadataCommand";
import {
  UpdateHubCommandInput,
  UpdateHubCommandOutput,
} from "./commands/UpdateHubCommand";
import {
  UpdateHubContentCommandInput,
  UpdateHubContentCommandOutput,
} from "./commands/UpdateHubContentCommand";
import {
  UpdateHubContentReferenceCommandInput,
  UpdateHubContentReferenceCommandOutput,
} from "./commands/UpdateHubContentReferenceCommand";
import {
  UpdateImageCommandInput,
  UpdateImageCommandOutput,
} from "./commands/UpdateImageCommand";
import {
  UpdateImageVersionCommandInput,
  UpdateImageVersionCommandOutput,
} from "./commands/UpdateImageVersionCommand";
import {
  UpdateInferenceComponentCommandInput,
  UpdateInferenceComponentCommandOutput,
} from "./commands/UpdateInferenceComponentCommand";
import {
  UpdateInferenceComponentRuntimeConfigCommandInput,
  UpdateInferenceComponentRuntimeConfigCommandOutput,
} from "./commands/UpdateInferenceComponentRuntimeConfigCommand";
import {
  UpdateInferenceExperimentCommandInput,
  UpdateInferenceExperimentCommandOutput,
} from "./commands/UpdateInferenceExperimentCommand";
import {
  UpdateMlflowAppCommandInput,
  UpdateMlflowAppCommandOutput,
} from "./commands/UpdateMlflowAppCommand";
import {
  UpdateMlflowTrackingServerCommandInput,
  UpdateMlflowTrackingServerCommandOutput,
} from "./commands/UpdateMlflowTrackingServerCommand";
import {
  UpdateModelCardCommandInput,
  UpdateModelCardCommandOutput,
} from "./commands/UpdateModelCardCommand";
import {
  UpdateModelPackageCommandInput,
  UpdateModelPackageCommandOutput,
} from "./commands/UpdateModelPackageCommand";
import {
  UpdateMonitoringAlertCommandInput,
  UpdateMonitoringAlertCommandOutput,
} from "./commands/UpdateMonitoringAlertCommand";
import {
  UpdateMonitoringScheduleCommandInput,
  UpdateMonitoringScheduleCommandOutput,
} from "./commands/UpdateMonitoringScheduleCommand";
import {
  UpdateNotebookInstanceCommandInput,
  UpdateNotebookInstanceCommandOutput,
} from "./commands/UpdateNotebookInstanceCommand";
import {
  UpdateNotebookInstanceLifecycleConfigCommandInput,
  UpdateNotebookInstanceLifecycleConfigCommandOutput,
} from "./commands/UpdateNotebookInstanceLifecycleConfigCommand";
import {
  UpdatePartnerAppCommandInput,
  UpdatePartnerAppCommandOutput,
} from "./commands/UpdatePartnerAppCommand";
import {
  UpdatePipelineCommandInput,
  UpdatePipelineCommandOutput,
} from "./commands/UpdatePipelineCommand";
import {
  UpdatePipelineExecutionCommandInput,
  UpdatePipelineExecutionCommandOutput,
} from "./commands/UpdatePipelineExecutionCommand";
import {
  UpdatePipelineVersionCommandInput,
  UpdatePipelineVersionCommandOutput,
} from "./commands/UpdatePipelineVersionCommand";
import {
  UpdateProjectCommandInput,
  UpdateProjectCommandOutput,
} from "./commands/UpdateProjectCommand";
import {
  UpdateSpaceCommandInput,
  UpdateSpaceCommandOutput,
} from "./commands/UpdateSpaceCommand";
import {
  UpdateTrainingJobCommandInput,
  UpdateTrainingJobCommandOutput,
} from "./commands/UpdateTrainingJobCommand";
import {
  UpdateTrialCommandInput,
  UpdateTrialCommandOutput,
} from "./commands/UpdateTrialCommand";
import {
  UpdateTrialComponentCommandInput,
  UpdateTrialComponentCommandOutput,
} from "./commands/UpdateTrialComponentCommand";
import {
  UpdateUserProfileCommandInput,
  UpdateUserProfileCommandOutput,
} from "./commands/UpdateUserProfileCommand";
import {
  UpdateWorkforceCommandInput,
  UpdateWorkforceCommandOutput,
} from "./commands/UpdateWorkforceCommand";
import {
  UpdateWorkteamCommandInput,
  UpdateWorkteamCommandOutput,
} from "./commands/UpdateWorkteamCommand";
import { SageMakerClient } from "./SageMakerClient";
export interface SageMaker {
  addAssociation(
    args: AddAssociationCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<AddAssociationCommandOutput>;
  addAssociation(
    args: AddAssociationCommandInput,
    cb: (err: any, data?: AddAssociationCommandOutput) => void
  ): void;
  addAssociation(
    args: AddAssociationCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: AddAssociationCommandOutput) => void
  ): void;
  addTags(
    args: AddTagsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<AddTagsCommandOutput>;
  addTags(
    args: AddTagsCommandInput,
    cb: (err: any, data?: AddTagsCommandOutput) => void
  ): void;
  addTags(
    args: AddTagsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: AddTagsCommandOutput) => void
  ): void;
  associateTrialComponent(
    args: AssociateTrialComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<AssociateTrialComponentCommandOutput>;
  associateTrialComponent(
    args: AssociateTrialComponentCommandInput,
    cb: (err: any, data?: AssociateTrialComponentCommandOutput) => void
  ): void;
  associateTrialComponent(
    args: AssociateTrialComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: AssociateTrialComponentCommandOutput) => void
  ): void;
  attachClusterNodeVolume(
    args: AttachClusterNodeVolumeCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<AttachClusterNodeVolumeCommandOutput>;
  attachClusterNodeVolume(
    args: AttachClusterNodeVolumeCommandInput,
    cb: (err: any, data?: AttachClusterNodeVolumeCommandOutput) => void
  ): void;
  attachClusterNodeVolume(
    args: AttachClusterNodeVolumeCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: AttachClusterNodeVolumeCommandOutput) => void
  ): void;
  batchAddClusterNodes(
    args: BatchAddClusterNodesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<BatchAddClusterNodesCommandOutput>;
  batchAddClusterNodes(
    args: BatchAddClusterNodesCommandInput,
    cb: (err: any, data?: BatchAddClusterNodesCommandOutput) => void
  ): void;
  batchAddClusterNodes(
    args: BatchAddClusterNodesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: BatchAddClusterNodesCommandOutput) => void
  ): void;
  batchDeleteClusterNodes(
    args: BatchDeleteClusterNodesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<BatchDeleteClusterNodesCommandOutput>;
  batchDeleteClusterNodes(
    args: BatchDeleteClusterNodesCommandInput,
    cb: (err: any, data?: BatchDeleteClusterNodesCommandOutput) => void
  ): void;
  batchDeleteClusterNodes(
    args: BatchDeleteClusterNodesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: BatchDeleteClusterNodesCommandOutput) => void
  ): void;
  batchDescribeModelPackage(
    args: BatchDescribeModelPackageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<BatchDescribeModelPackageCommandOutput>;
  batchDescribeModelPackage(
    args: BatchDescribeModelPackageCommandInput,
    cb: (err: any, data?: BatchDescribeModelPackageCommandOutput) => void
  ): void;
  batchDescribeModelPackage(
    args: BatchDescribeModelPackageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: BatchDescribeModelPackageCommandOutput) => void
  ): void;
  batchRebootClusterNodes(
    args: BatchRebootClusterNodesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<BatchRebootClusterNodesCommandOutput>;
  batchRebootClusterNodes(
    args: BatchRebootClusterNodesCommandInput,
    cb: (err: any, data?: BatchRebootClusterNodesCommandOutput) => void
  ): void;
  batchRebootClusterNodes(
    args: BatchRebootClusterNodesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: BatchRebootClusterNodesCommandOutput) => void
  ): void;
  batchReplaceClusterNodes(
    args: BatchReplaceClusterNodesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<BatchReplaceClusterNodesCommandOutput>;
  batchReplaceClusterNodes(
    args: BatchReplaceClusterNodesCommandInput,
    cb: (err: any, data?: BatchReplaceClusterNodesCommandOutput) => void
  ): void;
  batchReplaceClusterNodes(
    args: BatchReplaceClusterNodesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: BatchReplaceClusterNodesCommandOutput) => void
  ): void;
  createAction(
    args: CreateActionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateActionCommandOutput>;
  createAction(
    args: CreateActionCommandInput,
    cb: (err: any, data?: CreateActionCommandOutput) => void
  ): void;
  createAction(
    args: CreateActionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateActionCommandOutput) => void
  ): void;
  createAlgorithm(
    args: CreateAlgorithmCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateAlgorithmCommandOutput>;
  createAlgorithm(
    args: CreateAlgorithmCommandInput,
    cb: (err: any, data?: CreateAlgorithmCommandOutput) => void
  ): void;
  createAlgorithm(
    args: CreateAlgorithmCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateAlgorithmCommandOutput) => void
  ): void;
  createApp(
    args: CreateAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateAppCommandOutput>;
  createApp(
    args: CreateAppCommandInput,
    cb: (err: any, data?: CreateAppCommandOutput) => void
  ): void;
  createApp(
    args: CreateAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateAppCommandOutput) => void
  ): void;
  createAppImageConfig(
    args: CreateAppImageConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateAppImageConfigCommandOutput>;
  createAppImageConfig(
    args: CreateAppImageConfigCommandInput,
    cb: (err: any, data?: CreateAppImageConfigCommandOutput) => void
  ): void;
  createAppImageConfig(
    args: CreateAppImageConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateAppImageConfigCommandOutput) => void
  ): void;
  createArtifact(
    args: CreateArtifactCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateArtifactCommandOutput>;
  createArtifact(
    args: CreateArtifactCommandInput,
    cb: (err: any, data?: CreateArtifactCommandOutput) => void
  ): void;
  createArtifact(
    args: CreateArtifactCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateArtifactCommandOutput) => void
  ): void;
  createAutoMLJob(
    args: CreateAutoMLJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateAutoMLJobCommandOutput>;
  createAutoMLJob(
    args: CreateAutoMLJobCommandInput,
    cb: (err: any, data?: CreateAutoMLJobCommandOutput) => void
  ): void;
  createAutoMLJob(
    args: CreateAutoMLJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateAutoMLJobCommandOutput) => void
  ): void;
  createAutoMLJobV2(
    args: CreateAutoMLJobV2CommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateAutoMLJobV2CommandOutput>;
  createAutoMLJobV2(
    args: CreateAutoMLJobV2CommandInput,
    cb: (err: any, data?: CreateAutoMLJobV2CommandOutput) => void
  ): void;
  createAutoMLJobV2(
    args: CreateAutoMLJobV2CommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateAutoMLJobV2CommandOutput) => void
  ): void;
  createCluster(
    args: CreateClusterCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateClusterCommandOutput>;
  createCluster(
    args: CreateClusterCommandInput,
    cb: (err: any, data?: CreateClusterCommandOutput) => void
  ): void;
  createCluster(
    args: CreateClusterCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateClusterCommandOutput) => void
  ): void;
  createClusterSchedulerConfig(
    args: CreateClusterSchedulerConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateClusterSchedulerConfigCommandOutput>;
  createClusterSchedulerConfig(
    args: CreateClusterSchedulerConfigCommandInput,
    cb: (err: any, data?: CreateClusterSchedulerConfigCommandOutput) => void
  ): void;
  createClusterSchedulerConfig(
    args: CreateClusterSchedulerConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateClusterSchedulerConfigCommandOutput) => void
  ): void;
  createCodeRepository(
    args: CreateCodeRepositoryCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateCodeRepositoryCommandOutput>;
  createCodeRepository(
    args: CreateCodeRepositoryCommandInput,
    cb: (err: any, data?: CreateCodeRepositoryCommandOutput) => void
  ): void;
  createCodeRepository(
    args: CreateCodeRepositoryCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateCodeRepositoryCommandOutput) => void
  ): void;
  createCompilationJob(
    args: CreateCompilationJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateCompilationJobCommandOutput>;
  createCompilationJob(
    args: CreateCompilationJobCommandInput,
    cb: (err: any, data?: CreateCompilationJobCommandOutput) => void
  ): void;
  createCompilationJob(
    args: CreateCompilationJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateCompilationJobCommandOutput) => void
  ): void;
  createComputeQuota(
    args: CreateComputeQuotaCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateComputeQuotaCommandOutput>;
  createComputeQuota(
    args: CreateComputeQuotaCommandInput,
    cb: (err: any, data?: CreateComputeQuotaCommandOutput) => void
  ): void;
  createComputeQuota(
    args: CreateComputeQuotaCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateComputeQuotaCommandOutput) => void
  ): void;
  createContext(
    args: CreateContextCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateContextCommandOutput>;
  createContext(
    args: CreateContextCommandInput,
    cb: (err: any, data?: CreateContextCommandOutput) => void
  ): void;
  createContext(
    args: CreateContextCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateContextCommandOutput) => void
  ): void;
  createDataQualityJobDefinition(
    args: CreateDataQualityJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateDataQualityJobDefinitionCommandOutput>;
  createDataQualityJobDefinition(
    args: CreateDataQualityJobDefinitionCommandInput,
    cb: (err: any, data?: CreateDataQualityJobDefinitionCommandOutput) => void
  ): void;
  createDataQualityJobDefinition(
    args: CreateDataQualityJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateDataQualityJobDefinitionCommandOutput) => void
  ): void;
  createDeviceFleet(
    args: CreateDeviceFleetCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateDeviceFleetCommandOutput>;
  createDeviceFleet(
    args: CreateDeviceFleetCommandInput,
    cb: (err: any, data?: CreateDeviceFleetCommandOutput) => void
  ): void;
  createDeviceFleet(
    args: CreateDeviceFleetCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateDeviceFleetCommandOutput) => void
  ): void;
  createDomain(
    args: CreateDomainCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateDomainCommandOutput>;
  createDomain(
    args: CreateDomainCommandInput,
    cb: (err: any, data?: CreateDomainCommandOutput) => void
  ): void;
  createDomain(
    args: CreateDomainCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateDomainCommandOutput) => void
  ): void;
  createEdgeDeploymentPlan(
    args: CreateEdgeDeploymentPlanCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateEdgeDeploymentPlanCommandOutput>;
  createEdgeDeploymentPlan(
    args: CreateEdgeDeploymentPlanCommandInput,
    cb: (err: any, data?: CreateEdgeDeploymentPlanCommandOutput) => void
  ): void;
  createEdgeDeploymentPlan(
    args: CreateEdgeDeploymentPlanCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateEdgeDeploymentPlanCommandOutput) => void
  ): void;
  createEdgeDeploymentStage(
    args: CreateEdgeDeploymentStageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateEdgeDeploymentStageCommandOutput>;
  createEdgeDeploymentStage(
    args: CreateEdgeDeploymentStageCommandInput,
    cb: (err: any, data?: CreateEdgeDeploymentStageCommandOutput) => void
  ): void;
  createEdgeDeploymentStage(
    args: CreateEdgeDeploymentStageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateEdgeDeploymentStageCommandOutput) => void
  ): void;
  createEdgePackagingJob(
    args: CreateEdgePackagingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateEdgePackagingJobCommandOutput>;
  createEdgePackagingJob(
    args: CreateEdgePackagingJobCommandInput,
    cb: (err: any, data?: CreateEdgePackagingJobCommandOutput) => void
  ): void;
  createEdgePackagingJob(
    args: CreateEdgePackagingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateEdgePackagingJobCommandOutput) => void
  ): void;
  createEndpoint(
    args: CreateEndpointCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateEndpointCommandOutput>;
  createEndpoint(
    args: CreateEndpointCommandInput,
    cb: (err: any, data?: CreateEndpointCommandOutput) => void
  ): void;
  createEndpoint(
    args: CreateEndpointCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateEndpointCommandOutput) => void
  ): void;
  createEndpointConfig(
    args: CreateEndpointConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateEndpointConfigCommandOutput>;
  createEndpointConfig(
    args: CreateEndpointConfigCommandInput,
    cb: (err: any, data?: CreateEndpointConfigCommandOutput) => void
  ): void;
  createEndpointConfig(
    args: CreateEndpointConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateEndpointConfigCommandOutput) => void
  ): void;
  createExperiment(
    args: CreateExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateExperimentCommandOutput>;
  createExperiment(
    args: CreateExperimentCommandInput,
    cb: (err: any, data?: CreateExperimentCommandOutput) => void
  ): void;
  createExperiment(
    args: CreateExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateExperimentCommandOutput) => void
  ): void;
  createFeatureGroup(
    args: CreateFeatureGroupCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateFeatureGroupCommandOutput>;
  createFeatureGroup(
    args: CreateFeatureGroupCommandInput,
    cb: (err: any, data?: CreateFeatureGroupCommandOutput) => void
  ): void;
  createFeatureGroup(
    args: CreateFeatureGroupCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateFeatureGroupCommandOutput) => void
  ): void;
  createFlowDefinition(
    args: CreateFlowDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateFlowDefinitionCommandOutput>;
  createFlowDefinition(
    args: CreateFlowDefinitionCommandInput,
    cb: (err: any, data?: CreateFlowDefinitionCommandOutput) => void
  ): void;
  createFlowDefinition(
    args: CreateFlowDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateFlowDefinitionCommandOutput) => void
  ): void;
  createHub(
    args: CreateHubCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateHubCommandOutput>;
  createHub(
    args: CreateHubCommandInput,
    cb: (err: any, data?: CreateHubCommandOutput) => void
  ): void;
  createHub(
    args: CreateHubCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateHubCommandOutput) => void
  ): void;
  createHubContentPresignedUrls(
    args: CreateHubContentPresignedUrlsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateHubContentPresignedUrlsCommandOutput>;
  createHubContentPresignedUrls(
    args: CreateHubContentPresignedUrlsCommandInput,
    cb: (err: any, data?: CreateHubContentPresignedUrlsCommandOutput) => void
  ): void;
  createHubContentPresignedUrls(
    args: CreateHubContentPresignedUrlsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateHubContentPresignedUrlsCommandOutput) => void
  ): void;
  createHubContentReference(
    args: CreateHubContentReferenceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateHubContentReferenceCommandOutput>;
  createHubContentReference(
    args: CreateHubContentReferenceCommandInput,
    cb: (err: any, data?: CreateHubContentReferenceCommandOutput) => void
  ): void;
  createHubContentReference(
    args: CreateHubContentReferenceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateHubContentReferenceCommandOutput) => void
  ): void;
  createHumanTaskUi(
    args: CreateHumanTaskUiCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateHumanTaskUiCommandOutput>;
  createHumanTaskUi(
    args: CreateHumanTaskUiCommandInput,
    cb: (err: any, data?: CreateHumanTaskUiCommandOutput) => void
  ): void;
  createHumanTaskUi(
    args: CreateHumanTaskUiCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateHumanTaskUiCommandOutput) => void
  ): void;
  createHyperParameterTuningJob(
    args: CreateHyperParameterTuningJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateHyperParameterTuningJobCommandOutput>;
  createHyperParameterTuningJob(
    args: CreateHyperParameterTuningJobCommandInput,
    cb: (err: any, data?: CreateHyperParameterTuningJobCommandOutput) => void
  ): void;
  createHyperParameterTuningJob(
    args: CreateHyperParameterTuningJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateHyperParameterTuningJobCommandOutput) => void
  ): void;
  createImage(
    args: CreateImageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateImageCommandOutput>;
  createImage(
    args: CreateImageCommandInput,
    cb: (err: any, data?: CreateImageCommandOutput) => void
  ): void;
  createImage(
    args: CreateImageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateImageCommandOutput) => void
  ): void;
  createImageVersion(
    args: CreateImageVersionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateImageVersionCommandOutput>;
  createImageVersion(
    args: CreateImageVersionCommandInput,
    cb: (err: any, data?: CreateImageVersionCommandOutput) => void
  ): void;
  createImageVersion(
    args: CreateImageVersionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateImageVersionCommandOutput) => void
  ): void;
  createInferenceComponent(
    args: CreateInferenceComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateInferenceComponentCommandOutput>;
  createInferenceComponent(
    args: CreateInferenceComponentCommandInput,
    cb: (err: any, data?: CreateInferenceComponentCommandOutput) => void
  ): void;
  createInferenceComponent(
    args: CreateInferenceComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateInferenceComponentCommandOutput) => void
  ): void;
  createInferenceExperiment(
    args: CreateInferenceExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateInferenceExperimentCommandOutput>;
  createInferenceExperiment(
    args: CreateInferenceExperimentCommandInput,
    cb: (err: any, data?: CreateInferenceExperimentCommandOutput) => void
  ): void;
  createInferenceExperiment(
    args: CreateInferenceExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateInferenceExperimentCommandOutput) => void
  ): void;
  createInferenceRecommendationsJob(
    args: CreateInferenceRecommendationsJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateInferenceRecommendationsJobCommandOutput>;
  createInferenceRecommendationsJob(
    args: CreateInferenceRecommendationsJobCommandInput,
    cb: (
      err: any,
      data?: CreateInferenceRecommendationsJobCommandOutput
    ) => void
  ): void;
  createInferenceRecommendationsJob(
    args: CreateInferenceRecommendationsJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: CreateInferenceRecommendationsJobCommandOutput
    ) => void
  ): void;
  createLabelingJob(
    args: CreateLabelingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateLabelingJobCommandOutput>;
  createLabelingJob(
    args: CreateLabelingJobCommandInput,
    cb: (err: any, data?: CreateLabelingJobCommandOutput) => void
  ): void;
  createLabelingJob(
    args: CreateLabelingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateLabelingJobCommandOutput) => void
  ): void;
  createMlflowApp(
    args: CreateMlflowAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateMlflowAppCommandOutput>;
  createMlflowApp(
    args: CreateMlflowAppCommandInput,
    cb: (err: any, data?: CreateMlflowAppCommandOutput) => void
  ): void;
  createMlflowApp(
    args: CreateMlflowAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateMlflowAppCommandOutput) => void
  ): void;
  createMlflowTrackingServer(
    args: CreateMlflowTrackingServerCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateMlflowTrackingServerCommandOutput>;
  createMlflowTrackingServer(
    args: CreateMlflowTrackingServerCommandInput,
    cb: (err: any, data?: CreateMlflowTrackingServerCommandOutput) => void
  ): void;
  createMlflowTrackingServer(
    args: CreateMlflowTrackingServerCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateMlflowTrackingServerCommandOutput) => void
  ): void;
  createModel(
    args: CreateModelCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateModelCommandOutput>;
  createModel(
    args: CreateModelCommandInput,
    cb: (err: any, data?: CreateModelCommandOutput) => void
  ): void;
  createModel(
    args: CreateModelCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateModelCommandOutput) => void
  ): void;
  createModelBiasJobDefinition(
    args: CreateModelBiasJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateModelBiasJobDefinitionCommandOutput>;
  createModelBiasJobDefinition(
    args: CreateModelBiasJobDefinitionCommandInput,
    cb: (err: any, data?: CreateModelBiasJobDefinitionCommandOutput) => void
  ): void;
  createModelBiasJobDefinition(
    args: CreateModelBiasJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateModelBiasJobDefinitionCommandOutput) => void
  ): void;
  createModelCard(
    args: CreateModelCardCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateModelCardCommandOutput>;
  createModelCard(
    args: CreateModelCardCommandInput,
    cb: (err: any, data?: CreateModelCardCommandOutput) => void
  ): void;
  createModelCard(
    args: CreateModelCardCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateModelCardCommandOutput) => void
  ): void;
  createModelCardExportJob(
    args: CreateModelCardExportJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateModelCardExportJobCommandOutput>;
  createModelCardExportJob(
    args: CreateModelCardExportJobCommandInput,
    cb: (err: any, data?: CreateModelCardExportJobCommandOutput) => void
  ): void;
  createModelCardExportJob(
    args: CreateModelCardExportJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateModelCardExportJobCommandOutput) => void
  ): void;
  createModelExplainabilityJobDefinition(
    args: CreateModelExplainabilityJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateModelExplainabilityJobDefinitionCommandOutput>;
  createModelExplainabilityJobDefinition(
    args: CreateModelExplainabilityJobDefinitionCommandInput,
    cb: (
      err: any,
      data?: CreateModelExplainabilityJobDefinitionCommandOutput
    ) => void
  ): void;
  createModelExplainabilityJobDefinition(
    args: CreateModelExplainabilityJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: CreateModelExplainabilityJobDefinitionCommandOutput
    ) => void
  ): void;
  createModelPackage(): Promise<CreateModelPackageCommandOutput>;
  createModelPackage(
    args: CreateModelPackageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateModelPackageCommandOutput>;
  createModelPackage(
    args: CreateModelPackageCommandInput,
    cb: (err: any, data?: CreateModelPackageCommandOutput) => void
  ): void;
  createModelPackage(
    args: CreateModelPackageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateModelPackageCommandOutput) => void
  ): void;
  createModelPackageGroup(
    args: CreateModelPackageGroupCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateModelPackageGroupCommandOutput>;
  createModelPackageGroup(
    args: CreateModelPackageGroupCommandInput,
    cb: (err: any, data?: CreateModelPackageGroupCommandOutput) => void
  ): void;
  createModelPackageGroup(
    args: CreateModelPackageGroupCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateModelPackageGroupCommandOutput) => void
  ): void;
  createModelQualityJobDefinition(
    args: CreateModelQualityJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateModelQualityJobDefinitionCommandOutput>;
  createModelQualityJobDefinition(
    args: CreateModelQualityJobDefinitionCommandInput,
    cb: (err: any, data?: CreateModelQualityJobDefinitionCommandOutput) => void
  ): void;
  createModelQualityJobDefinition(
    args: CreateModelQualityJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateModelQualityJobDefinitionCommandOutput) => void
  ): void;
  createMonitoringSchedule(
    args: CreateMonitoringScheduleCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateMonitoringScheduleCommandOutput>;
  createMonitoringSchedule(
    args: CreateMonitoringScheduleCommandInput,
    cb: (err: any, data?: CreateMonitoringScheduleCommandOutput) => void
  ): void;
  createMonitoringSchedule(
    args: CreateMonitoringScheduleCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateMonitoringScheduleCommandOutput) => void
  ): void;
  createNotebookInstance(
    args: CreateNotebookInstanceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateNotebookInstanceCommandOutput>;
  createNotebookInstance(
    args: CreateNotebookInstanceCommandInput,
    cb: (err: any, data?: CreateNotebookInstanceCommandOutput) => void
  ): void;
  createNotebookInstance(
    args: CreateNotebookInstanceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateNotebookInstanceCommandOutput) => void
  ): void;
  createNotebookInstanceLifecycleConfig(
    args: CreateNotebookInstanceLifecycleConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateNotebookInstanceLifecycleConfigCommandOutput>;
  createNotebookInstanceLifecycleConfig(
    args: CreateNotebookInstanceLifecycleConfigCommandInput,
    cb: (
      err: any,
      data?: CreateNotebookInstanceLifecycleConfigCommandOutput
    ) => void
  ): void;
  createNotebookInstanceLifecycleConfig(
    args: CreateNotebookInstanceLifecycleConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: CreateNotebookInstanceLifecycleConfigCommandOutput
    ) => void
  ): void;
  createOptimizationJob(
    args: CreateOptimizationJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateOptimizationJobCommandOutput>;
  createOptimizationJob(
    args: CreateOptimizationJobCommandInput,
    cb: (err: any, data?: CreateOptimizationJobCommandOutput) => void
  ): void;
  createOptimizationJob(
    args: CreateOptimizationJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateOptimizationJobCommandOutput) => void
  ): void;
  createPartnerApp(
    args: CreatePartnerAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreatePartnerAppCommandOutput>;
  createPartnerApp(
    args: CreatePartnerAppCommandInput,
    cb: (err: any, data?: CreatePartnerAppCommandOutput) => void
  ): void;
  createPartnerApp(
    args: CreatePartnerAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreatePartnerAppCommandOutput) => void
  ): void;
  createPartnerAppPresignedUrl(
    args: CreatePartnerAppPresignedUrlCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreatePartnerAppPresignedUrlCommandOutput>;
  createPartnerAppPresignedUrl(
    args: CreatePartnerAppPresignedUrlCommandInput,
    cb: (err: any, data?: CreatePartnerAppPresignedUrlCommandOutput) => void
  ): void;
  createPartnerAppPresignedUrl(
    args: CreatePartnerAppPresignedUrlCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreatePartnerAppPresignedUrlCommandOutput) => void
  ): void;
  createPipeline(
    args: CreatePipelineCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreatePipelineCommandOutput>;
  createPipeline(
    args: CreatePipelineCommandInput,
    cb: (err: any, data?: CreatePipelineCommandOutput) => void
  ): void;
  createPipeline(
    args: CreatePipelineCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreatePipelineCommandOutput) => void
  ): void;
  createPresignedDomainUrl(
    args: CreatePresignedDomainUrlCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreatePresignedDomainUrlCommandOutput>;
  createPresignedDomainUrl(
    args: CreatePresignedDomainUrlCommandInput,
    cb: (err: any, data?: CreatePresignedDomainUrlCommandOutput) => void
  ): void;
  createPresignedDomainUrl(
    args: CreatePresignedDomainUrlCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreatePresignedDomainUrlCommandOutput) => void
  ): void;
  createPresignedMlflowAppUrl(
    args: CreatePresignedMlflowAppUrlCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreatePresignedMlflowAppUrlCommandOutput>;
  createPresignedMlflowAppUrl(
    args: CreatePresignedMlflowAppUrlCommandInput,
    cb: (err: any, data?: CreatePresignedMlflowAppUrlCommandOutput) => void
  ): void;
  createPresignedMlflowAppUrl(
    args: CreatePresignedMlflowAppUrlCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreatePresignedMlflowAppUrlCommandOutput) => void
  ): void;
  createPresignedMlflowTrackingServerUrl(
    args: CreatePresignedMlflowTrackingServerUrlCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreatePresignedMlflowTrackingServerUrlCommandOutput>;
  createPresignedMlflowTrackingServerUrl(
    args: CreatePresignedMlflowTrackingServerUrlCommandInput,
    cb: (
      err: any,
      data?: CreatePresignedMlflowTrackingServerUrlCommandOutput
    ) => void
  ): void;
  createPresignedMlflowTrackingServerUrl(
    args: CreatePresignedMlflowTrackingServerUrlCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: CreatePresignedMlflowTrackingServerUrlCommandOutput
    ) => void
  ): void;
  createPresignedNotebookInstanceUrl(
    args: CreatePresignedNotebookInstanceUrlCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreatePresignedNotebookInstanceUrlCommandOutput>;
  createPresignedNotebookInstanceUrl(
    args: CreatePresignedNotebookInstanceUrlCommandInput,
    cb: (
      err: any,
      data?: CreatePresignedNotebookInstanceUrlCommandOutput
    ) => void
  ): void;
  createPresignedNotebookInstanceUrl(
    args: CreatePresignedNotebookInstanceUrlCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: CreatePresignedNotebookInstanceUrlCommandOutput
    ) => void
  ): void;
  createProcessingJob(
    args: CreateProcessingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateProcessingJobCommandOutput>;
  createProcessingJob(
    args: CreateProcessingJobCommandInput,
    cb: (err: any, data?: CreateProcessingJobCommandOutput) => void
  ): void;
  createProcessingJob(
    args: CreateProcessingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateProcessingJobCommandOutput) => void
  ): void;
  createProject(
    args: CreateProjectCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateProjectCommandOutput>;
  createProject(
    args: CreateProjectCommandInput,
    cb: (err: any, data?: CreateProjectCommandOutput) => void
  ): void;
  createProject(
    args: CreateProjectCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateProjectCommandOutput) => void
  ): void;
  createSpace(
    args: CreateSpaceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateSpaceCommandOutput>;
  createSpace(
    args: CreateSpaceCommandInput,
    cb: (err: any, data?: CreateSpaceCommandOutput) => void
  ): void;
  createSpace(
    args: CreateSpaceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateSpaceCommandOutput) => void
  ): void;
  createStudioLifecycleConfig(
    args: CreateStudioLifecycleConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateStudioLifecycleConfigCommandOutput>;
  createStudioLifecycleConfig(
    args: CreateStudioLifecycleConfigCommandInput,
    cb: (err: any, data?: CreateStudioLifecycleConfigCommandOutput) => void
  ): void;
  createStudioLifecycleConfig(
    args: CreateStudioLifecycleConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateStudioLifecycleConfigCommandOutput) => void
  ): void;
  createTrainingJob(
    args: CreateTrainingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateTrainingJobCommandOutput>;
  createTrainingJob(
    args: CreateTrainingJobCommandInput,
    cb: (err: any, data?: CreateTrainingJobCommandOutput) => void
  ): void;
  createTrainingJob(
    args: CreateTrainingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateTrainingJobCommandOutput) => void
  ): void;
  createTrainingPlan(
    args: CreateTrainingPlanCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateTrainingPlanCommandOutput>;
  createTrainingPlan(
    args: CreateTrainingPlanCommandInput,
    cb: (err: any, data?: CreateTrainingPlanCommandOutput) => void
  ): void;
  createTrainingPlan(
    args: CreateTrainingPlanCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateTrainingPlanCommandOutput) => void
  ): void;
  createTransformJob(
    args: CreateTransformJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateTransformJobCommandOutput>;
  createTransformJob(
    args: CreateTransformJobCommandInput,
    cb: (err: any, data?: CreateTransformJobCommandOutput) => void
  ): void;
  createTransformJob(
    args: CreateTransformJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateTransformJobCommandOutput) => void
  ): void;
  createTrial(
    args: CreateTrialCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateTrialCommandOutput>;
  createTrial(
    args: CreateTrialCommandInput,
    cb: (err: any, data?: CreateTrialCommandOutput) => void
  ): void;
  createTrial(
    args: CreateTrialCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateTrialCommandOutput) => void
  ): void;
  createTrialComponent(
    args: CreateTrialComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateTrialComponentCommandOutput>;
  createTrialComponent(
    args: CreateTrialComponentCommandInput,
    cb: (err: any, data?: CreateTrialComponentCommandOutput) => void
  ): void;
  createTrialComponent(
    args: CreateTrialComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateTrialComponentCommandOutput) => void
  ): void;
  createUserProfile(
    args: CreateUserProfileCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateUserProfileCommandOutput>;
  createUserProfile(
    args: CreateUserProfileCommandInput,
    cb: (err: any, data?: CreateUserProfileCommandOutput) => void
  ): void;
  createUserProfile(
    args: CreateUserProfileCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateUserProfileCommandOutput) => void
  ): void;
  createWorkforce(
    args: CreateWorkforceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateWorkforceCommandOutput>;
  createWorkforce(
    args: CreateWorkforceCommandInput,
    cb: (err: any, data?: CreateWorkforceCommandOutput) => void
  ): void;
  createWorkforce(
    args: CreateWorkforceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateWorkforceCommandOutput) => void
  ): void;
  createWorkteam(
    args: CreateWorkteamCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<CreateWorkteamCommandOutput>;
  createWorkteam(
    args: CreateWorkteamCommandInput,
    cb: (err: any, data?: CreateWorkteamCommandOutput) => void
  ): void;
  createWorkteam(
    args: CreateWorkteamCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: CreateWorkteamCommandOutput) => void
  ): void;
  deleteAction(
    args: DeleteActionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteActionCommandOutput>;
  deleteAction(
    args: DeleteActionCommandInput,
    cb: (err: any, data?: DeleteActionCommandOutput) => void
  ): void;
  deleteAction(
    args: DeleteActionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteActionCommandOutput) => void
  ): void;
  deleteAlgorithm(
    args: DeleteAlgorithmCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteAlgorithmCommandOutput>;
  deleteAlgorithm(
    args: DeleteAlgorithmCommandInput,
    cb: (err: any, data?: DeleteAlgorithmCommandOutput) => void
  ): void;
  deleteAlgorithm(
    args: DeleteAlgorithmCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteAlgorithmCommandOutput) => void
  ): void;
  deleteApp(
    args: DeleteAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteAppCommandOutput>;
  deleteApp(
    args: DeleteAppCommandInput,
    cb: (err: any, data?: DeleteAppCommandOutput) => void
  ): void;
  deleteApp(
    args: DeleteAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteAppCommandOutput) => void
  ): void;
  deleteAppImageConfig(
    args: DeleteAppImageConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteAppImageConfigCommandOutput>;
  deleteAppImageConfig(
    args: DeleteAppImageConfigCommandInput,
    cb: (err: any, data?: DeleteAppImageConfigCommandOutput) => void
  ): void;
  deleteAppImageConfig(
    args: DeleteAppImageConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteAppImageConfigCommandOutput) => void
  ): void;
  deleteArtifact(): Promise<DeleteArtifactCommandOutput>;
  deleteArtifact(
    args: DeleteArtifactCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteArtifactCommandOutput>;
  deleteArtifact(
    args: DeleteArtifactCommandInput,
    cb: (err: any, data?: DeleteArtifactCommandOutput) => void
  ): void;
  deleteArtifact(
    args: DeleteArtifactCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteArtifactCommandOutput) => void
  ): void;
  deleteAssociation(
    args: DeleteAssociationCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteAssociationCommandOutput>;
  deleteAssociation(
    args: DeleteAssociationCommandInput,
    cb: (err: any, data?: DeleteAssociationCommandOutput) => void
  ): void;
  deleteAssociation(
    args: DeleteAssociationCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteAssociationCommandOutput) => void
  ): void;
  deleteCluster(
    args: DeleteClusterCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteClusterCommandOutput>;
  deleteCluster(
    args: DeleteClusterCommandInput,
    cb: (err: any, data?: DeleteClusterCommandOutput) => void
  ): void;
  deleteCluster(
    args: DeleteClusterCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteClusterCommandOutput) => void
  ): void;
  deleteClusterSchedulerConfig(
    args: DeleteClusterSchedulerConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteClusterSchedulerConfigCommandOutput>;
  deleteClusterSchedulerConfig(
    args: DeleteClusterSchedulerConfigCommandInput,
    cb: (err: any, data?: DeleteClusterSchedulerConfigCommandOutput) => void
  ): void;
  deleteClusterSchedulerConfig(
    args: DeleteClusterSchedulerConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteClusterSchedulerConfigCommandOutput) => void
  ): void;
  deleteCodeRepository(
    args: DeleteCodeRepositoryCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteCodeRepositoryCommandOutput>;
  deleteCodeRepository(
    args: DeleteCodeRepositoryCommandInput,
    cb: (err: any, data?: DeleteCodeRepositoryCommandOutput) => void
  ): void;
  deleteCodeRepository(
    args: DeleteCodeRepositoryCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteCodeRepositoryCommandOutput) => void
  ): void;
  deleteCompilationJob(
    args: DeleteCompilationJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteCompilationJobCommandOutput>;
  deleteCompilationJob(
    args: DeleteCompilationJobCommandInput,
    cb: (err: any, data?: DeleteCompilationJobCommandOutput) => void
  ): void;
  deleteCompilationJob(
    args: DeleteCompilationJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteCompilationJobCommandOutput) => void
  ): void;
  deleteComputeQuota(
    args: DeleteComputeQuotaCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteComputeQuotaCommandOutput>;
  deleteComputeQuota(
    args: DeleteComputeQuotaCommandInput,
    cb: (err: any, data?: DeleteComputeQuotaCommandOutput) => void
  ): void;
  deleteComputeQuota(
    args: DeleteComputeQuotaCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteComputeQuotaCommandOutput) => void
  ): void;
  deleteContext(
    args: DeleteContextCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteContextCommandOutput>;
  deleteContext(
    args: DeleteContextCommandInput,
    cb: (err: any, data?: DeleteContextCommandOutput) => void
  ): void;
  deleteContext(
    args: DeleteContextCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteContextCommandOutput) => void
  ): void;
  deleteDataQualityJobDefinition(
    args: DeleteDataQualityJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteDataQualityJobDefinitionCommandOutput>;
  deleteDataQualityJobDefinition(
    args: DeleteDataQualityJobDefinitionCommandInput,
    cb: (err: any, data?: DeleteDataQualityJobDefinitionCommandOutput) => void
  ): void;
  deleteDataQualityJobDefinition(
    args: DeleteDataQualityJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteDataQualityJobDefinitionCommandOutput) => void
  ): void;
  deleteDeviceFleet(
    args: DeleteDeviceFleetCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteDeviceFleetCommandOutput>;
  deleteDeviceFleet(
    args: DeleteDeviceFleetCommandInput,
    cb: (err: any, data?: DeleteDeviceFleetCommandOutput) => void
  ): void;
  deleteDeviceFleet(
    args: DeleteDeviceFleetCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteDeviceFleetCommandOutput) => void
  ): void;
  deleteDomain(
    args: DeleteDomainCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteDomainCommandOutput>;
  deleteDomain(
    args: DeleteDomainCommandInput,
    cb: (err: any, data?: DeleteDomainCommandOutput) => void
  ): void;
  deleteDomain(
    args: DeleteDomainCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteDomainCommandOutput) => void
  ): void;
  deleteEdgeDeploymentPlan(
    args: DeleteEdgeDeploymentPlanCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteEdgeDeploymentPlanCommandOutput>;
  deleteEdgeDeploymentPlan(
    args: DeleteEdgeDeploymentPlanCommandInput,
    cb: (err: any, data?: DeleteEdgeDeploymentPlanCommandOutput) => void
  ): void;
  deleteEdgeDeploymentPlan(
    args: DeleteEdgeDeploymentPlanCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteEdgeDeploymentPlanCommandOutput) => void
  ): void;
  deleteEdgeDeploymentStage(
    args: DeleteEdgeDeploymentStageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteEdgeDeploymentStageCommandOutput>;
  deleteEdgeDeploymentStage(
    args: DeleteEdgeDeploymentStageCommandInput,
    cb: (err: any, data?: DeleteEdgeDeploymentStageCommandOutput) => void
  ): void;
  deleteEdgeDeploymentStage(
    args: DeleteEdgeDeploymentStageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteEdgeDeploymentStageCommandOutput) => void
  ): void;
  deleteEndpoint(
    args: DeleteEndpointCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteEndpointCommandOutput>;
  deleteEndpoint(
    args: DeleteEndpointCommandInput,
    cb: (err: any, data?: DeleteEndpointCommandOutput) => void
  ): void;
  deleteEndpoint(
    args: DeleteEndpointCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteEndpointCommandOutput) => void
  ): void;
  deleteEndpointConfig(
    args: DeleteEndpointConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteEndpointConfigCommandOutput>;
  deleteEndpointConfig(
    args: DeleteEndpointConfigCommandInput,
    cb: (err: any, data?: DeleteEndpointConfigCommandOutput) => void
  ): void;
  deleteEndpointConfig(
    args: DeleteEndpointConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteEndpointConfigCommandOutput) => void
  ): void;
  deleteExperiment(
    args: DeleteExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteExperimentCommandOutput>;
  deleteExperiment(
    args: DeleteExperimentCommandInput,
    cb: (err: any, data?: DeleteExperimentCommandOutput) => void
  ): void;
  deleteExperiment(
    args: DeleteExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteExperimentCommandOutput) => void
  ): void;
  deleteFeatureGroup(
    args: DeleteFeatureGroupCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteFeatureGroupCommandOutput>;
  deleteFeatureGroup(
    args: DeleteFeatureGroupCommandInput,
    cb: (err: any, data?: DeleteFeatureGroupCommandOutput) => void
  ): void;
  deleteFeatureGroup(
    args: DeleteFeatureGroupCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteFeatureGroupCommandOutput) => void
  ): void;
  deleteFlowDefinition(
    args: DeleteFlowDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteFlowDefinitionCommandOutput>;
  deleteFlowDefinition(
    args: DeleteFlowDefinitionCommandInput,
    cb: (err: any, data?: DeleteFlowDefinitionCommandOutput) => void
  ): void;
  deleteFlowDefinition(
    args: DeleteFlowDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteFlowDefinitionCommandOutput) => void
  ): void;
  deleteHub(
    args: DeleteHubCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteHubCommandOutput>;
  deleteHub(
    args: DeleteHubCommandInput,
    cb: (err: any, data?: DeleteHubCommandOutput) => void
  ): void;
  deleteHub(
    args: DeleteHubCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteHubCommandOutput) => void
  ): void;
  deleteHubContent(
    args: DeleteHubContentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteHubContentCommandOutput>;
  deleteHubContent(
    args: DeleteHubContentCommandInput,
    cb: (err: any, data?: DeleteHubContentCommandOutput) => void
  ): void;
  deleteHubContent(
    args: DeleteHubContentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteHubContentCommandOutput) => void
  ): void;
  deleteHubContentReference(
    args: DeleteHubContentReferenceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteHubContentReferenceCommandOutput>;
  deleteHubContentReference(
    args: DeleteHubContentReferenceCommandInput,
    cb: (err: any, data?: DeleteHubContentReferenceCommandOutput) => void
  ): void;
  deleteHubContentReference(
    args: DeleteHubContentReferenceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteHubContentReferenceCommandOutput) => void
  ): void;
  deleteHumanTaskUi(
    args: DeleteHumanTaskUiCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteHumanTaskUiCommandOutput>;
  deleteHumanTaskUi(
    args: DeleteHumanTaskUiCommandInput,
    cb: (err: any, data?: DeleteHumanTaskUiCommandOutput) => void
  ): void;
  deleteHumanTaskUi(
    args: DeleteHumanTaskUiCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteHumanTaskUiCommandOutput) => void
  ): void;
  deleteHyperParameterTuningJob(
    args: DeleteHyperParameterTuningJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteHyperParameterTuningJobCommandOutput>;
  deleteHyperParameterTuningJob(
    args: DeleteHyperParameterTuningJobCommandInput,
    cb: (err: any, data?: DeleteHyperParameterTuningJobCommandOutput) => void
  ): void;
  deleteHyperParameterTuningJob(
    args: DeleteHyperParameterTuningJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteHyperParameterTuningJobCommandOutput) => void
  ): void;
  deleteImage(
    args: DeleteImageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteImageCommandOutput>;
  deleteImage(
    args: DeleteImageCommandInput,
    cb: (err: any, data?: DeleteImageCommandOutput) => void
  ): void;
  deleteImage(
    args: DeleteImageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteImageCommandOutput) => void
  ): void;
  deleteImageVersion(
    args: DeleteImageVersionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteImageVersionCommandOutput>;
  deleteImageVersion(
    args: DeleteImageVersionCommandInput,
    cb: (err: any, data?: DeleteImageVersionCommandOutput) => void
  ): void;
  deleteImageVersion(
    args: DeleteImageVersionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteImageVersionCommandOutput) => void
  ): void;
  deleteInferenceComponent(
    args: DeleteInferenceComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteInferenceComponentCommandOutput>;
  deleteInferenceComponent(
    args: DeleteInferenceComponentCommandInput,
    cb: (err: any, data?: DeleteInferenceComponentCommandOutput) => void
  ): void;
  deleteInferenceComponent(
    args: DeleteInferenceComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteInferenceComponentCommandOutput) => void
  ): void;
  deleteInferenceExperiment(
    args: DeleteInferenceExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteInferenceExperimentCommandOutput>;
  deleteInferenceExperiment(
    args: DeleteInferenceExperimentCommandInput,
    cb: (err: any, data?: DeleteInferenceExperimentCommandOutput) => void
  ): void;
  deleteInferenceExperiment(
    args: DeleteInferenceExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteInferenceExperimentCommandOutput) => void
  ): void;
  deleteMlflowApp(
    args: DeleteMlflowAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteMlflowAppCommandOutput>;
  deleteMlflowApp(
    args: DeleteMlflowAppCommandInput,
    cb: (err: any, data?: DeleteMlflowAppCommandOutput) => void
  ): void;
  deleteMlflowApp(
    args: DeleteMlflowAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteMlflowAppCommandOutput) => void
  ): void;
  deleteMlflowTrackingServer(
    args: DeleteMlflowTrackingServerCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteMlflowTrackingServerCommandOutput>;
  deleteMlflowTrackingServer(
    args: DeleteMlflowTrackingServerCommandInput,
    cb: (err: any, data?: DeleteMlflowTrackingServerCommandOutput) => void
  ): void;
  deleteMlflowTrackingServer(
    args: DeleteMlflowTrackingServerCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteMlflowTrackingServerCommandOutput) => void
  ): void;
  deleteModel(
    args: DeleteModelCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteModelCommandOutput>;
  deleteModel(
    args: DeleteModelCommandInput,
    cb: (err: any, data?: DeleteModelCommandOutput) => void
  ): void;
  deleteModel(
    args: DeleteModelCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteModelCommandOutput) => void
  ): void;
  deleteModelBiasJobDefinition(
    args: DeleteModelBiasJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteModelBiasJobDefinitionCommandOutput>;
  deleteModelBiasJobDefinition(
    args: DeleteModelBiasJobDefinitionCommandInput,
    cb: (err: any, data?: DeleteModelBiasJobDefinitionCommandOutput) => void
  ): void;
  deleteModelBiasJobDefinition(
    args: DeleteModelBiasJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteModelBiasJobDefinitionCommandOutput) => void
  ): void;
  deleteModelCard(
    args: DeleteModelCardCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteModelCardCommandOutput>;
  deleteModelCard(
    args: DeleteModelCardCommandInput,
    cb: (err: any, data?: DeleteModelCardCommandOutput) => void
  ): void;
  deleteModelCard(
    args: DeleteModelCardCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteModelCardCommandOutput) => void
  ): void;
  deleteModelExplainabilityJobDefinition(
    args: DeleteModelExplainabilityJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteModelExplainabilityJobDefinitionCommandOutput>;
  deleteModelExplainabilityJobDefinition(
    args: DeleteModelExplainabilityJobDefinitionCommandInput,
    cb: (
      err: any,
      data?: DeleteModelExplainabilityJobDefinitionCommandOutput
    ) => void
  ): void;
  deleteModelExplainabilityJobDefinition(
    args: DeleteModelExplainabilityJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: DeleteModelExplainabilityJobDefinitionCommandOutput
    ) => void
  ): void;
  deleteModelPackage(
    args: DeleteModelPackageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteModelPackageCommandOutput>;
  deleteModelPackage(
    args: DeleteModelPackageCommandInput,
    cb: (err: any, data?: DeleteModelPackageCommandOutput) => void
  ): void;
  deleteModelPackage(
    args: DeleteModelPackageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteModelPackageCommandOutput) => void
  ): void;
  deleteModelPackageGroup(
    args: DeleteModelPackageGroupCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteModelPackageGroupCommandOutput>;
  deleteModelPackageGroup(
    args: DeleteModelPackageGroupCommandInput,
    cb: (err: any, data?: DeleteModelPackageGroupCommandOutput) => void
  ): void;
  deleteModelPackageGroup(
    args: DeleteModelPackageGroupCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteModelPackageGroupCommandOutput) => void
  ): void;
  deleteModelPackageGroupPolicy(
    args: DeleteModelPackageGroupPolicyCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteModelPackageGroupPolicyCommandOutput>;
  deleteModelPackageGroupPolicy(
    args: DeleteModelPackageGroupPolicyCommandInput,
    cb: (err: any, data?: DeleteModelPackageGroupPolicyCommandOutput) => void
  ): void;
  deleteModelPackageGroupPolicy(
    args: DeleteModelPackageGroupPolicyCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteModelPackageGroupPolicyCommandOutput) => void
  ): void;
  deleteModelQualityJobDefinition(
    args: DeleteModelQualityJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteModelQualityJobDefinitionCommandOutput>;
  deleteModelQualityJobDefinition(
    args: DeleteModelQualityJobDefinitionCommandInput,
    cb: (err: any, data?: DeleteModelQualityJobDefinitionCommandOutput) => void
  ): void;
  deleteModelQualityJobDefinition(
    args: DeleteModelQualityJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteModelQualityJobDefinitionCommandOutput) => void
  ): void;
  deleteMonitoringSchedule(
    args: DeleteMonitoringScheduleCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteMonitoringScheduleCommandOutput>;
  deleteMonitoringSchedule(
    args: DeleteMonitoringScheduleCommandInput,
    cb: (err: any, data?: DeleteMonitoringScheduleCommandOutput) => void
  ): void;
  deleteMonitoringSchedule(
    args: DeleteMonitoringScheduleCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteMonitoringScheduleCommandOutput) => void
  ): void;
  deleteNotebookInstance(
    args: DeleteNotebookInstanceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteNotebookInstanceCommandOutput>;
  deleteNotebookInstance(
    args: DeleteNotebookInstanceCommandInput,
    cb: (err: any, data?: DeleteNotebookInstanceCommandOutput) => void
  ): void;
  deleteNotebookInstance(
    args: DeleteNotebookInstanceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteNotebookInstanceCommandOutput) => void
  ): void;
  deleteNotebookInstanceLifecycleConfig(
    args: DeleteNotebookInstanceLifecycleConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteNotebookInstanceLifecycleConfigCommandOutput>;
  deleteNotebookInstanceLifecycleConfig(
    args: DeleteNotebookInstanceLifecycleConfigCommandInput,
    cb: (
      err: any,
      data?: DeleteNotebookInstanceLifecycleConfigCommandOutput
    ) => void
  ): void;
  deleteNotebookInstanceLifecycleConfig(
    args: DeleteNotebookInstanceLifecycleConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: DeleteNotebookInstanceLifecycleConfigCommandOutput
    ) => void
  ): void;
  deleteOptimizationJob(
    args: DeleteOptimizationJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteOptimizationJobCommandOutput>;
  deleteOptimizationJob(
    args: DeleteOptimizationJobCommandInput,
    cb: (err: any, data?: DeleteOptimizationJobCommandOutput) => void
  ): void;
  deleteOptimizationJob(
    args: DeleteOptimizationJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteOptimizationJobCommandOutput) => void
  ): void;
  deletePartnerApp(
    args: DeletePartnerAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeletePartnerAppCommandOutput>;
  deletePartnerApp(
    args: DeletePartnerAppCommandInput,
    cb: (err: any, data?: DeletePartnerAppCommandOutput) => void
  ): void;
  deletePartnerApp(
    args: DeletePartnerAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeletePartnerAppCommandOutput) => void
  ): void;
  deletePipeline(
    args: DeletePipelineCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeletePipelineCommandOutput>;
  deletePipeline(
    args: DeletePipelineCommandInput,
    cb: (err: any, data?: DeletePipelineCommandOutput) => void
  ): void;
  deletePipeline(
    args: DeletePipelineCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeletePipelineCommandOutput) => void
  ): void;
  deleteProcessingJob(
    args: DeleteProcessingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteProcessingJobCommandOutput>;
  deleteProcessingJob(
    args: DeleteProcessingJobCommandInput,
    cb: (err: any, data?: DeleteProcessingJobCommandOutput) => void
  ): void;
  deleteProcessingJob(
    args: DeleteProcessingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteProcessingJobCommandOutput) => void
  ): void;
  deleteProject(
    args: DeleteProjectCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteProjectCommandOutput>;
  deleteProject(
    args: DeleteProjectCommandInput,
    cb: (err: any, data?: DeleteProjectCommandOutput) => void
  ): void;
  deleteProject(
    args: DeleteProjectCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteProjectCommandOutput) => void
  ): void;
  deleteSpace(
    args: DeleteSpaceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteSpaceCommandOutput>;
  deleteSpace(
    args: DeleteSpaceCommandInput,
    cb: (err: any, data?: DeleteSpaceCommandOutput) => void
  ): void;
  deleteSpace(
    args: DeleteSpaceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteSpaceCommandOutput) => void
  ): void;
  deleteStudioLifecycleConfig(
    args: DeleteStudioLifecycleConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteStudioLifecycleConfigCommandOutput>;
  deleteStudioLifecycleConfig(
    args: DeleteStudioLifecycleConfigCommandInput,
    cb: (err: any, data?: DeleteStudioLifecycleConfigCommandOutput) => void
  ): void;
  deleteStudioLifecycleConfig(
    args: DeleteStudioLifecycleConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteStudioLifecycleConfigCommandOutput) => void
  ): void;
  deleteTags(
    args: DeleteTagsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteTagsCommandOutput>;
  deleteTags(
    args: DeleteTagsCommandInput,
    cb: (err: any, data?: DeleteTagsCommandOutput) => void
  ): void;
  deleteTags(
    args: DeleteTagsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteTagsCommandOutput) => void
  ): void;
  deleteTrainingJob(
    args: DeleteTrainingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteTrainingJobCommandOutput>;
  deleteTrainingJob(
    args: DeleteTrainingJobCommandInput,
    cb: (err: any, data?: DeleteTrainingJobCommandOutput) => void
  ): void;
  deleteTrainingJob(
    args: DeleteTrainingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteTrainingJobCommandOutput) => void
  ): void;
  deleteTrial(
    args: DeleteTrialCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteTrialCommandOutput>;
  deleteTrial(
    args: DeleteTrialCommandInput,
    cb: (err: any, data?: DeleteTrialCommandOutput) => void
  ): void;
  deleteTrial(
    args: DeleteTrialCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteTrialCommandOutput) => void
  ): void;
  deleteTrialComponent(
    args: DeleteTrialComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteTrialComponentCommandOutput>;
  deleteTrialComponent(
    args: DeleteTrialComponentCommandInput,
    cb: (err: any, data?: DeleteTrialComponentCommandOutput) => void
  ): void;
  deleteTrialComponent(
    args: DeleteTrialComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteTrialComponentCommandOutput) => void
  ): void;
  deleteUserProfile(
    args: DeleteUserProfileCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteUserProfileCommandOutput>;
  deleteUserProfile(
    args: DeleteUserProfileCommandInput,
    cb: (err: any, data?: DeleteUserProfileCommandOutput) => void
  ): void;
  deleteUserProfile(
    args: DeleteUserProfileCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteUserProfileCommandOutput) => void
  ): void;
  deleteWorkforce(
    args: DeleteWorkforceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteWorkforceCommandOutput>;
  deleteWorkforce(
    args: DeleteWorkforceCommandInput,
    cb: (err: any, data?: DeleteWorkforceCommandOutput) => void
  ): void;
  deleteWorkforce(
    args: DeleteWorkforceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteWorkforceCommandOutput) => void
  ): void;
  deleteWorkteam(
    args: DeleteWorkteamCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeleteWorkteamCommandOutput>;
  deleteWorkteam(
    args: DeleteWorkteamCommandInput,
    cb: (err: any, data?: DeleteWorkteamCommandOutput) => void
  ): void;
  deleteWorkteam(
    args: DeleteWorkteamCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeleteWorkteamCommandOutput) => void
  ): void;
  deregisterDevices(
    args: DeregisterDevicesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DeregisterDevicesCommandOutput>;
  deregisterDevices(
    args: DeregisterDevicesCommandInput,
    cb: (err: any, data?: DeregisterDevicesCommandOutput) => void
  ): void;
  deregisterDevices(
    args: DeregisterDevicesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DeregisterDevicesCommandOutput) => void
  ): void;
  describeAction(
    args: DescribeActionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeActionCommandOutput>;
  describeAction(
    args: DescribeActionCommandInput,
    cb: (err: any, data?: DescribeActionCommandOutput) => void
  ): void;
  describeAction(
    args: DescribeActionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeActionCommandOutput) => void
  ): void;
  describeAlgorithm(
    args: DescribeAlgorithmCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeAlgorithmCommandOutput>;
  describeAlgorithm(
    args: DescribeAlgorithmCommandInput,
    cb: (err: any, data?: DescribeAlgorithmCommandOutput) => void
  ): void;
  describeAlgorithm(
    args: DescribeAlgorithmCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeAlgorithmCommandOutput) => void
  ): void;
  describeApp(
    args: DescribeAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeAppCommandOutput>;
  describeApp(
    args: DescribeAppCommandInput,
    cb: (err: any, data?: DescribeAppCommandOutput) => void
  ): void;
  describeApp(
    args: DescribeAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeAppCommandOutput) => void
  ): void;
  describeAppImageConfig(
    args: DescribeAppImageConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeAppImageConfigCommandOutput>;
  describeAppImageConfig(
    args: DescribeAppImageConfigCommandInput,
    cb: (err: any, data?: DescribeAppImageConfigCommandOutput) => void
  ): void;
  describeAppImageConfig(
    args: DescribeAppImageConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeAppImageConfigCommandOutput) => void
  ): void;
  describeArtifact(
    args: DescribeArtifactCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeArtifactCommandOutput>;
  describeArtifact(
    args: DescribeArtifactCommandInput,
    cb: (err: any, data?: DescribeArtifactCommandOutput) => void
  ): void;
  describeArtifact(
    args: DescribeArtifactCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeArtifactCommandOutput) => void
  ): void;
  describeAutoMLJob(
    args: DescribeAutoMLJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeAutoMLJobCommandOutput>;
  describeAutoMLJob(
    args: DescribeAutoMLJobCommandInput,
    cb: (err: any, data?: DescribeAutoMLJobCommandOutput) => void
  ): void;
  describeAutoMLJob(
    args: DescribeAutoMLJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeAutoMLJobCommandOutput) => void
  ): void;
  describeAutoMLJobV2(
    args: DescribeAutoMLJobV2CommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeAutoMLJobV2CommandOutput>;
  describeAutoMLJobV2(
    args: DescribeAutoMLJobV2CommandInput,
    cb: (err: any, data?: DescribeAutoMLJobV2CommandOutput) => void
  ): void;
  describeAutoMLJobV2(
    args: DescribeAutoMLJobV2CommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeAutoMLJobV2CommandOutput) => void
  ): void;
  describeCluster(
    args: DescribeClusterCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeClusterCommandOutput>;
  describeCluster(
    args: DescribeClusterCommandInput,
    cb: (err: any, data?: DescribeClusterCommandOutput) => void
  ): void;
  describeCluster(
    args: DescribeClusterCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeClusterCommandOutput) => void
  ): void;
  describeClusterEvent(
    args: DescribeClusterEventCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeClusterEventCommandOutput>;
  describeClusterEvent(
    args: DescribeClusterEventCommandInput,
    cb: (err: any, data?: DescribeClusterEventCommandOutput) => void
  ): void;
  describeClusterEvent(
    args: DescribeClusterEventCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeClusterEventCommandOutput) => void
  ): void;
  describeClusterNode(
    args: DescribeClusterNodeCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeClusterNodeCommandOutput>;
  describeClusterNode(
    args: DescribeClusterNodeCommandInput,
    cb: (err: any, data?: DescribeClusterNodeCommandOutput) => void
  ): void;
  describeClusterNode(
    args: DescribeClusterNodeCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeClusterNodeCommandOutput) => void
  ): void;
  describeClusterSchedulerConfig(
    args: DescribeClusterSchedulerConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeClusterSchedulerConfigCommandOutput>;
  describeClusterSchedulerConfig(
    args: DescribeClusterSchedulerConfigCommandInput,
    cb: (err: any, data?: DescribeClusterSchedulerConfigCommandOutput) => void
  ): void;
  describeClusterSchedulerConfig(
    args: DescribeClusterSchedulerConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeClusterSchedulerConfigCommandOutput) => void
  ): void;
  describeCodeRepository(
    args: DescribeCodeRepositoryCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeCodeRepositoryCommandOutput>;
  describeCodeRepository(
    args: DescribeCodeRepositoryCommandInput,
    cb: (err: any, data?: DescribeCodeRepositoryCommandOutput) => void
  ): void;
  describeCodeRepository(
    args: DescribeCodeRepositoryCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeCodeRepositoryCommandOutput) => void
  ): void;
  describeCompilationJob(
    args: DescribeCompilationJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeCompilationJobCommandOutput>;
  describeCompilationJob(
    args: DescribeCompilationJobCommandInput,
    cb: (err: any, data?: DescribeCompilationJobCommandOutput) => void
  ): void;
  describeCompilationJob(
    args: DescribeCompilationJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeCompilationJobCommandOutput) => void
  ): void;
  describeComputeQuota(
    args: DescribeComputeQuotaCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeComputeQuotaCommandOutput>;
  describeComputeQuota(
    args: DescribeComputeQuotaCommandInput,
    cb: (err: any, data?: DescribeComputeQuotaCommandOutput) => void
  ): void;
  describeComputeQuota(
    args: DescribeComputeQuotaCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeComputeQuotaCommandOutput) => void
  ): void;
  describeContext(
    args: DescribeContextCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeContextCommandOutput>;
  describeContext(
    args: DescribeContextCommandInput,
    cb: (err: any, data?: DescribeContextCommandOutput) => void
  ): void;
  describeContext(
    args: DescribeContextCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeContextCommandOutput) => void
  ): void;
  describeDataQualityJobDefinition(
    args: DescribeDataQualityJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeDataQualityJobDefinitionCommandOutput>;
  describeDataQualityJobDefinition(
    args: DescribeDataQualityJobDefinitionCommandInput,
    cb: (err: any, data?: DescribeDataQualityJobDefinitionCommandOutput) => void
  ): void;
  describeDataQualityJobDefinition(
    args: DescribeDataQualityJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeDataQualityJobDefinitionCommandOutput) => void
  ): void;
  describeDevice(
    args: DescribeDeviceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeDeviceCommandOutput>;
  describeDevice(
    args: DescribeDeviceCommandInput,
    cb: (err: any, data?: DescribeDeviceCommandOutput) => void
  ): void;
  describeDevice(
    args: DescribeDeviceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeDeviceCommandOutput) => void
  ): void;
  describeDeviceFleet(
    args: DescribeDeviceFleetCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeDeviceFleetCommandOutput>;
  describeDeviceFleet(
    args: DescribeDeviceFleetCommandInput,
    cb: (err: any, data?: DescribeDeviceFleetCommandOutput) => void
  ): void;
  describeDeviceFleet(
    args: DescribeDeviceFleetCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeDeviceFleetCommandOutput) => void
  ): void;
  describeDomain(
    args: DescribeDomainCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeDomainCommandOutput>;
  describeDomain(
    args: DescribeDomainCommandInput,
    cb: (err: any, data?: DescribeDomainCommandOutput) => void
  ): void;
  describeDomain(
    args: DescribeDomainCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeDomainCommandOutput) => void
  ): void;
  describeEdgeDeploymentPlan(
    args: DescribeEdgeDeploymentPlanCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeEdgeDeploymentPlanCommandOutput>;
  describeEdgeDeploymentPlan(
    args: DescribeEdgeDeploymentPlanCommandInput,
    cb: (err: any, data?: DescribeEdgeDeploymentPlanCommandOutput) => void
  ): void;
  describeEdgeDeploymentPlan(
    args: DescribeEdgeDeploymentPlanCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeEdgeDeploymentPlanCommandOutput) => void
  ): void;
  describeEdgePackagingJob(
    args: DescribeEdgePackagingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeEdgePackagingJobCommandOutput>;
  describeEdgePackagingJob(
    args: DescribeEdgePackagingJobCommandInput,
    cb: (err: any, data?: DescribeEdgePackagingJobCommandOutput) => void
  ): void;
  describeEdgePackagingJob(
    args: DescribeEdgePackagingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeEdgePackagingJobCommandOutput) => void
  ): void;
  describeEndpoint(
    args: DescribeEndpointCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeEndpointCommandOutput>;
  describeEndpoint(
    args: DescribeEndpointCommandInput,
    cb: (err: any, data?: DescribeEndpointCommandOutput) => void
  ): void;
  describeEndpoint(
    args: DescribeEndpointCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeEndpointCommandOutput) => void
  ): void;
  describeEndpointConfig(
    args: DescribeEndpointConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeEndpointConfigCommandOutput>;
  describeEndpointConfig(
    args: DescribeEndpointConfigCommandInput,
    cb: (err: any, data?: DescribeEndpointConfigCommandOutput) => void
  ): void;
  describeEndpointConfig(
    args: DescribeEndpointConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeEndpointConfigCommandOutput) => void
  ): void;
  describeExperiment(
    args: DescribeExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeExperimentCommandOutput>;
  describeExperiment(
    args: DescribeExperimentCommandInput,
    cb: (err: any, data?: DescribeExperimentCommandOutput) => void
  ): void;
  describeExperiment(
    args: DescribeExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeExperimentCommandOutput) => void
  ): void;
  describeFeatureGroup(
    args: DescribeFeatureGroupCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeFeatureGroupCommandOutput>;
  describeFeatureGroup(
    args: DescribeFeatureGroupCommandInput,
    cb: (err: any, data?: DescribeFeatureGroupCommandOutput) => void
  ): void;
  describeFeatureGroup(
    args: DescribeFeatureGroupCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeFeatureGroupCommandOutput) => void
  ): void;
  describeFeatureMetadata(
    args: DescribeFeatureMetadataCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeFeatureMetadataCommandOutput>;
  describeFeatureMetadata(
    args: DescribeFeatureMetadataCommandInput,
    cb: (err: any, data?: DescribeFeatureMetadataCommandOutput) => void
  ): void;
  describeFeatureMetadata(
    args: DescribeFeatureMetadataCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeFeatureMetadataCommandOutput) => void
  ): void;
  describeFlowDefinition(
    args: DescribeFlowDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeFlowDefinitionCommandOutput>;
  describeFlowDefinition(
    args: DescribeFlowDefinitionCommandInput,
    cb: (err: any, data?: DescribeFlowDefinitionCommandOutput) => void
  ): void;
  describeFlowDefinition(
    args: DescribeFlowDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeFlowDefinitionCommandOutput) => void
  ): void;
  describeHub(
    args: DescribeHubCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeHubCommandOutput>;
  describeHub(
    args: DescribeHubCommandInput,
    cb: (err: any, data?: DescribeHubCommandOutput) => void
  ): void;
  describeHub(
    args: DescribeHubCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeHubCommandOutput) => void
  ): void;
  describeHubContent(
    args: DescribeHubContentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeHubContentCommandOutput>;
  describeHubContent(
    args: DescribeHubContentCommandInput,
    cb: (err: any, data?: DescribeHubContentCommandOutput) => void
  ): void;
  describeHubContent(
    args: DescribeHubContentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeHubContentCommandOutput) => void
  ): void;
  describeHumanTaskUi(
    args: DescribeHumanTaskUiCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeHumanTaskUiCommandOutput>;
  describeHumanTaskUi(
    args: DescribeHumanTaskUiCommandInput,
    cb: (err: any, data?: DescribeHumanTaskUiCommandOutput) => void
  ): void;
  describeHumanTaskUi(
    args: DescribeHumanTaskUiCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeHumanTaskUiCommandOutput) => void
  ): void;
  describeHyperParameterTuningJob(
    args: DescribeHyperParameterTuningJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeHyperParameterTuningJobCommandOutput>;
  describeHyperParameterTuningJob(
    args: DescribeHyperParameterTuningJobCommandInput,
    cb: (err: any, data?: DescribeHyperParameterTuningJobCommandOutput) => void
  ): void;
  describeHyperParameterTuningJob(
    args: DescribeHyperParameterTuningJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeHyperParameterTuningJobCommandOutput) => void
  ): void;
  describeImage(
    args: DescribeImageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeImageCommandOutput>;
  describeImage(
    args: DescribeImageCommandInput,
    cb: (err: any, data?: DescribeImageCommandOutput) => void
  ): void;
  describeImage(
    args: DescribeImageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeImageCommandOutput) => void
  ): void;
  describeImageVersion(
    args: DescribeImageVersionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeImageVersionCommandOutput>;
  describeImageVersion(
    args: DescribeImageVersionCommandInput,
    cb: (err: any, data?: DescribeImageVersionCommandOutput) => void
  ): void;
  describeImageVersion(
    args: DescribeImageVersionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeImageVersionCommandOutput) => void
  ): void;
  describeInferenceComponent(
    args: DescribeInferenceComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeInferenceComponentCommandOutput>;
  describeInferenceComponent(
    args: DescribeInferenceComponentCommandInput,
    cb: (err: any, data?: DescribeInferenceComponentCommandOutput) => void
  ): void;
  describeInferenceComponent(
    args: DescribeInferenceComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeInferenceComponentCommandOutput) => void
  ): void;
  describeInferenceExperiment(
    args: DescribeInferenceExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeInferenceExperimentCommandOutput>;
  describeInferenceExperiment(
    args: DescribeInferenceExperimentCommandInput,
    cb: (err: any, data?: DescribeInferenceExperimentCommandOutput) => void
  ): void;
  describeInferenceExperiment(
    args: DescribeInferenceExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeInferenceExperimentCommandOutput) => void
  ): void;
  describeInferenceRecommendationsJob(
    args: DescribeInferenceRecommendationsJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeInferenceRecommendationsJobCommandOutput>;
  describeInferenceRecommendationsJob(
    args: DescribeInferenceRecommendationsJobCommandInput,
    cb: (
      err: any,
      data?: DescribeInferenceRecommendationsJobCommandOutput
    ) => void
  ): void;
  describeInferenceRecommendationsJob(
    args: DescribeInferenceRecommendationsJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: DescribeInferenceRecommendationsJobCommandOutput
    ) => void
  ): void;
  describeLabelingJob(
    args: DescribeLabelingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeLabelingJobCommandOutput>;
  describeLabelingJob(
    args: DescribeLabelingJobCommandInput,
    cb: (err: any, data?: DescribeLabelingJobCommandOutput) => void
  ): void;
  describeLabelingJob(
    args: DescribeLabelingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeLabelingJobCommandOutput) => void
  ): void;
  describeLineageGroup(
    args: DescribeLineageGroupCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeLineageGroupCommandOutput>;
  describeLineageGroup(
    args: DescribeLineageGroupCommandInput,
    cb: (err: any, data?: DescribeLineageGroupCommandOutput) => void
  ): void;
  describeLineageGroup(
    args: DescribeLineageGroupCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeLineageGroupCommandOutput) => void
  ): void;
  describeMlflowApp(
    args: DescribeMlflowAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeMlflowAppCommandOutput>;
  describeMlflowApp(
    args: DescribeMlflowAppCommandInput,
    cb: (err: any, data?: DescribeMlflowAppCommandOutput) => void
  ): void;
  describeMlflowApp(
    args: DescribeMlflowAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeMlflowAppCommandOutput) => void
  ): void;
  describeMlflowTrackingServer(
    args: DescribeMlflowTrackingServerCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeMlflowTrackingServerCommandOutput>;
  describeMlflowTrackingServer(
    args: DescribeMlflowTrackingServerCommandInput,
    cb: (err: any, data?: DescribeMlflowTrackingServerCommandOutput) => void
  ): void;
  describeMlflowTrackingServer(
    args: DescribeMlflowTrackingServerCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeMlflowTrackingServerCommandOutput) => void
  ): void;
  describeModel(
    args: DescribeModelCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeModelCommandOutput>;
  describeModel(
    args: DescribeModelCommandInput,
    cb: (err: any, data?: DescribeModelCommandOutput) => void
  ): void;
  describeModel(
    args: DescribeModelCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeModelCommandOutput) => void
  ): void;
  describeModelBiasJobDefinition(
    args: DescribeModelBiasJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeModelBiasJobDefinitionCommandOutput>;
  describeModelBiasJobDefinition(
    args: DescribeModelBiasJobDefinitionCommandInput,
    cb: (err: any, data?: DescribeModelBiasJobDefinitionCommandOutput) => void
  ): void;
  describeModelBiasJobDefinition(
    args: DescribeModelBiasJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeModelBiasJobDefinitionCommandOutput) => void
  ): void;
  describeModelCard(
    args: DescribeModelCardCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeModelCardCommandOutput>;
  describeModelCard(
    args: DescribeModelCardCommandInput,
    cb: (err: any, data?: DescribeModelCardCommandOutput) => void
  ): void;
  describeModelCard(
    args: DescribeModelCardCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeModelCardCommandOutput) => void
  ): void;
  describeModelCardExportJob(
    args: DescribeModelCardExportJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeModelCardExportJobCommandOutput>;
  describeModelCardExportJob(
    args: DescribeModelCardExportJobCommandInput,
    cb: (err: any, data?: DescribeModelCardExportJobCommandOutput) => void
  ): void;
  describeModelCardExportJob(
    args: DescribeModelCardExportJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeModelCardExportJobCommandOutput) => void
  ): void;
  describeModelExplainabilityJobDefinition(
    args: DescribeModelExplainabilityJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeModelExplainabilityJobDefinitionCommandOutput>;
  describeModelExplainabilityJobDefinition(
    args: DescribeModelExplainabilityJobDefinitionCommandInput,
    cb: (
      err: any,
      data?: DescribeModelExplainabilityJobDefinitionCommandOutput
    ) => void
  ): void;
  describeModelExplainabilityJobDefinition(
    args: DescribeModelExplainabilityJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: DescribeModelExplainabilityJobDefinitionCommandOutput
    ) => void
  ): void;
  describeModelPackage(
    args: DescribeModelPackageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeModelPackageCommandOutput>;
  describeModelPackage(
    args: DescribeModelPackageCommandInput,
    cb: (err: any, data?: DescribeModelPackageCommandOutput) => void
  ): void;
  describeModelPackage(
    args: DescribeModelPackageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeModelPackageCommandOutput) => void
  ): void;
  describeModelPackageGroup(
    args: DescribeModelPackageGroupCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeModelPackageGroupCommandOutput>;
  describeModelPackageGroup(
    args: DescribeModelPackageGroupCommandInput,
    cb: (err: any, data?: DescribeModelPackageGroupCommandOutput) => void
  ): void;
  describeModelPackageGroup(
    args: DescribeModelPackageGroupCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeModelPackageGroupCommandOutput) => void
  ): void;
  describeModelQualityJobDefinition(
    args: DescribeModelQualityJobDefinitionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeModelQualityJobDefinitionCommandOutput>;
  describeModelQualityJobDefinition(
    args: DescribeModelQualityJobDefinitionCommandInput,
    cb: (
      err: any,
      data?: DescribeModelQualityJobDefinitionCommandOutput
    ) => void
  ): void;
  describeModelQualityJobDefinition(
    args: DescribeModelQualityJobDefinitionCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: DescribeModelQualityJobDefinitionCommandOutput
    ) => void
  ): void;
  describeMonitoringSchedule(
    args: DescribeMonitoringScheduleCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeMonitoringScheduleCommandOutput>;
  describeMonitoringSchedule(
    args: DescribeMonitoringScheduleCommandInput,
    cb: (err: any, data?: DescribeMonitoringScheduleCommandOutput) => void
  ): void;
  describeMonitoringSchedule(
    args: DescribeMonitoringScheduleCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeMonitoringScheduleCommandOutput) => void
  ): void;
  describeNotebookInstance(
    args: DescribeNotebookInstanceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeNotebookInstanceCommandOutput>;
  describeNotebookInstance(
    args: DescribeNotebookInstanceCommandInput,
    cb: (err: any, data?: DescribeNotebookInstanceCommandOutput) => void
  ): void;
  describeNotebookInstance(
    args: DescribeNotebookInstanceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeNotebookInstanceCommandOutput) => void
  ): void;
  describeNotebookInstanceLifecycleConfig(
    args: DescribeNotebookInstanceLifecycleConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeNotebookInstanceLifecycleConfigCommandOutput>;
  describeNotebookInstanceLifecycleConfig(
    args: DescribeNotebookInstanceLifecycleConfigCommandInput,
    cb: (
      err: any,
      data?: DescribeNotebookInstanceLifecycleConfigCommandOutput
    ) => void
  ): void;
  describeNotebookInstanceLifecycleConfig(
    args: DescribeNotebookInstanceLifecycleConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: DescribeNotebookInstanceLifecycleConfigCommandOutput
    ) => void
  ): void;
  describeOptimizationJob(
    args: DescribeOptimizationJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeOptimizationJobCommandOutput>;
  describeOptimizationJob(
    args: DescribeOptimizationJobCommandInput,
    cb: (err: any, data?: DescribeOptimizationJobCommandOutput) => void
  ): void;
  describeOptimizationJob(
    args: DescribeOptimizationJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeOptimizationJobCommandOutput) => void
  ): void;
  describePartnerApp(
    args: DescribePartnerAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribePartnerAppCommandOutput>;
  describePartnerApp(
    args: DescribePartnerAppCommandInput,
    cb: (err: any, data?: DescribePartnerAppCommandOutput) => void
  ): void;
  describePartnerApp(
    args: DescribePartnerAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribePartnerAppCommandOutput) => void
  ): void;
  describePipeline(
    args: DescribePipelineCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribePipelineCommandOutput>;
  describePipeline(
    args: DescribePipelineCommandInput,
    cb: (err: any, data?: DescribePipelineCommandOutput) => void
  ): void;
  describePipeline(
    args: DescribePipelineCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribePipelineCommandOutput) => void
  ): void;
  describePipelineDefinitionForExecution(
    args: DescribePipelineDefinitionForExecutionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribePipelineDefinitionForExecutionCommandOutput>;
  describePipelineDefinitionForExecution(
    args: DescribePipelineDefinitionForExecutionCommandInput,
    cb: (
      err: any,
      data?: DescribePipelineDefinitionForExecutionCommandOutput
    ) => void
  ): void;
  describePipelineDefinitionForExecution(
    args: DescribePipelineDefinitionForExecutionCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: DescribePipelineDefinitionForExecutionCommandOutput
    ) => void
  ): void;
  describePipelineExecution(
    args: DescribePipelineExecutionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribePipelineExecutionCommandOutput>;
  describePipelineExecution(
    args: DescribePipelineExecutionCommandInput,
    cb: (err: any, data?: DescribePipelineExecutionCommandOutput) => void
  ): void;
  describePipelineExecution(
    args: DescribePipelineExecutionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribePipelineExecutionCommandOutput) => void
  ): void;
  describeProcessingJob(
    args: DescribeProcessingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeProcessingJobCommandOutput>;
  describeProcessingJob(
    args: DescribeProcessingJobCommandInput,
    cb: (err: any, data?: DescribeProcessingJobCommandOutput) => void
  ): void;
  describeProcessingJob(
    args: DescribeProcessingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeProcessingJobCommandOutput) => void
  ): void;
  describeProject(
    args: DescribeProjectCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeProjectCommandOutput>;
  describeProject(
    args: DescribeProjectCommandInput,
    cb: (err: any, data?: DescribeProjectCommandOutput) => void
  ): void;
  describeProject(
    args: DescribeProjectCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeProjectCommandOutput) => void
  ): void;
  describeReservedCapacity(
    args: DescribeReservedCapacityCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeReservedCapacityCommandOutput>;
  describeReservedCapacity(
    args: DescribeReservedCapacityCommandInput,
    cb: (err: any, data?: DescribeReservedCapacityCommandOutput) => void
  ): void;
  describeReservedCapacity(
    args: DescribeReservedCapacityCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeReservedCapacityCommandOutput) => void
  ): void;
  describeSpace(
    args: DescribeSpaceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeSpaceCommandOutput>;
  describeSpace(
    args: DescribeSpaceCommandInput,
    cb: (err: any, data?: DescribeSpaceCommandOutput) => void
  ): void;
  describeSpace(
    args: DescribeSpaceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeSpaceCommandOutput) => void
  ): void;
  describeStudioLifecycleConfig(
    args: DescribeStudioLifecycleConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeStudioLifecycleConfigCommandOutput>;
  describeStudioLifecycleConfig(
    args: DescribeStudioLifecycleConfigCommandInput,
    cb: (err: any, data?: DescribeStudioLifecycleConfigCommandOutput) => void
  ): void;
  describeStudioLifecycleConfig(
    args: DescribeStudioLifecycleConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeStudioLifecycleConfigCommandOutput) => void
  ): void;
  describeSubscribedWorkteam(
    args: DescribeSubscribedWorkteamCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeSubscribedWorkteamCommandOutput>;
  describeSubscribedWorkteam(
    args: DescribeSubscribedWorkteamCommandInput,
    cb: (err: any, data?: DescribeSubscribedWorkteamCommandOutput) => void
  ): void;
  describeSubscribedWorkteam(
    args: DescribeSubscribedWorkteamCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeSubscribedWorkteamCommandOutput) => void
  ): void;
  describeTrainingJob(
    args: DescribeTrainingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeTrainingJobCommandOutput>;
  describeTrainingJob(
    args: DescribeTrainingJobCommandInput,
    cb: (err: any, data?: DescribeTrainingJobCommandOutput) => void
  ): void;
  describeTrainingJob(
    args: DescribeTrainingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeTrainingJobCommandOutput) => void
  ): void;
  describeTrainingPlan(
    args: DescribeTrainingPlanCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeTrainingPlanCommandOutput>;
  describeTrainingPlan(
    args: DescribeTrainingPlanCommandInput,
    cb: (err: any, data?: DescribeTrainingPlanCommandOutput) => void
  ): void;
  describeTrainingPlan(
    args: DescribeTrainingPlanCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeTrainingPlanCommandOutput) => void
  ): void;
  describeTransformJob(
    args: DescribeTransformJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeTransformJobCommandOutput>;
  describeTransformJob(
    args: DescribeTransformJobCommandInput,
    cb: (err: any, data?: DescribeTransformJobCommandOutput) => void
  ): void;
  describeTransformJob(
    args: DescribeTransformJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeTransformJobCommandOutput) => void
  ): void;
  describeTrial(
    args: DescribeTrialCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeTrialCommandOutput>;
  describeTrial(
    args: DescribeTrialCommandInput,
    cb: (err: any, data?: DescribeTrialCommandOutput) => void
  ): void;
  describeTrial(
    args: DescribeTrialCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeTrialCommandOutput) => void
  ): void;
  describeTrialComponent(
    args: DescribeTrialComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeTrialComponentCommandOutput>;
  describeTrialComponent(
    args: DescribeTrialComponentCommandInput,
    cb: (err: any, data?: DescribeTrialComponentCommandOutput) => void
  ): void;
  describeTrialComponent(
    args: DescribeTrialComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeTrialComponentCommandOutput) => void
  ): void;
  describeUserProfile(
    args: DescribeUserProfileCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeUserProfileCommandOutput>;
  describeUserProfile(
    args: DescribeUserProfileCommandInput,
    cb: (err: any, data?: DescribeUserProfileCommandOutput) => void
  ): void;
  describeUserProfile(
    args: DescribeUserProfileCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeUserProfileCommandOutput) => void
  ): void;
  describeWorkforce(
    args: DescribeWorkforceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeWorkforceCommandOutput>;
  describeWorkforce(
    args: DescribeWorkforceCommandInput,
    cb: (err: any, data?: DescribeWorkforceCommandOutput) => void
  ): void;
  describeWorkforce(
    args: DescribeWorkforceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeWorkforceCommandOutput) => void
  ): void;
  describeWorkteam(
    args: DescribeWorkteamCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DescribeWorkteamCommandOutput>;
  describeWorkteam(
    args: DescribeWorkteamCommandInput,
    cb: (err: any, data?: DescribeWorkteamCommandOutput) => void
  ): void;
  describeWorkteam(
    args: DescribeWorkteamCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DescribeWorkteamCommandOutput) => void
  ): void;
  detachClusterNodeVolume(
    args: DetachClusterNodeVolumeCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DetachClusterNodeVolumeCommandOutput>;
  detachClusterNodeVolume(
    args: DetachClusterNodeVolumeCommandInput,
    cb: (err: any, data?: DetachClusterNodeVolumeCommandOutput) => void
  ): void;
  detachClusterNodeVolume(
    args: DetachClusterNodeVolumeCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DetachClusterNodeVolumeCommandOutput) => void
  ): void;
  disableSagemakerServicecatalogPortfolio(): Promise<DisableSagemakerServicecatalogPortfolioCommandOutput>;
  disableSagemakerServicecatalogPortfolio(
    args: DisableSagemakerServicecatalogPortfolioCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DisableSagemakerServicecatalogPortfolioCommandOutput>;
  disableSagemakerServicecatalogPortfolio(
    args: DisableSagemakerServicecatalogPortfolioCommandInput,
    cb: (
      err: any,
      data?: DisableSagemakerServicecatalogPortfolioCommandOutput
    ) => void
  ): void;
  disableSagemakerServicecatalogPortfolio(
    args: DisableSagemakerServicecatalogPortfolioCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: DisableSagemakerServicecatalogPortfolioCommandOutput
    ) => void
  ): void;
  disassociateTrialComponent(
    args: DisassociateTrialComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<DisassociateTrialComponentCommandOutput>;
  disassociateTrialComponent(
    args: DisassociateTrialComponentCommandInput,
    cb: (err: any, data?: DisassociateTrialComponentCommandOutput) => void
  ): void;
  disassociateTrialComponent(
    args: DisassociateTrialComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: DisassociateTrialComponentCommandOutput) => void
  ): void;
  enableSagemakerServicecatalogPortfolio(): Promise<EnableSagemakerServicecatalogPortfolioCommandOutput>;
  enableSagemakerServicecatalogPortfolio(
    args: EnableSagemakerServicecatalogPortfolioCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<EnableSagemakerServicecatalogPortfolioCommandOutput>;
  enableSagemakerServicecatalogPortfolio(
    args: EnableSagemakerServicecatalogPortfolioCommandInput,
    cb: (
      err: any,
      data?: EnableSagemakerServicecatalogPortfolioCommandOutput
    ) => void
  ): void;
  enableSagemakerServicecatalogPortfolio(
    args: EnableSagemakerServicecatalogPortfolioCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: EnableSagemakerServicecatalogPortfolioCommandOutput
    ) => void
  ): void;
  getDeviceFleetReport(
    args: GetDeviceFleetReportCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<GetDeviceFleetReportCommandOutput>;
  getDeviceFleetReport(
    args: GetDeviceFleetReportCommandInput,
    cb: (err: any, data?: GetDeviceFleetReportCommandOutput) => void
  ): void;
  getDeviceFleetReport(
    args: GetDeviceFleetReportCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: GetDeviceFleetReportCommandOutput) => void
  ): void;
  getLineageGroupPolicy(
    args: GetLineageGroupPolicyCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<GetLineageGroupPolicyCommandOutput>;
  getLineageGroupPolicy(
    args: GetLineageGroupPolicyCommandInput,
    cb: (err: any, data?: GetLineageGroupPolicyCommandOutput) => void
  ): void;
  getLineageGroupPolicy(
    args: GetLineageGroupPolicyCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: GetLineageGroupPolicyCommandOutput) => void
  ): void;
  getModelPackageGroupPolicy(
    args: GetModelPackageGroupPolicyCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<GetModelPackageGroupPolicyCommandOutput>;
  getModelPackageGroupPolicy(
    args: GetModelPackageGroupPolicyCommandInput,
    cb: (err: any, data?: GetModelPackageGroupPolicyCommandOutput) => void
  ): void;
  getModelPackageGroupPolicy(
    args: GetModelPackageGroupPolicyCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: GetModelPackageGroupPolicyCommandOutput) => void
  ): void;
  getSagemakerServicecatalogPortfolioStatus(): Promise<GetSagemakerServicecatalogPortfolioStatusCommandOutput>;
  getSagemakerServicecatalogPortfolioStatus(
    args: GetSagemakerServicecatalogPortfolioStatusCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<GetSagemakerServicecatalogPortfolioStatusCommandOutput>;
  getSagemakerServicecatalogPortfolioStatus(
    args: GetSagemakerServicecatalogPortfolioStatusCommandInput,
    cb: (
      err: any,
      data?: GetSagemakerServicecatalogPortfolioStatusCommandOutput
    ) => void
  ): void;
  getSagemakerServicecatalogPortfolioStatus(
    args: GetSagemakerServicecatalogPortfolioStatusCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: GetSagemakerServicecatalogPortfolioStatusCommandOutput
    ) => void
  ): void;
  getScalingConfigurationRecommendation(
    args: GetScalingConfigurationRecommendationCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<GetScalingConfigurationRecommendationCommandOutput>;
  getScalingConfigurationRecommendation(
    args: GetScalingConfigurationRecommendationCommandInput,
    cb: (
      err: any,
      data?: GetScalingConfigurationRecommendationCommandOutput
    ) => void
  ): void;
  getScalingConfigurationRecommendation(
    args: GetScalingConfigurationRecommendationCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: GetScalingConfigurationRecommendationCommandOutput
    ) => void
  ): void;
  getSearchSuggestions(
    args: GetSearchSuggestionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<GetSearchSuggestionsCommandOutput>;
  getSearchSuggestions(
    args: GetSearchSuggestionsCommandInput,
    cb: (err: any, data?: GetSearchSuggestionsCommandOutput) => void
  ): void;
  getSearchSuggestions(
    args: GetSearchSuggestionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: GetSearchSuggestionsCommandOutput) => void
  ): void;
  importHubContent(
    args: ImportHubContentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ImportHubContentCommandOutput>;
  importHubContent(
    args: ImportHubContentCommandInput,
    cb: (err: any, data?: ImportHubContentCommandOutput) => void
  ): void;
  importHubContent(
    args: ImportHubContentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ImportHubContentCommandOutput) => void
  ): void;
  listActions(): Promise<ListActionsCommandOutput>;
  listActions(
    args: ListActionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListActionsCommandOutput>;
  listActions(
    args: ListActionsCommandInput,
    cb: (err: any, data?: ListActionsCommandOutput) => void
  ): void;
  listActions(
    args: ListActionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListActionsCommandOutput) => void
  ): void;
  listAlgorithms(): Promise<ListAlgorithmsCommandOutput>;
  listAlgorithms(
    args: ListAlgorithmsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListAlgorithmsCommandOutput>;
  listAlgorithms(
    args: ListAlgorithmsCommandInput,
    cb: (err: any, data?: ListAlgorithmsCommandOutput) => void
  ): void;
  listAlgorithms(
    args: ListAlgorithmsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListAlgorithmsCommandOutput) => void
  ): void;
  listAliases(
    args: ListAliasesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListAliasesCommandOutput>;
  listAliases(
    args: ListAliasesCommandInput,
    cb: (err: any, data?: ListAliasesCommandOutput) => void
  ): void;
  listAliases(
    args: ListAliasesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListAliasesCommandOutput) => void
  ): void;
  listAppImageConfigs(): Promise<ListAppImageConfigsCommandOutput>;
  listAppImageConfigs(
    args: ListAppImageConfigsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListAppImageConfigsCommandOutput>;
  listAppImageConfigs(
    args: ListAppImageConfigsCommandInput,
    cb: (err: any, data?: ListAppImageConfigsCommandOutput) => void
  ): void;
  listAppImageConfigs(
    args: ListAppImageConfigsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListAppImageConfigsCommandOutput) => void
  ): void;
  listApps(): Promise<ListAppsCommandOutput>;
  listApps(
    args: ListAppsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListAppsCommandOutput>;
  listApps(
    args: ListAppsCommandInput,
    cb: (err: any, data?: ListAppsCommandOutput) => void
  ): void;
  listApps(
    args: ListAppsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListAppsCommandOutput) => void
  ): void;
  listArtifacts(): Promise<ListArtifactsCommandOutput>;
  listArtifacts(
    args: ListArtifactsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListArtifactsCommandOutput>;
  listArtifacts(
    args: ListArtifactsCommandInput,
    cb: (err: any, data?: ListArtifactsCommandOutput) => void
  ): void;
  listArtifacts(
    args: ListArtifactsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListArtifactsCommandOutput) => void
  ): void;
  listAssociations(): Promise<ListAssociationsCommandOutput>;
  listAssociations(
    args: ListAssociationsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListAssociationsCommandOutput>;
  listAssociations(
    args: ListAssociationsCommandInput,
    cb: (err: any, data?: ListAssociationsCommandOutput) => void
  ): void;
  listAssociations(
    args: ListAssociationsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListAssociationsCommandOutput) => void
  ): void;
  listAutoMLJobs(): Promise<ListAutoMLJobsCommandOutput>;
  listAutoMLJobs(
    args: ListAutoMLJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListAutoMLJobsCommandOutput>;
  listAutoMLJobs(
    args: ListAutoMLJobsCommandInput,
    cb: (err: any, data?: ListAutoMLJobsCommandOutput) => void
  ): void;
  listAutoMLJobs(
    args: ListAutoMLJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListAutoMLJobsCommandOutput) => void
  ): void;
  listCandidatesForAutoMLJob(
    args: ListCandidatesForAutoMLJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListCandidatesForAutoMLJobCommandOutput>;
  listCandidatesForAutoMLJob(
    args: ListCandidatesForAutoMLJobCommandInput,
    cb: (err: any, data?: ListCandidatesForAutoMLJobCommandOutput) => void
  ): void;
  listCandidatesForAutoMLJob(
    args: ListCandidatesForAutoMLJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListCandidatesForAutoMLJobCommandOutput) => void
  ): void;
  listClusterEvents(
    args: ListClusterEventsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListClusterEventsCommandOutput>;
  listClusterEvents(
    args: ListClusterEventsCommandInput,
    cb: (err: any, data?: ListClusterEventsCommandOutput) => void
  ): void;
  listClusterEvents(
    args: ListClusterEventsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListClusterEventsCommandOutput) => void
  ): void;
  listClusterNodes(
    args: ListClusterNodesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListClusterNodesCommandOutput>;
  listClusterNodes(
    args: ListClusterNodesCommandInput,
    cb: (err: any, data?: ListClusterNodesCommandOutput) => void
  ): void;
  listClusterNodes(
    args: ListClusterNodesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListClusterNodesCommandOutput) => void
  ): void;
  listClusters(): Promise<ListClustersCommandOutput>;
  listClusters(
    args: ListClustersCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListClustersCommandOutput>;
  listClusters(
    args: ListClustersCommandInput,
    cb: (err: any, data?: ListClustersCommandOutput) => void
  ): void;
  listClusters(
    args: ListClustersCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListClustersCommandOutput) => void
  ): void;
  listClusterSchedulerConfigs(): Promise<ListClusterSchedulerConfigsCommandOutput>;
  listClusterSchedulerConfigs(
    args: ListClusterSchedulerConfigsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListClusterSchedulerConfigsCommandOutput>;
  listClusterSchedulerConfigs(
    args: ListClusterSchedulerConfigsCommandInput,
    cb: (err: any, data?: ListClusterSchedulerConfigsCommandOutput) => void
  ): void;
  listClusterSchedulerConfigs(
    args: ListClusterSchedulerConfigsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListClusterSchedulerConfigsCommandOutput) => void
  ): void;
  listCodeRepositories(): Promise<ListCodeRepositoriesCommandOutput>;
  listCodeRepositories(
    args: ListCodeRepositoriesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListCodeRepositoriesCommandOutput>;
  listCodeRepositories(
    args: ListCodeRepositoriesCommandInput,
    cb: (err: any, data?: ListCodeRepositoriesCommandOutput) => void
  ): void;
  listCodeRepositories(
    args: ListCodeRepositoriesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListCodeRepositoriesCommandOutput) => void
  ): void;
  listCompilationJobs(): Promise<ListCompilationJobsCommandOutput>;
  listCompilationJobs(
    args: ListCompilationJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListCompilationJobsCommandOutput>;
  listCompilationJobs(
    args: ListCompilationJobsCommandInput,
    cb: (err: any, data?: ListCompilationJobsCommandOutput) => void
  ): void;
  listCompilationJobs(
    args: ListCompilationJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListCompilationJobsCommandOutput) => void
  ): void;
  listComputeQuotas(): Promise<ListComputeQuotasCommandOutput>;
  listComputeQuotas(
    args: ListComputeQuotasCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListComputeQuotasCommandOutput>;
  listComputeQuotas(
    args: ListComputeQuotasCommandInput,
    cb: (err: any, data?: ListComputeQuotasCommandOutput) => void
  ): void;
  listComputeQuotas(
    args: ListComputeQuotasCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListComputeQuotasCommandOutput) => void
  ): void;
  listContexts(): Promise<ListContextsCommandOutput>;
  listContexts(
    args: ListContextsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListContextsCommandOutput>;
  listContexts(
    args: ListContextsCommandInput,
    cb: (err: any, data?: ListContextsCommandOutput) => void
  ): void;
  listContexts(
    args: ListContextsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListContextsCommandOutput) => void
  ): void;
  listDataQualityJobDefinitions(): Promise<ListDataQualityJobDefinitionsCommandOutput>;
  listDataQualityJobDefinitions(
    args: ListDataQualityJobDefinitionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListDataQualityJobDefinitionsCommandOutput>;
  listDataQualityJobDefinitions(
    args: ListDataQualityJobDefinitionsCommandInput,
    cb: (err: any, data?: ListDataQualityJobDefinitionsCommandOutput) => void
  ): void;
  listDataQualityJobDefinitions(
    args: ListDataQualityJobDefinitionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListDataQualityJobDefinitionsCommandOutput) => void
  ): void;
  listDeviceFleets(): Promise<ListDeviceFleetsCommandOutput>;
  listDeviceFleets(
    args: ListDeviceFleetsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListDeviceFleetsCommandOutput>;
  listDeviceFleets(
    args: ListDeviceFleetsCommandInput,
    cb: (err: any, data?: ListDeviceFleetsCommandOutput) => void
  ): void;
  listDeviceFleets(
    args: ListDeviceFleetsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListDeviceFleetsCommandOutput) => void
  ): void;
  listDevices(): Promise<ListDevicesCommandOutput>;
  listDevices(
    args: ListDevicesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListDevicesCommandOutput>;
  listDevices(
    args: ListDevicesCommandInput,
    cb: (err: any, data?: ListDevicesCommandOutput) => void
  ): void;
  listDevices(
    args: ListDevicesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListDevicesCommandOutput) => void
  ): void;
  listDomains(): Promise<ListDomainsCommandOutput>;
  listDomains(
    args: ListDomainsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListDomainsCommandOutput>;
  listDomains(
    args: ListDomainsCommandInput,
    cb: (err: any, data?: ListDomainsCommandOutput) => void
  ): void;
  listDomains(
    args: ListDomainsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListDomainsCommandOutput) => void
  ): void;
  listEdgeDeploymentPlans(): Promise<ListEdgeDeploymentPlansCommandOutput>;
  listEdgeDeploymentPlans(
    args: ListEdgeDeploymentPlansCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListEdgeDeploymentPlansCommandOutput>;
  listEdgeDeploymentPlans(
    args: ListEdgeDeploymentPlansCommandInput,
    cb: (err: any, data?: ListEdgeDeploymentPlansCommandOutput) => void
  ): void;
  listEdgeDeploymentPlans(
    args: ListEdgeDeploymentPlansCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListEdgeDeploymentPlansCommandOutput) => void
  ): void;
  listEdgePackagingJobs(): Promise<ListEdgePackagingJobsCommandOutput>;
  listEdgePackagingJobs(
    args: ListEdgePackagingJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListEdgePackagingJobsCommandOutput>;
  listEdgePackagingJobs(
    args: ListEdgePackagingJobsCommandInput,
    cb: (err: any, data?: ListEdgePackagingJobsCommandOutput) => void
  ): void;
  listEdgePackagingJobs(
    args: ListEdgePackagingJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListEdgePackagingJobsCommandOutput) => void
  ): void;
  listEndpointConfigs(): Promise<ListEndpointConfigsCommandOutput>;
  listEndpointConfigs(
    args: ListEndpointConfigsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListEndpointConfigsCommandOutput>;
  listEndpointConfigs(
    args: ListEndpointConfigsCommandInput,
    cb: (err: any, data?: ListEndpointConfigsCommandOutput) => void
  ): void;
  listEndpointConfigs(
    args: ListEndpointConfigsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListEndpointConfigsCommandOutput) => void
  ): void;
  listEndpoints(): Promise<ListEndpointsCommandOutput>;
  listEndpoints(
    args: ListEndpointsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListEndpointsCommandOutput>;
  listEndpoints(
    args: ListEndpointsCommandInput,
    cb: (err: any, data?: ListEndpointsCommandOutput) => void
  ): void;
  listEndpoints(
    args: ListEndpointsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListEndpointsCommandOutput) => void
  ): void;
  listExperiments(): Promise<ListExperimentsCommandOutput>;
  listExperiments(
    args: ListExperimentsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListExperimentsCommandOutput>;
  listExperiments(
    args: ListExperimentsCommandInput,
    cb: (err: any, data?: ListExperimentsCommandOutput) => void
  ): void;
  listExperiments(
    args: ListExperimentsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListExperimentsCommandOutput) => void
  ): void;
  listFeatureGroups(): Promise<ListFeatureGroupsCommandOutput>;
  listFeatureGroups(
    args: ListFeatureGroupsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListFeatureGroupsCommandOutput>;
  listFeatureGroups(
    args: ListFeatureGroupsCommandInput,
    cb: (err: any, data?: ListFeatureGroupsCommandOutput) => void
  ): void;
  listFeatureGroups(
    args: ListFeatureGroupsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListFeatureGroupsCommandOutput) => void
  ): void;
  listFlowDefinitions(): Promise<ListFlowDefinitionsCommandOutput>;
  listFlowDefinitions(
    args: ListFlowDefinitionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListFlowDefinitionsCommandOutput>;
  listFlowDefinitions(
    args: ListFlowDefinitionsCommandInput,
    cb: (err: any, data?: ListFlowDefinitionsCommandOutput) => void
  ): void;
  listFlowDefinitions(
    args: ListFlowDefinitionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListFlowDefinitionsCommandOutput) => void
  ): void;
  listHubContents(
    args: ListHubContentsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListHubContentsCommandOutput>;
  listHubContents(
    args: ListHubContentsCommandInput,
    cb: (err: any, data?: ListHubContentsCommandOutput) => void
  ): void;
  listHubContents(
    args: ListHubContentsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListHubContentsCommandOutput) => void
  ): void;
  listHubContentVersions(
    args: ListHubContentVersionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListHubContentVersionsCommandOutput>;
  listHubContentVersions(
    args: ListHubContentVersionsCommandInput,
    cb: (err: any, data?: ListHubContentVersionsCommandOutput) => void
  ): void;
  listHubContentVersions(
    args: ListHubContentVersionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListHubContentVersionsCommandOutput) => void
  ): void;
  listHubs(): Promise<ListHubsCommandOutput>;
  listHubs(
    args: ListHubsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListHubsCommandOutput>;
  listHubs(
    args: ListHubsCommandInput,
    cb: (err: any, data?: ListHubsCommandOutput) => void
  ): void;
  listHubs(
    args: ListHubsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListHubsCommandOutput) => void
  ): void;
  listHumanTaskUis(): Promise<ListHumanTaskUisCommandOutput>;
  listHumanTaskUis(
    args: ListHumanTaskUisCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListHumanTaskUisCommandOutput>;
  listHumanTaskUis(
    args: ListHumanTaskUisCommandInput,
    cb: (err: any, data?: ListHumanTaskUisCommandOutput) => void
  ): void;
  listHumanTaskUis(
    args: ListHumanTaskUisCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListHumanTaskUisCommandOutput) => void
  ): void;
  listHyperParameterTuningJobs(): Promise<ListHyperParameterTuningJobsCommandOutput>;
  listHyperParameterTuningJobs(
    args: ListHyperParameterTuningJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListHyperParameterTuningJobsCommandOutput>;
  listHyperParameterTuningJobs(
    args: ListHyperParameterTuningJobsCommandInput,
    cb: (err: any, data?: ListHyperParameterTuningJobsCommandOutput) => void
  ): void;
  listHyperParameterTuningJobs(
    args: ListHyperParameterTuningJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListHyperParameterTuningJobsCommandOutput) => void
  ): void;
  listImages(): Promise<ListImagesCommandOutput>;
  listImages(
    args: ListImagesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListImagesCommandOutput>;
  listImages(
    args: ListImagesCommandInput,
    cb: (err: any, data?: ListImagesCommandOutput) => void
  ): void;
  listImages(
    args: ListImagesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListImagesCommandOutput) => void
  ): void;
  listImageVersions(
    args: ListImageVersionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListImageVersionsCommandOutput>;
  listImageVersions(
    args: ListImageVersionsCommandInput,
    cb: (err: any, data?: ListImageVersionsCommandOutput) => void
  ): void;
  listImageVersions(
    args: ListImageVersionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListImageVersionsCommandOutput) => void
  ): void;
  listInferenceComponents(): Promise<ListInferenceComponentsCommandOutput>;
  listInferenceComponents(
    args: ListInferenceComponentsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListInferenceComponentsCommandOutput>;
  listInferenceComponents(
    args: ListInferenceComponentsCommandInput,
    cb: (err: any, data?: ListInferenceComponentsCommandOutput) => void
  ): void;
  listInferenceComponents(
    args: ListInferenceComponentsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListInferenceComponentsCommandOutput) => void
  ): void;
  listInferenceExperiments(): Promise<ListInferenceExperimentsCommandOutput>;
  listInferenceExperiments(
    args: ListInferenceExperimentsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListInferenceExperimentsCommandOutput>;
  listInferenceExperiments(
    args: ListInferenceExperimentsCommandInput,
    cb: (err: any, data?: ListInferenceExperimentsCommandOutput) => void
  ): void;
  listInferenceExperiments(
    args: ListInferenceExperimentsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListInferenceExperimentsCommandOutput) => void
  ): void;
  listInferenceRecommendationsJobs(): Promise<ListInferenceRecommendationsJobsCommandOutput>;
  listInferenceRecommendationsJobs(
    args: ListInferenceRecommendationsJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListInferenceRecommendationsJobsCommandOutput>;
  listInferenceRecommendationsJobs(
    args: ListInferenceRecommendationsJobsCommandInput,
    cb: (err: any, data?: ListInferenceRecommendationsJobsCommandOutput) => void
  ): void;
  listInferenceRecommendationsJobs(
    args: ListInferenceRecommendationsJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListInferenceRecommendationsJobsCommandOutput) => void
  ): void;
  listInferenceRecommendationsJobSteps(
    args: ListInferenceRecommendationsJobStepsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListInferenceRecommendationsJobStepsCommandOutput>;
  listInferenceRecommendationsJobSteps(
    args: ListInferenceRecommendationsJobStepsCommandInput,
    cb: (
      err: any,
      data?: ListInferenceRecommendationsJobStepsCommandOutput
    ) => void
  ): void;
  listInferenceRecommendationsJobSteps(
    args: ListInferenceRecommendationsJobStepsCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: ListInferenceRecommendationsJobStepsCommandOutput
    ) => void
  ): void;
  listLabelingJobs(): Promise<ListLabelingJobsCommandOutput>;
  listLabelingJobs(
    args: ListLabelingJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListLabelingJobsCommandOutput>;
  listLabelingJobs(
    args: ListLabelingJobsCommandInput,
    cb: (err: any, data?: ListLabelingJobsCommandOutput) => void
  ): void;
  listLabelingJobs(
    args: ListLabelingJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListLabelingJobsCommandOutput) => void
  ): void;
  listLabelingJobsForWorkteam(
    args: ListLabelingJobsForWorkteamCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListLabelingJobsForWorkteamCommandOutput>;
  listLabelingJobsForWorkteam(
    args: ListLabelingJobsForWorkteamCommandInput,
    cb: (err: any, data?: ListLabelingJobsForWorkteamCommandOutput) => void
  ): void;
  listLabelingJobsForWorkteam(
    args: ListLabelingJobsForWorkteamCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListLabelingJobsForWorkteamCommandOutput) => void
  ): void;
  listLineageGroups(): Promise<ListLineageGroupsCommandOutput>;
  listLineageGroups(
    args: ListLineageGroupsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListLineageGroupsCommandOutput>;
  listLineageGroups(
    args: ListLineageGroupsCommandInput,
    cb: (err: any, data?: ListLineageGroupsCommandOutput) => void
  ): void;
  listLineageGroups(
    args: ListLineageGroupsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListLineageGroupsCommandOutput) => void
  ): void;
  listMlflowApps(): Promise<ListMlflowAppsCommandOutput>;
  listMlflowApps(
    args: ListMlflowAppsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListMlflowAppsCommandOutput>;
  listMlflowApps(
    args: ListMlflowAppsCommandInput,
    cb: (err: any, data?: ListMlflowAppsCommandOutput) => void
  ): void;
  listMlflowApps(
    args: ListMlflowAppsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListMlflowAppsCommandOutput) => void
  ): void;
  listMlflowTrackingServers(): Promise<ListMlflowTrackingServersCommandOutput>;
  listMlflowTrackingServers(
    args: ListMlflowTrackingServersCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListMlflowTrackingServersCommandOutput>;
  listMlflowTrackingServers(
    args: ListMlflowTrackingServersCommandInput,
    cb: (err: any, data?: ListMlflowTrackingServersCommandOutput) => void
  ): void;
  listMlflowTrackingServers(
    args: ListMlflowTrackingServersCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListMlflowTrackingServersCommandOutput) => void
  ): void;
  listModelBiasJobDefinitions(): Promise<ListModelBiasJobDefinitionsCommandOutput>;
  listModelBiasJobDefinitions(
    args: ListModelBiasJobDefinitionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelBiasJobDefinitionsCommandOutput>;
  listModelBiasJobDefinitions(
    args: ListModelBiasJobDefinitionsCommandInput,
    cb: (err: any, data?: ListModelBiasJobDefinitionsCommandOutput) => void
  ): void;
  listModelBiasJobDefinitions(
    args: ListModelBiasJobDefinitionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListModelBiasJobDefinitionsCommandOutput) => void
  ): void;
  listModelCardExportJobs(
    args: ListModelCardExportJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelCardExportJobsCommandOutput>;
  listModelCardExportJobs(
    args: ListModelCardExportJobsCommandInput,
    cb: (err: any, data?: ListModelCardExportJobsCommandOutput) => void
  ): void;
  listModelCardExportJobs(
    args: ListModelCardExportJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListModelCardExportJobsCommandOutput) => void
  ): void;
  listModelCards(): Promise<ListModelCardsCommandOutput>;
  listModelCards(
    args: ListModelCardsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelCardsCommandOutput>;
  listModelCards(
    args: ListModelCardsCommandInput,
    cb: (err: any, data?: ListModelCardsCommandOutput) => void
  ): void;
  listModelCards(
    args: ListModelCardsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListModelCardsCommandOutput) => void
  ): void;
  listModelCardVersions(
    args: ListModelCardVersionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelCardVersionsCommandOutput>;
  listModelCardVersions(
    args: ListModelCardVersionsCommandInput,
    cb: (err: any, data?: ListModelCardVersionsCommandOutput) => void
  ): void;
  listModelCardVersions(
    args: ListModelCardVersionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListModelCardVersionsCommandOutput) => void
  ): void;
  listModelExplainabilityJobDefinitions(): Promise<ListModelExplainabilityJobDefinitionsCommandOutput>;
  listModelExplainabilityJobDefinitions(
    args: ListModelExplainabilityJobDefinitionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelExplainabilityJobDefinitionsCommandOutput>;
  listModelExplainabilityJobDefinitions(
    args: ListModelExplainabilityJobDefinitionsCommandInput,
    cb: (
      err: any,
      data?: ListModelExplainabilityJobDefinitionsCommandOutput
    ) => void
  ): void;
  listModelExplainabilityJobDefinitions(
    args: ListModelExplainabilityJobDefinitionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: ListModelExplainabilityJobDefinitionsCommandOutput
    ) => void
  ): void;
  listModelMetadata(): Promise<ListModelMetadataCommandOutput>;
  listModelMetadata(
    args: ListModelMetadataCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelMetadataCommandOutput>;
  listModelMetadata(
    args: ListModelMetadataCommandInput,
    cb: (err: any, data?: ListModelMetadataCommandOutput) => void
  ): void;
  listModelMetadata(
    args: ListModelMetadataCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListModelMetadataCommandOutput) => void
  ): void;
  listModelPackageGroups(): Promise<ListModelPackageGroupsCommandOutput>;
  listModelPackageGroups(
    args: ListModelPackageGroupsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelPackageGroupsCommandOutput>;
  listModelPackageGroups(
    args: ListModelPackageGroupsCommandInput,
    cb: (err: any, data?: ListModelPackageGroupsCommandOutput) => void
  ): void;
  listModelPackageGroups(
    args: ListModelPackageGroupsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListModelPackageGroupsCommandOutput) => void
  ): void;
  listModelPackages(): Promise<ListModelPackagesCommandOutput>;
  listModelPackages(
    args: ListModelPackagesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelPackagesCommandOutput>;
  listModelPackages(
    args: ListModelPackagesCommandInput,
    cb: (err: any, data?: ListModelPackagesCommandOutput) => void
  ): void;
  listModelPackages(
    args: ListModelPackagesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListModelPackagesCommandOutput) => void
  ): void;
  listModelQualityJobDefinitions(): Promise<ListModelQualityJobDefinitionsCommandOutput>;
  listModelQualityJobDefinitions(
    args: ListModelQualityJobDefinitionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelQualityJobDefinitionsCommandOutput>;
  listModelQualityJobDefinitions(
    args: ListModelQualityJobDefinitionsCommandInput,
    cb: (err: any, data?: ListModelQualityJobDefinitionsCommandOutput) => void
  ): void;
  listModelQualityJobDefinitions(
    args: ListModelQualityJobDefinitionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListModelQualityJobDefinitionsCommandOutput) => void
  ): void;
  listModels(): Promise<ListModelsCommandOutput>;
  listModels(
    args: ListModelsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListModelsCommandOutput>;
  listModels(
    args: ListModelsCommandInput,
    cb: (err: any, data?: ListModelsCommandOutput) => void
  ): void;
  listModels(
    args: ListModelsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListModelsCommandOutput) => void
  ): void;
  listMonitoringAlertHistory(): Promise<ListMonitoringAlertHistoryCommandOutput>;
  listMonitoringAlertHistory(
    args: ListMonitoringAlertHistoryCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListMonitoringAlertHistoryCommandOutput>;
  listMonitoringAlertHistory(
    args: ListMonitoringAlertHistoryCommandInput,
    cb: (err: any, data?: ListMonitoringAlertHistoryCommandOutput) => void
  ): void;
  listMonitoringAlertHistory(
    args: ListMonitoringAlertHistoryCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListMonitoringAlertHistoryCommandOutput) => void
  ): void;
  listMonitoringAlerts(
    args: ListMonitoringAlertsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListMonitoringAlertsCommandOutput>;
  listMonitoringAlerts(
    args: ListMonitoringAlertsCommandInput,
    cb: (err: any, data?: ListMonitoringAlertsCommandOutput) => void
  ): void;
  listMonitoringAlerts(
    args: ListMonitoringAlertsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListMonitoringAlertsCommandOutput) => void
  ): void;
  listMonitoringExecutions(): Promise<ListMonitoringExecutionsCommandOutput>;
  listMonitoringExecutions(
    args: ListMonitoringExecutionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListMonitoringExecutionsCommandOutput>;
  listMonitoringExecutions(
    args: ListMonitoringExecutionsCommandInput,
    cb: (err: any, data?: ListMonitoringExecutionsCommandOutput) => void
  ): void;
  listMonitoringExecutions(
    args: ListMonitoringExecutionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListMonitoringExecutionsCommandOutput) => void
  ): void;
  listMonitoringSchedules(): Promise<ListMonitoringSchedulesCommandOutput>;
  listMonitoringSchedules(
    args: ListMonitoringSchedulesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListMonitoringSchedulesCommandOutput>;
  listMonitoringSchedules(
    args: ListMonitoringSchedulesCommandInput,
    cb: (err: any, data?: ListMonitoringSchedulesCommandOutput) => void
  ): void;
  listMonitoringSchedules(
    args: ListMonitoringSchedulesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListMonitoringSchedulesCommandOutput) => void
  ): void;
  listNotebookInstanceLifecycleConfigs(): Promise<ListNotebookInstanceLifecycleConfigsCommandOutput>;
  listNotebookInstanceLifecycleConfigs(
    args: ListNotebookInstanceLifecycleConfigsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListNotebookInstanceLifecycleConfigsCommandOutput>;
  listNotebookInstanceLifecycleConfigs(
    args: ListNotebookInstanceLifecycleConfigsCommandInput,
    cb: (
      err: any,
      data?: ListNotebookInstanceLifecycleConfigsCommandOutput
    ) => void
  ): void;
  listNotebookInstanceLifecycleConfigs(
    args: ListNotebookInstanceLifecycleConfigsCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: ListNotebookInstanceLifecycleConfigsCommandOutput
    ) => void
  ): void;
  listNotebookInstances(): Promise<ListNotebookInstancesCommandOutput>;
  listNotebookInstances(
    args: ListNotebookInstancesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListNotebookInstancesCommandOutput>;
  listNotebookInstances(
    args: ListNotebookInstancesCommandInput,
    cb: (err: any, data?: ListNotebookInstancesCommandOutput) => void
  ): void;
  listNotebookInstances(
    args: ListNotebookInstancesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListNotebookInstancesCommandOutput) => void
  ): void;
  listOptimizationJobs(): Promise<ListOptimizationJobsCommandOutput>;
  listOptimizationJobs(
    args: ListOptimizationJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListOptimizationJobsCommandOutput>;
  listOptimizationJobs(
    args: ListOptimizationJobsCommandInput,
    cb: (err: any, data?: ListOptimizationJobsCommandOutput) => void
  ): void;
  listOptimizationJobs(
    args: ListOptimizationJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListOptimizationJobsCommandOutput) => void
  ): void;
  listPartnerApps(): Promise<ListPartnerAppsCommandOutput>;
  listPartnerApps(
    args: ListPartnerAppsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListPartnerAppsCommandOutput>;
  listPartnerApps(
    args: ListPartnerAppsCommandInput,
    cb: (err: any, data?: ListPartnerAppsCommandOutput) => void
  ): void;
  listPartnerApps(
    args: ListPartnerAppsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListPartnerAppsCommandOutput) => void
  ): void;
  listPipelineExecutions(
    args: ListPipelineExecutionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListPipelineExecutionsCommandOutput>;
  listPipelineExecutions(
    args: ListPipelineExecutionsCommandInput,
    cb: (err: any, data?: ListPipelineExecutionsCommandOutput) => void
  ): void;
  listPipelineExecutions(
    args: ListPipelineExecutionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListPipelineExecutionsCommandOutput) => void
  ): void;
  listPipelineExecutionSteps(): Promise<ListPipelineExecutionStepsCommandOutput>;
  listPipelineExecutionSteps(
    args: ListPipelineExecutionStepsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListPipelineExecutionStepsCommandOutput>;
  listPipelineExecutionSteps(
    args: ListPipelineExecutionStepsCommandInput,
    cb: (err: any, data?: ListPipelineExecutionStepsCommandOutput) => void
  ): void;
  listPipelineExecutionSteps(
    args: ListPipelineExecutionStepsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListPipelineExecutionStepsCommandOutput) => void
  ): void;
  listPipelineParametersForExecution(
    args: ListPipelineParametersForExecutionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListPipelineParametersForExecutionCommandOutput>;
  listPipelineParametersForExecution(
    args: ListPipelineParametersForExecutionCommandInput,
    cb: (
      err: any,
      data?: ListPipelineParametersForExecutionCommandOutput
    ) => void
  ): void;
  listPipelineParametersForExecution(
    args: ListPipelineParametersForExecutionCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: ListPipelineParametersForExecutionCommandOutput
    ) => void
  ): void;
  listPipelines(): Promise<ListPipelinesCommandOutput>;
  listPipelines(
    args: ListPipelinesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListPipelinesCommandOutput>;
  listPipelines(
    args: ListPipelinesCommandInput,
    cb: (err: any, data?: ListPipelinesCommandOutput) => void
  ): void;
  listPipelines(
    args: ListPipelinesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListPipelinesCommandOutput) => void
  ): void;
  listPipelineVersions(
    args: ListPipelineVersionsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListPipelineVersionsCommandOutput>;
  listPipelineVersions(
    args: ListPipelineVersionsCommandInput,
    cb: (err: any, data?: ListPipelineVersionsCommandOutput) => void
  ): void;
  listPipelineVersions(
    args: ListPipelineVersionsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListPipelineVersionsCommandOutput) => void
  ): void;
  listProcessingJobs(): Promise<ListProcessingJobsCommandOutput>;
  listProcessingJobs(
    args: ListProcessingJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListProcessingJobsCommandOutput>;
  listProcessingJobs(
    args: ListProcessingJobsCommandInput,
    cb: (err: any, data?: ListProcessingJobsCommandOutput) => void
  ): void;
  listProcessingJobs(
    args: ListProcessingJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListProcessingJobsCommandOutput) => void
  ): void;
  listProjects(): Promise<ListProjectsCommandOutput>;
  listProjects(
    args: ListProjectsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListProjectsCommandOutput>;
  listProjects(
    args: ListProjectsCommandInput,
    cb: (err: any, data?: ListProjectsCommandOutput) => void
  ): void;
  listProjects(
    args: ListProjectsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListProjectsCommandOutput) => void
  ): void;
  listResourceCatalogs(): Promise<ListResourceCatalogsCommandOutput>;
  listResourceCatalogs(
    args: ListResourceCatalogsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListResourceCatalogsCommandOutput>;
  listResourceCatalogs(
    args: ListResourceCatalogsCommandInput,
    cb: (err: any, data?: ListResourceCatalogsCommandOutput) => void
  ): void;
  listResourceCatalogs(
    args: ListResourceCatalogsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListResourceCatalogsCommandOutput) => void
  ): void;
  listSpaces(): Promise<ListSpacesCommandOutput>;
  listSpaces(
    args: ListSpacesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListSpacesCommandOutput>;
  listSpaces(
    args: ListSpacesCommandInput,
    cb: (err: any, data?: ListSpacesCommandOutput) => void
  ): void;
  listSpaces(
    args: ListSpacesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListSpacesCommandOutput) => void
  ): void;
  listStageDevices(
    args: ListStageDevicesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListStageDevicesCommandOutput>;
  listStageDevices(
    args: ListStageDevicesCommandInput,
    cb: (err: any, data?: ListStageDevicesCommandOutput) => void
  ): void;
  listStageDevices(
    args: ListStageDevicesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListStageDevicesCommandOutput) => void
  ): void;
  listStudioLifecycleConfigs(): Promise<ListStudioLifecycleConfigsCommandOutput>;
  listStudioLifecycleConfigs(
    args: ListStudioLifecycleConfigsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListStudioLifecycleConfigsCommandOutput>;
  listStudioLifecycleConfigs(
    args: ListStudioLifecycleConfigsCommandInput,
    cb: (err: any, data?: ListStudioLifecycleConfigsCommandOutput) => void
  ): void;
  listStudioLifecycleConfigs(
    args: ListStudioLifecycleConfigsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListStudioLifecycleConfigsCommandOutput) => void
  ): void;
  listSubscribedWorkteams(): Promise<ListSubscribedWorkteamsCommandOutput>;
  listSubscribedWorkteams(
    args: ListSubscribedWorkteamsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListSubscribedWorkteamsCommandOutput>;
  listSubscribedWorkteams(
    args: ListSubscribedWorkteamsCommandInput,
    cb: (err: any, data?: ListSubscribedWorkteamsCommandOutput) => void
  ): void;
  listSubscribedWorkteams(
    args: ListSubscribedWorkteamsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListSubscribedWorkteamsCommandOutput) => void
  ): void;
  listTags(
    args: ListTagsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListTagsCommandOutput>;
  listTags(
    args: ListTagsCommandInput,
    cb: (err: any, data?: ListTagsCommandOutput) => void
  ): void;
  listTags(
    args: ListTagsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListTagsCommandOutput) => void
  ): void;
  listTrainingJobs(): Promise<ListTrainingJobsCommandOutput>;
  listTrainingJobs(
    args: ListTrainingJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListTrainingJobsCommandOutput>;
  listTrainingJobs(
    args: ListTrainingJobsCommandInput,
    cb: (err: any, data?: ListTrainingJobsCommandOutput) => void
  ): void;
  listTrainingJobs(
    args: ListTrainingJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListTrainingJobsCommandOutput) => void
  ): void;
  listTrainingJobsForHyperParameterTuningJob(
    args: ListTrainingJobsForHyperParameterTuningJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListTrainingJobsForHyperParameterTuningJobCommandOutput>;
  listTrainingJobsForHyperParameterTuningJob(
    args: ListTrainingJobsForHyperParameterTuningJobCommandInput,
    cb: (
      err: any,
      data?: ListTrainingJobsForHyperParameterTuningJobCommandOutput
    ) => void
  ): void;
  listTrainingJobsForHyperParameterTuningJob(
    args: ListTrainingJobsForHyperParameterTuningJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: ListTrainingJobsForHyperParameterTuningJobCommandOutput
    ) => void
  ): void;
  listTrainingPlans(): Promise<ListTrainingPlansCommandOutput>;
  listTrainingPlans(
    args: ListTrainingPlansCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListTrainingPlansCommandOutput>;
  listTrainingPlans(
    args: ListTrainingPlansCommandInput,
    cb: (err: any, data?: ListTrainingPlansCommandOutput) => void
  ): void;
  listTrainingPlans(
    args: ListTrainingPlansCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListTrainingPlansCommandOutput) => void
  ): void;
  listTransformJobs(): Promise<ListTransformJobsCommandOutput>;
  listTransformJobs(
    args: ListTransformJobsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListTransformJobsCommandOutput>;
  listTransformJobs(
    args: ListTransformJobsCommandInput,
    cb: (err: any, data?: ListTransformJobsCommandOutput) => void
  ): void;
  listTransformJobs(
    args: ListTransformJobsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListTransformJobsCommandOutput) => void
  ): void;
  listTrialComponents(): Promise<ListTrialComponentsCommandOutput>;
  listTrialComponents(
    args: ListTrialComponentsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListTrialComponentsCommandOutput>;
  listTrialComponents(
    args: ListTrialComponentsCommandInput,
    cb: (err: any, data?: ListTrialComponentsCommandOutput) => void
  ): void;
  listTrialComponents(
    args: ListTrialComponentsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListTrialComponentsCommandOutput) => void
  ): void;
  listTrials(): Promise<ListTrialsCommandOutput>;
  listTrials(
    args: ListTrialsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListTrialsCommandOutput>;
  listTrials(
    args: ListTrialsCommandInput,
    cb: (err: any, data?: ListTrialsCommandOutput) => void
  ): void;
  listTrials(
    args: ListTrialsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListTrialsCommandOutput) => void
  ): void;
  listUltraServersByReservedCapacity(
    args: ListUltraServersByReservedCapacityCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListUltraServersByReservedCapacityCommandOutput>;
  listUltraServersByReservedCapacity(
    args: ListUltraServersByReservedCapacityCommandInput,
    cb: (
      err: any,
      data?: ListUltraServersByReservedCapacityCommandOutput
    ) => void
  ): void;
  listUltraServersByReservedCapacity(
    args: ListUltraServersByReservedCapacityCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: ListUltraServersByReservedCapacityCommandOutput
    ) => void
  ): void;
  listUserProfiles(): Promise<ListUserProfilesCommandOutput>;
  listUserProfiles(
    args: ListUserProfilesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListUserProfilesCommandOutput>;
  listUserProfiles(
    args: ListUserProfilesCommandInput,
    cb: (err: any, data?: ListUserProfilesCommandOutput) => void
  ): void;
  listUserProfiles(
    args: ListUserProfilesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListUserProfilesCommandOutput) => void
  ): void;
  listWorkforces(): Promise<ListWorkforcesCommandOutput>;
  listWorkforces(
    args: ListWorkforcesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListWorkforcesCommandOutput>;
  listWorkforces(
    args: ListWorkforcesCommandInput,
    cb: (err: any, data?: ListWorkforcesCommandOutput) => void
  ): void;
  listWorkforces(
    args: ListWorkforcesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListWorkforcesCommandOutput) => void
  ): void;
  listWorkteams(): Promise<ListWorkteamsCommandOutput>;
  listWorkteams(
    args: ListWorkteamsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<ListWorkteamsCommandOutput>;
  listWorkteams(
    args: ListWorkteamsCommandInput,
    cb: (err: any, data?: ListWorkteamsCommandOutput) => void
  ): void;
  listWorkteams(
    args: ListWorkteamsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: ListWorkteamsCommandOutput) => void
  ): void;
  putModelPackageGroupPolicy(
    args: PutModelPackageGroupPolicyCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<PutModelPackageGroupPolicyCommandOutput>;
  putModelPackageGroupPolicy(
    args: PutModelPackageGroupPolicyCommandInput,
    cb: (err: any, data?: PutModelPackageGroupPolicyCommandOutput) => void
  ): void;
  putModelPackageGroupPolicy(
    args: PutModelPackageGroupPolicyCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: PutModelPackageGroupPolicyCommandOutput) => void
  ): void;
  queryLineage(): Promise<QueryLineageCommandOutput>;
  queryLineage(
    args: QueryLineageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<QueryLineageCommandOutput>;
  queryLineage(
    args: QueryLineageCommandInput,
    cb: (err: any, data?: QueryLineageCommandOutput) => void
  ): void;
  queryLineage(
    args: QueryLineageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: QueryLineageCommandOutput) => void
  ): void;
  registerDevices(
    args: RegisterDevicesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<RegisterDevicesCommandOutput>;
  registerDevices(
    args: RegisterDevicesCommandInput,
    cb: (err: any, data?: RegisterDevicesCommandOutput) => void
  ): void;
  registerDevices(
    args: RegisterDevicesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: RegisterDevicesCommandOutput) => void
  ): void;
  renderUiTemplate(
    args: RenderUiTemplateCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<RenderUiTemplateCommandOutput>;
  renderUiTemplate(
    args: RenderUiTemplateCommandInput,
    cb: (err: any, data?: RenderUiTemplateCommandOutput) => void
  ): void;
  renderUiTemplate(
    args: RenderUiTemplateCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: RenderUiTemplateCommandOutput) => void
  ): void;
  retryPipelineExecution(
    args: RetryPipelineExecutionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<RetryPipelineExecutionCommandOutput>;
  retryPipelineExecution(
    args: RetryPipelineExecutionCommandInput,
    cb: (err: any, data?: RetryPipelineExecutionCommandOutput) => void
  ): void;
  retryPipelineExecution(
    args: RetryPipelineExecutionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: RetryPipelineExecutionCommandOutput) => void
  ): void;
  search(
    args: SearchCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<SearchCommandOutput>;
  search(
    args: SearchCommandInput,
    cb: (err: any, data?: SearchCommandOutput) => void
  ): void;
  search(
    args: SearchCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: SearchCommandOutput) => void
  ): void;
  searchTrainingPlanOfferings(): Promise<SearchTrainingPlanOfferingsCommandOutput>;
  searchTrainingPlanOfferings(
    args: SearchTrainingPlanOfferingsCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<SearchTrainingPlanOfferingsCommandOutput>;
  searchTrainingPlanOfferings(
    args: SearchTrainingPlanOfferingsCommandInput,
    cb: (err: any, data?: SearchTrainingPlanOfferingsCommandOutput) => void
  ): void;
  searchTrainingPlanOfferings(
    args: SearchTrainingPlanOfferingsCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: SearchTrainingPlanOfferingsCommandOutput) => void
  ): void;
  sendPipelineExecutionStepFailure(
    args: SendPipelineExecutionStepFailureCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<SendPipelineExecutionStepFailureCommandOutput>;
  sendPipelineExecutionStepFailure(
    args: SendPipelineExecutionStepFailureCommandInput,
    cb: (err: any, data?: SendPipelineExecutionStepFailureCommandOutput) => void
  ): void;
  sendPipelineExecutionStepFailure(
    args: SendPipelineExecutionStepFailureCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: SendPipelineExecutionStepFailureCommandOutput) => void
  ): void;
  sendPipelineExecutionStepSuccess(
    args: SendPipelineExecutionStepSuccessCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<SendPipelineExecutionStepSuccessCommandOutput>;
  sendPipelineExecutionStepSuccess(
    args: SendPipelineExecutionStepSuccessCommandInput,
    cb: (err: any, data?: SendPipelineExecutionStepSuccessCommandOutput) => void
  ): void;
  sendPipelineExecutionStepSuccess(
    args: SendPipelineExecutionStepSuccessCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: SendPipelineExecutionStepSuccessCommandOutput) => void
  ): void;
  startEdgeDeploymentStage(
    args: StartEdgeDeploymentStageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StartEdgeDeploymentStageCommandOutput>;
  startEdgeDeploymentStage(
    args: StartEdgeDeploymentStageCommandInput,
    cb: (err: any, data?: StartEdgeDeploymentStageCommandOutput) => void
  ): void;
  startEdgeDeploymentStage(
    args: StartEdgeDeploymentStageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StartEdgeDeploymentStageCommandOutput) => void
  ): void;
  startInferenceExperiment(
    args: StartInferenceExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StartInferenceExperimentCommandOutput>;
  startInferenceExperiment(
    args: StartInferenceExperimentCommandInput,
    cb: (err: any, data?: StartInferenceExperimentCommandOutput) => void
  ): void;
  startInferenceExperiment(
    args: StartInferenceExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StartInferenceExperimentCommandOutput) => void
  ): void;
  startMlflowTrackingServer(
    args: StartMlflowTrackingServerCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StartMlflowTrackingServerCommandOutput>;
  startMlflowTrackingServer(
    args: StartMlflowTrackingServerCommandInput,
    cb: (err: any, data?: StartMlflowTrackingServerCommandOutput) => void
  ): void;
  startMlflowTrackingServer(
    args: StartMlflowTrackingServerCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StartMlflowTrackingServerCommandOutput) => void
  ): void;
  startMonitoringSchedule(
    args: StartMonitoringScheduleCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StartMonitoringScheduleCommandOutput>;
  startMonitoringSchedule(
    args: StartMonitoringScheduleCommandInput,
    cb: (err: any, data?: StartMonitoringScheduleCommandOutput) => void
  ): void;
  startMonitoringSchedule(
    args: StartMonitoringScheduleCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StartMonitoringScheduleCommandOutput) => void
  ): void;
  startNotebookInstance(
    args: StartNotebookInstanceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StartNotebookInstanceCommandOutput>;
  startNotebookInstance(
    args: StartNotebookInstanceCommandInput,
    cb: (err: any, data?: StartNotebookInstanceCommandOutput) => void
  ): void;
  startNotebookInstance(
    args: StartNotebookInstanceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StartNotebookInstanceCommandOutput) => void
  ): void;
  startPipelineExecution(
    args: StartPipelineExecutionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StartPipelineExecutionCommandOutput>;
  startPipelineExecution(
    args: StartPipelineExecutionCommandInput,
    cb: (err: any, data?: StartPipelineExecutionCommandOutput) => void
  ): void;
  startPipelineExecution(
    args: StartPipelineExecutionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StartPipelineExecutionCommandOutput) => void
  ): void;
  startSession(
    args: StartSessionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StartSessionCommandOutput>;
  startSession(
    args: StartSessionCommandInput,
    cb: (err: any, data?: StartSessionCommandOutput) => void
  ): void;
  startSession(
    args: StartSessionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StartSessionCommandOutput) => void
  ): void;
  stopAutoMLJob(
    args: StopAutoMLJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopAutoMLJobCommandOutput>;
  stopAutoMLJob(
    args: StopAutoMLJobCommandInput,
    cb: (err: any, data?: StopAutoMLJobCommandOutput) => void
  ): void;
  stopAutoMLJob(
    args: StopAutoMLJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopAutoMLJobCommandOutput) => void
  ): void;
  stopCompilationJob(
    args: StopCompilationJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopCompilationJobCommandOutput>;
  stopCompilationJob(
    args: StopCompilationJobCommandInput,
    cb: (err: any, data?: StopCompilationJobCommandOutput) => void
  ): void;
  stopCompilationJob(
    args: StopCompilationJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopCompilationJobCommandOutput) => void
  ): void;
  stopEdgeDeploymentStage(
    args: StopEdgeDeploymentStageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopEdgeDeploymentStageCommandOutput>;
  stopEdgeDeploymentStage(
    args: StopEdgeDeploymentStageCommandInput,
    cb: (err: any, data?: StopEdgeDeploymentStageCommandOutput) => void
  ): void;
  stopEdgeDeploymentStage(
    args: StopEdgeDeploymentStageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopEdgeDeploymentStageCommandOutput) => void
  ): void;
  stopEdgePackagingJob(
    args: StopEdgePackagingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopEdgePackagingJobCommandOutput>;
  stopEdgePackagingJob(
    args: StopEdgePackagingJobCommandInput,
    cb: (err: any, data?: StopEdgePackagingJobCommandOutput) => void
  ): void;
  stopEdgePackagingJob(
    args: StopEdgePackagingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopEdgePackagingJobCommandOutput) => void
  ): void;
  stopHyperParameterTuningJob(
    args: StopHyperParameterTuningJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopHyperParameterTuningJobCommandOutput>;
  stopHyperParameterTuningJob(
    args: StopHyperParameterTuningJobCommandInput,
    cb: (err: any, data?: StopHyperParameterTuningJobCommandOutput) => void
  ): void;
  stopHyperParameterTuningJob(
    args: StopHyperParameterTuningJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopHyperParameterTuningJobCommandOutput) => void
  ): void;
  stopInferenceExperiment(
    args: StopInferenceExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopInferenceExperimentCommandOutput>;
  stopInferenceExperiment(
    args: StopInferenceExperimentCommandInput,
    cb: (err: any, data?: StopInferenceExperimentCommandOutput) => void
  ): void;
  stopInferenceExperiment(
    args: StopInferenceExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopInferenceExperimentCommandOutput) => void
  ): void;
  stopInferenceRecommendationsJob(
    args: StopInferenceRecommendationsJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopInferenceRecommendationsJobCommandOutput>;
  stopInferenceRecommendationsJob(
    args: StopInferenceRecommendationsJobCommandInput,
    cb: (err: any, data?: StopInferenceRecommendationsJobCommandOutput) => void
  ): void;
  stopInferenceRecommendationsJob(
    args: StopInferenceRecommendationsJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopInferenceRecommendationsJobCommandOutput) => void
  ): void;
  stopLabelingJob(
    args: StopLabelingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopLabelingJobCommandOutput>;
  stopLabelingJob(
    args: StopLabelingJobCommandInput,
    cb: (err: any, data?: StopLabelingJobCommandOutput) => void
  ): void;
  stopLabelingJob(
    args: StopLabelingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopLabelingJobCommandOutput) => void
  ): void;
  stopMlflowTrackingServer(
    args: StopMlflowTrackingServerCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopMlflowTrackingServerCommandOutput>;
  stopMlflowTrackingServer(
    args: StopMlflowTrackingServerCommandInput,
    cb: (err: any, data?: StopMlflowTrackingServerCommandOutput) => void
  ): void;
  stopMlflowTrackingServer(
    args: StopMlflowTrackingServerCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopMlflowTrackingServerCommandOutput) => void
  ): void;
  stopMonitoringSchedule(
    args: StopMonitoringScheduleCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopMonitoringScheduleCommandOutput>;
  stopMonitoringSchedule(
    args: StopMonitoringScheduleCommandInput,
    cb: (err: any, data?: StopMonitoringScheduleCommandOutput) => void
  ): void;
  stopMonitoringSchedule(
    args: StopMonitoringScheduleCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopMonitoringScheduleCommandOutput) => void
  ): void;
  stopNotebookInstance(
    args: StopNotebookInstanceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopNotebookInstanceCommandOutput>;
  stopNotebookInstance(
    args: StopNotebookInstanceCommandInput,
    cb: (err: any, data?: StopNotebookInstanceCommandOutput) => void
  ): void;
  stopNotebookInstance(
    args: StopNotebookInstanceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopNotebookInstanceCommandOutput) => void
  ): void;
  stopOptimizationJob(
    args: StopOptimizationJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopOptimizationJobCommandOutput>;
  stopOptimizationJob(
    args: StopOptimizationJobCommandInput,
    cb: (err: any, data?: StopOptimizationJobCommandOutput) => void
  ): void;
  stopOptimizationJob(
    args: StopOptimizationJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopOptimizationJobCommandOutput) => void
  ): void;
  stopPipelineExecution(
    args: StopPipelineExecutionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopPipelineExecutionCommandOutput>;
  stopPipelineExecution(
    args: StopPipelineExecutionCommandInput,
    cb: (err: any, data?: StopPipelineExecutionCommandOutput) => void
  ): void;
  stopPipelineExecution(
    args: StopPipelineExecutionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopPipelineExecutionCommandOutput) => void
  ): void;
  stopProcessingJob(
    args: StopProcessingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopProcessingJobCommandOutput>;
  stopProcessingJob(
    args: StopProcessingJobCommandInput,
    cb: (err: any, data?: StopProcessingJobCommandOutput) => void
  ): void;
  stopProcessingJob(
    args: StopProcessingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopProcessingJobCommandOutput) => void
  ): void;
  stopTrainingJob(
    args: StopTrainingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopTrainingJobCommandOutput>;
  stopTrainingJob(
    args: StopTrainingJobCommandInput,
    cb: (err: any, data?: StopTrainingJobCommandOutput) => void
  ): void;
  stopTrainingJob(
    args: StopTrainingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopTrainingJobCommandOutput) => void
  ): void;
  stopTransformJob(
    args: StopTransformJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<StopTransformJobCommandOutput>;
  stopTransformJob(
    args: StopTransformJobCommandInput,
    cb: (err: any, data?: StopTransformJobCommandOutput) => void
  ): void;
  stopTransformJob(
    args: StopTransformJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: StopTransformJobCommandOutput) => void
  ): void;
  updateAction(
    args: UpdateActionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateActionCommandOutput>;
  updateAction(
    args: UpdateActionCommandInput,
    cb: (err: any, data?: UpdateActionCommandOutput) => void
  ): void;
  updateAction(
    args: UpdateActionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateActionCommandOutput) => void
  ): void;
  updateAppImageConfig(
    args: UpdateAppImageConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateAppImageConfigCommandOutput>;
  updateAppImageConfig(
    args: UpdateAppImageConfigCommandInput,
    cb: (err: any, data?: UpdateAppImageConfigCommandOutput) => void
  ): void;
  updateAppImageConfig(
    args: UpdateAppImageConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateAppImageConfigCommandOutput) => void
  ): void;
  updateArtifact(
    args: UpdateArtifactCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateArtifactCommandOutput>;
  updateArtifact(
    args: UpdateArtifactCommandInput,
    cb: (err: any, data?: UpdateArtifactCommandOutput) => void
  ): void;
  updateArtifact(
    args: UpdateArtifactCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateArtifactCommandOutput) => void
  ): void;
  updateCluster(
    args: UpdateClusterCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateClusterCommandOutput>;
  updateCluster(
    args: UpdateClusterCommandInput,
    cb: (err: any, data?: UpdateClusterCommandOutput) => void
  ): void;
  updateCluster(
    args: UpdateClusterCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateClusterCommandOutput) => void
  ): void;
  updateClusterSchedulerConfig(
    args: UpdateClusterSchedulerConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateClusterSchedulerConfigCommandOutput>;
  updateClusterSchedulerConfig(
    args: UpdateClusterSchedulerConfigCommandInput,
    cb: (err: any, data?: UpdateClusterSchedulerConfigCommandOutput) => void
  ): void;
  updateClusterSchedulerConfig(
    args: UpdateClusterSchedulerConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateClusterSchedulerConfigCommandOutput) => void
  ): void;
  updateClusterSoftware(
    args: UpdateClusterSoftwareCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateClusterSoftwareCommandOutput>;
  updateClusterSoftware(
    args: UpdateClusterSoftwareCommandInput,
    cb: (err: any, data?: UpdateClusterSoftwareCommandOutput) => void
  ): void;
  updateClusterSoftware(
    args: UpdateClusterSoftwareCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateClusterSoftwareCommandOutput) => void
  ): void;
  updateCodeRepository(
    args: UpdateCodeRepositoryCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateCodeRepositoryCommandOutput>;
  updateCodeRepository(
    args: UpdateCodeRepositoryCommandInput,
    cb: (err: any, data?: UpdateCodeRepositoryCommandOutput) => void
  ): void;
  updateCodeRepository(
    args: UpdateCodeRepositoryCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateCodeRepositoryCommandOutput) => void
  ): void;
  updateComputeQuota(
    args: UpdateComputeQuotaCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateComputeQuotaCommandOutput>;
  updateComputeQuota(
    args: UpdateComputeQuotaCommandInput,
    cb: (err: any, data?: UpdateComputeQuotaCommandOutput) => void
  ): void;
  updateComputeQuota(
    args: UpdateComputeQuotaCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateComputeQuotaCommandOutput) => void
  ): void;
  updateContext(
    args: UpdateContextCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateContextCommandOutput>;
  updateContext(
    args: UpdateContextCommandInput,
    cb: (err: any, data?: UpdateContextCommandOutput) => void
  ): void;
  updateContext(
    args: UpdateContextCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateContextCommandOutput) => void
  ): void;
  updateDeviceFleet(
    args: UpdateDeviceFleetCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateDeviceFleetCommandOutput>;
  updateDeviceFleet(
    args: UpdateDeviceFleetCommandInput,
    cb: (err: any, data?: UpdateDeviceFleetCommandOutput) => void
  ): void;
  updateDeviceFleet(
    args: UpdateDeviceFleetCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateDeviceFleetCommandOutput) => void
  ): void;
  updateDevices(
    args: UpdateDevicesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateDevicesCommandOutput>;
  updateDevices(
    args: UpdateDevicesCommandInput,
    cb: (err: any, data?: UpdateDevicesCommandOutput) => void
  ): void;
  updateDevices(
    args: UpdateDevicesCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateDevicesCommandOutput) => void
  ): void;
  updateDomain(
    args: UpdateDomainCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateDomainCommandOutput>;
  updateDomain(
    args: UpdateDomainCommandInput,
    cb: (err: any, data?: UpdateDomainCommandOutput) => void
  ): void;
  updateDomain(
    args: UpdateDomainCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateDomainCommandOutput) => void
  ): void;
  updateEndpoint(
    args: UpdateEndpointCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateEndpointCommandOutput>;
  updateEndpoint(
    args: UpdateEndpointCommandInput,
    cb: (err: any, data?: UpdateEndpointCommandOutput) => void
  ): void;
  updateEndpoint(
    args: UpdateEndpointCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateEndpointCommandOutput) => void
  ): void;
  updateEndpointWeightsAndCapacities(
    args: UpdateEndpointWeightsAndCapacitiesCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateEndpointWeightsAndCapacitiesCommandOutput>;
  updateEndpointWeightsAndCapacities(
    args: UpdateEndpointWeightsAndCapacitiesCommandInput,
    cb: (
      err: any,
      data?: UpdateEndpointWeightsAndCapacitiesCommandOutput
    ) => void
  ): void;
  updateEndpointWeightsAndCapacities(
    args: UpdateEndpointWeightsAndCapacitiesCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: UpdateEndpointWeightsAndCapacitiesCommandOutput
    ) => void
  ): void;
  updateExperiment(
    args: UpdateExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateExperimentCommandOutput>;
  updateExperiment(
    args: UpdateExperimentCommandInput,
    cb: (err: any, data?: UpdateExperimentCommandOutput) => void
  ): void;
  updateExperiment(
    args: UpdateExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateExperimentCommandOutput) => void
  ): void;
  updateFeatureGroup(
    args: UpdateFeatureGroupCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateFeatureGroupCommandOutput>;
  updateFeatureGroup(
    args: UpdateFeatureGroupCommandInput,
    cb: (err: any, data?: UpdateFeatureGroupCommandOutput) => void
  ): void;
  updateFeatureGroup(
    args: UpdateFeatureGroupCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateFeatureGroupCommandOutput) => void
  ): void;
  updateFeatureMetadata(
    args: UpdateFeatureMetadataCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateFeatureMetadataCommandOutput>;
  updateFeatureMetadata(
    args: UpdateFeatureMetadataCommandInput,
    cb: (err: any, data?: UpdateFeatureMetadataCommandOutput) => void
  ): void;
  updateFeatureMetadata(
    args: UpdateFeatureMetadataCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateFeatureMetadataCommandOutput) => void
  ): void;
  updateHub(
    args: UpdateHubCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateHubCommandOutput>;
  updateHub(
    args: UpdateHubCommandInput,
    cb: (err: any, data?: UpdateHubCommandOutput) => void
  ): void;
  updateHub(
    args: UpdateHubCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateHubCommandOutput) => void
  ): void;
  updateHubContent(
    args: UpdateHubContentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateHubContentCommandOutput>;
  updateHubContent(
    args: UpdateHubContentCommandInput,
    cb: (err: any, data?: UpdateHubContentCommandOutput) => void
  ): void;
  updateHubContent(
    args: UpdateHubContentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateHubContentCommandOutput) => void
  ): void;
  updateHubContentReference(
    args: UpdateHubContentReferenceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateHubContentReferenceCommandOutput>;
  updateHubContentReference(
    args: UpdateHubContentReferenceCommandInput,
    cb: (err: any, data?: UpdateHubContentReferenceCommandOutput) => void
  ): void;
  updateHubContentReference(
    args: UpdateHubContentReferenceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateHubContentReferenceCommandOutput) => void
  ): void;
  updateImage(
    args: UpdateImageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateImageCommandOutput>;
  updateImage(
    args: UpdateImageCommandInput,
    cb: (err: any, data?: UpdateImageCommandOutput) => void
  ): void;
  updateImage(
    args: UpdateImageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateImageCommandOutput) => void
  ): void;
  updateImageVersion(
    args: UpdateImageVersionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateImageVersionCommandOutput>;
  updateImageVersion(
    args: UpdateImageVersionCommandInput,
    cb: (err: any, data?: UpdateImageVersionCommandOutput) => void
  ): void;
  updateImageVersion(
    args: UpdateImageVersionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateImageVersionCommandOutput) => void
  ): void;
  updateInferenceComponent(
    args: UpdateInferenceComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateInferenceComponentCommandOutput>;
  updateInferenceComponent(
    args: UpdateInferenceComponentCommandInput,
    cb: (err: any, data?: UpdateInferenceComponentCommandOutput) => void
  ): void;
  updateInferenceComponent(
    args: UpdateInferenceComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateInferenceComponentCommandOutput) => void
  ): void;
  updateInferenceComponentRuntimeConfig(
    args: UpdateInferenceComponentRuntimeConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateInferenceComponentRuntimeConfigCommandOutput>;
  updateInferenceComponentRuntimeConfig(
    args: UpdateInferenceComponentRuntimeConfigCommandInput,
    cb: (
      err: any,
      data?: UpdateInferenceComponentRuntimeConfigCommandOutput
    ) => void
  ): void;
  updateInferenceComponentRuntimeConfig(
    args: UpdateInferenceComponentRuntimeConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: UpdateInferenceComponentRuntimeConfigCommandOutput
    ) => void
  ): void;
  updateInferenceExperiment(
    args: UpdateInferenceExperimentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateInferenceExperimentCommandOutput>;
  updateInferenceExperiment(
    args: UpdateInferenceExperimentCommandInput,
    cb: (err: any, data?: UpdateInferenceExperimentCommandOutput) => void
  ): void;
  updateInferenceExperiment(
    args: UpdateInferenceExperimentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateInferenceExperimentCommandOutput) => void
  ): void;
  updateMlflowApp(
    args: UpdateMlflowAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateMlflowAppCommandOutput>;
  updateMlflowApp(
    args: UpdateMlflowAppCommandInput,
    cb: (err: any, data?: UpdateMlflowAppCommandOutput) => void
  ): void;
  updateMlflowApp(
    args: UpdateMlflowAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateMlflowAppCommandOutput) => void
  ): void;
  updateMlflowTrackingServer(
    args: UpdateMlflowTrackingServerCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateMlflowTrackingServerCommandOutput>;
  updateMlflowTrackingServer(
    args: UpdateMlflowTrackingServerCommandInput,
    cb: (err: any, data?: UpdateMlflowTrackingServerCommandOutput) => void
  ): void;
  updateMlflowTrackingServer(
    args: UpdateMlflowTrackingServerCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateMlflowTrackingServerCommandOutput) => void
  ): void;
  updateModelCard(
    args: UpdateModelCardCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateModelCardCommandOutput>;
  updateModelCard(
    args: UpdateModelCardCommandInput,
    cb: (err: any, data?: UpdateModelCardCommandOutput) => void
  ): void;
  updateModelCard(
    args: UpdateModelCardCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateModelCardCommandOutput) => void
  ): void;
  updateModelPackage(
    args: UpdateModelPackageCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateModelPackageCommandOutput>;
  updateModelPackage(
    args: UpdateModelPackageCommandInput,
    cb: (err: any, data?: UpdateModelPackageCommandOutput) => void
  ): void;
  updateModelPackage(
    args: UpdateModelPackageCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateModelPackageCommandOutput) => void
  ): void;
  updateMonitoringAlert(
    args: UpdateMonitoringAlertCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateMonitoringAlertCommandOutput>;
  updateMonitoringAlert(
    args: UpdateMonitoringAlertCommandInput,
    cb: (err: any, data?: UpdateMonitoringAlertCommandOutput) => void
  ): void;
  updateMonitoringAlert(
    args: UpdateMonitoringAlertCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateMonitoringAlertCommandOutput) => void
  ): void;
  updateMonitoringSchedule(
    args: UpdateMonitoringScheduleCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateMonitoringScheduleCommandOutput>;
  updateMonitoringSchedule(
    args: UpdateMonitoringScheduleCommandInput,
    cb: (err: any, data?: UpdateMonitoringScheduleCommandOutput) => void
  ): void;
  updateMonitoringSchedule(
    args: UpdateMonitoringScheduleCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateMonitoringScheduleCommandOutput) => void
  ): void;
  updateNotebookInstance(
    args: UpdateNotebookInstanceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateNotebookInstanceCommandOutput>;
  updateNotebookInstance(
    args: UpdateNotebookInstanceCommandInput,
    cb: (err: any, data?: UpdateNotebookInstanceCommandOutput) => void
  ): void;
  updateNotebookInstance(
    args: UpdateNotebookInstanceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateNotebookInstanceCommandOutput) => void
  ): void;
  updateNotebookInstanceLifecycleConfig(
    args: UpdateNotebookInstanceLifecycleConfigCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateNotebookInstanceLifecycleConfigCommandOutput>;
  updateNotebookInstanceLifecycleConfig(
    args: UpdateNotebookInstanceLifecycleConfigCommandInput,
    cb: (
      err: any,
      data?: UpdateNotebookInstanceLifecycleConfigCommandOutput
    ) => void
  ): void;
  updateNotebookInstanceLifecycleConfig(
    args: UpdateNotebookInstanceLifecycleConfigCommandInput,
    options: __HttpHandlerOptions,
    cb: (
      err: any,
      data?: UpdateNotebookInstanceLifecycleConfigCommandOutput
    ) => void
  ): void;
  updatePartnerApp(
    args: UpdatePartnerAppCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdatePartnerAppCommandOutput>;
  updatePartnerApp(
    args: UpdatePartnerAppCommandInput,
    cb: (err: any, data?: UpdatePartnerAppCommandOutput) => void
  ): void;
  updatePartnerApp(
    args: UpdatePartnerAppCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdatePartnerAppCommandOutput) => void
  ): void;
  updatePipeline(
    args: UpdatePipelineCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdatePipelineCommandOutput>;
  updatePipeline(
    args: UpdatePipelineCommandInput,
    cb: (err: any, data?: UpdatePipelineCommandOutput) => void
  ): void;
  updatePipeline(
    args: UpdatePipelineCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdatePipelineCommandOutput) => void
  ): void;
  updatePipelineExecution(
    args: UpdatePipelineExecutionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdatePipelineExecutionCommandOutput>;
  updatePipelineExecution(
    args: UpdatePipelineExecutionCommandInput,
    cb: (err: any, data?: UpdatePipelineExecutionCommandOutput) => void
  ): void;
  updatePipelineExecution(
    args: UpdatePipelineExecutionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdatePipelineExecutionCommandOutput) => void
  ): void;
  updatePipelineVersion(
    args: UpdatePipelineVersionCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdatePipelineVersionCommandOutput>;
  updatePipelineVersion(
    args: UpdatePipelineVersionCommandInput,
    cb: (err: any, data?: UpdatePipelineVersionCommandOutput) => void
  ): void;
  updatePipelineVersion(
    args: UpdatePipelineVersionCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdatePipelineVersionCommandOutput) => void
  ): void;
  updateProject(
    args: UpdateProjectCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateProjectCommandOutput>;
  updateProject(
    args: UpdateProjectCommandInput,
    cb: (err: any, data?: UpdateProjectCommandOutput) => void
  ): void;
  updateProject(
    args: UpdateProjectCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateProjectCommandOutput) => void
  ): void;
  updateSpace(
    args: UpdateSpaceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateSpaceCommandOutput>;
  updateSpace(
    args: UpdateSpaceCommandInput,
    cb: (err: any, data?: UpdateSpaceCommandOutput) => void
  ): void;
  updateSpace(
    args: UpdateSpaceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateSpaceCommandOutput) => void
  ): void;
  updateTrainingJob(
    args: UpdateTrainingJobCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateTrainingJobCommandOutput>;
  updateTrainingJob(
    args: UpdateTrainingJobCommandInput,
    cb: (err: any, data?: UpdateTrainingJobCommandOutput) => void
  ): void;
  updateTrainingJob(
    args: UpdateTrainingJobCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateTrainingJobCommandOutput) => void
  ): void;
  updateTrial(
    args: UpdateTrialCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateTrialCommandOutput>;
  updateTrial(
    args: UpdateTrialCommandInput,
    cb: (err: any, data?: UpdateTrialCommandOutput) => void
  ): void;
  updateTrial(
    args: UpdateTrialCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateTrialCommandOutput) => void
  ): void;
  updateTrialComponent(
    args: UpdateTrialComponentCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateTrialComponentCommandOutput>;
  updateTrialComponent(
    args: UpdateTrialComponentCommandInput,
    cb: (err: any, data?: UpdateTrialComponentCommandOutput) => void
  ): void;
  updateTrialComponent(
    args: UpdateTrialComponentCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateTrialComponentCommandOutput) => void
  ): void;
  updateUserProfile(
    args: UpdateUserProfileCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateUserProfileCommandOutput>;
  updateUserProfile(
    args: UpdateUserProfileCommandInput,
    cb: (err: any, data?: UpdateUserProfileCommandOutput) => void
  ): void;
  updateUserProfile(
    args: UpdateUserProfileCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateUserProfileCommandOutput) => void
  ): void;
  updateWorkforce(
    args: UpdateWorkforceCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateWorkforceCommandOutput>;
  updateWorkforce(
    args: UpdateWorkforceCommandInput,
    cb: (err: any, data?: UpdateWorkforceCommandOutput) => void
  ): void;
  updateWorkforce(
    args: UpdateWorkforceCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateWorkforceCommandOutput) => void
  ): void;
  updateWorkteam(
    args: UpdateWorkteamCommandInput,
    options?: __HttpHandlerOptions
  ): Promise<UpdateWorkteamCommandOutput>;
  updateWorkteam(
    args: UpdateWorkteamCommandInput,
    cb: (err: any, data?: UpdateWorkteamCommandOutput) => void
  ): void;
  updateWorkteam(
    args: UpdateWorkteamCommandInput,
    options: __HttpHandlerOptions,
    cb: (err: any, data?: UpdateWorkteamCommandOutput) => void
  ): void;
  paginateCreateHubContentPresignedUrls(
    args: CreateHubContentPresignedUrlsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<CreateHubContentPresignedUrlsCommandOutput>;
  paginateListActions(
    args?: ListActionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListActionsCommandOutput>;
  paginateListAlgorithms(
    args?: ListAlgorithmsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListAlgorithmsCommandOutput>;
  paginateListAliases(
    args: ListAliasesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListAliasesCommandOutput>;
  paginateListAppImageConfigs(
    args?: ListAppImageConfigsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListAppImageConfigsCommandOutput>;
  paginateListApps(
    args?: ListAppsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListAppsCommandOutput>;
  paginateListArtifacts(
    args?: ListArtifactsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListArtifactsCommandOutput>;
  paginateListAssociations(
    args?: ListAssociationsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListAssociationsCommandOutput>;
  paginateListAutoMLJobs(
    args?: ListAutoMLJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListAutoMLJobsCommandOutput>;
  paginateListCandidatesForAutoMLJob(
    args: ListCandidatesForAutoMLJobCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListCandidatesForAutoMLJobCommandOutput>;
  paginateListClusterEvents(
    args: ListClusterEventsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListClusterEventsCommandOutput>;
  paginateListClusterNodes(
    args: ListClusterNodesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListClusterNodesCommandOutput>;
  paginateListClusters(
    args?: ListClustersCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListClustersCommandOutput>;
  paginateListClusterSchedulerConfigs(
    args?: ListClusterSchedulerConfigsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListClusterSchedulerConfigsCommandOutput>;
  paginateListCodeRepositories(
    args?: ListCodeRepositoriesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListCodeRepositoriesCommandOutput>;
  paginateListCompilationJobs(
    args?: ListCompilationJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListCompilationJobsCommandOutput>;
  paginateListComputeQuotas(
    args?: ListComputeQuotasCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListComputeQuotasCommandOutput>;
  paginateListContexts(
    args?: ListContextsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListContextsCommandOutput>;
  paginateListDataQualityJobDefinitions(
    args?: ListDataQualityJobDefinitionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListDataQualityJobDefinitionsCommandOutput>;
  paginateListDeviceFleets(
    args?: ListDeviceFleetsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListDeviceFleetsCommandOutput>;
  paginateListDevices(
    args?: ListDevicesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListDevicesCommandOutput>;
  paginateListDomains(
    args?: ListDomainsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListDomainsCommandOutput>;
  paginateListEdgeDeploymentPlans(
    args?: ListEdgeDeploymentPlansCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListEdgeDeploymentPlansCommandOutput>;
  paginateListEdgePackagingJobs(
    args?: ListEdgePackagingJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListEdgePackagingJobsCommandOutput>;
  paginateListEndpointConfigs(
    args?: ListEndpointConfigsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListEndpointConfigsCommandOutput>;
  paginateListEndpoints(
    args?: ListEndpointsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListEndpointsCommandOutput>;
  paginateListExperiments(
    args?: ListExperimentsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListExperimentsCommandOutput>;
  paginateListFeatureGroups(
    args?: ListFeatureGroupsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListFeatureGroupsCommandOutput>;
  paginateListFlowDefinitions(
    args?: ListFlowDefinitionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListFlowDefinitionsCommandOutput>;
  paginateListHumanTaskUis(
    args?: ListHumanTaskUisCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListHumanTaskUisCommandOutput>;
  paginateListHyperParameterTuningJobs(
    args?: ListHyperParameterTuningJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListHyperParameterTuningJobsCommandOutput>;
  paginateListImages(
    args?: ListImagesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListImagesCommandOutput>;
  paginateListImageVersions(
    args: ListImageVersionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListImageVersionsCommandOutput>;
  paginateListInferenceComponents(
    args?: ListInferenceComponentsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListInferenceComponentsCommandOutput>;
  paginateListInferenceExperiments(
    args?: ListInferenceExperimentsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListInferenceExperimentsCommandOutput>;
  paginateListInferenceRecommendationsJobs(
    args?: ListInferenceRecommendationsJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListInferenceRecommendationsJobsCommandOutput>;
  paginateListInferenceRecommendationsJobSteps(
    args: ListInferenceRecommendationsJobStepsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListInferenceRecommendationsJobStepsCommandOutput>;
  paginateListLabelingJobs(
    args?: ListLabelingJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListLabelingJobsCommandOutput>;
  paginateListLabelingJobsForWorkteam(
    args: ListLabelingJobsForWorkteamCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListLabelingJobsForWorkteamCommandOutput>;
  paginateListLineageGroups(
    args?: ListLineageGroupsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListLineageGroupsCommandOutput>;
  paginateListMlflowApps(
    args?: ListMlflowAppsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListMlflowAppsCommandOutput>;
  paginateListMlflowTrackingServers(
    args?: ListMlflowTrackingServersCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListMlflowTrackingServersCommandOutput>;
  paginateListModelBiasJobDefinitions(
    args?: ListModelBiasJobDefinitionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelBiasJobDefinitionsCommandOutput>;
  paginateListModelCardExportJobs(
    args: ListModelCardExportJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelCardExportJobsCommandOutput>;
  paginateListModelCards(
    args?: ListModelCardsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelCardsCommandOutput>;
  paginateListModelCardVersions(
    args: ListModelCardVersionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelCardVersionsCommandOutput>;
  paginateListModelExplainabilityJobDefinitions(
    args?: ListModelExplainabilityJobDefinitionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelExplainabilityJobDefinitionsCommandOutput>;
  paginateListModelMetadata(
    args?: ListModelMetadataCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelMetadataCommandOutput>;
  paginateListModelPackageGroups(
    args?: ListModelPackageGroupsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelPackageGroupsCommandOutput>;
  paginateListModelPackages(
    args?: ListModelPackagesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelPackagesCommandOutput>;
  paginateListModelQualityJobDefinitions(
    args?: ListModelQualityJobDefinitionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelQualityJobDefinitionsCommandOutput>;
  paginateListModels(
    args?: ListModelsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListModelsCommandOutput>;
  paginateListMonitoringAlertHistory(
    args?: ListMonitoringAlertHistoryCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListMonitoringAlertHistoryCommandOutput>;
  paginateListMonitoringAlerts(
    args: ListMonitoringAlertsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListMonitoringAlertsCommandOutput>;
  paginateListMonitoringExecutions(
    args?: ListMonitoringExecutionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListMonitoringExecutionsCommandOutput>;
  paginateListMonitoringSchedules(
    args?: ListMonitoringSchedulesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListMonitoringSchedulesCommandOutput>;
  paginateListNotebookInstanceLifecycleConfigs(
    args?: ListNotebookInstanceLifecycleConfigsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListNotebookInstanceLifecycleConfigsCommandOutput>;
  paginateListNotebookInstances(
    args?: ListNotebookInstancesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListNotebookInstancesCommandOutput>;
  paginateListOptimizationJobs(
    args?: ListOptimizationJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListOptimizationJobsCommandOutput>;
  paginateListPartnerApps(
    args?: ListPartnerAppsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListPartnerAppsCommandOutput>;
  paginateListPipelineExecutions(
    args: ListPipelineExecutionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListPipelineExecutionsCommandOutput>;
  paginateListPipelineExecutionSteps(
    args?: ListPipelineExecutionStepsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListPipelineExecutionStepsCommandOutput>;
  paginateListPipelineParametersForExecution(
    args: ListPipelineParametersForExecutionCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListPipelineParametersForExecutionCommandOutput>;
  paginateListPipelines(
    args?: ListPipelinesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListPipelinesCommandOutput>;
  paginateListPipelineVersions(
    args: ListPipelineVersionsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListPipelineVersionsCommandOutput>;
  paginateListProcessingJobs(
    args?: ListProcessingJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListProcessingJobsCommandOutput>;
  paginateListProjects(
    args?: ListProjectsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListProjectsCommandOutput>;
  paginateListResourceCatalogs(
    args?: ListResourceCatalogsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListResourceCatalogsCommandOutput>;
  paginateListSpaces(
    args?: ListSpacesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListSpacesCommandOutput>;
  paginateListStageDevices(
    args: ListStageDevicesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListStageDevicesCommandOutput>;
  paginateListStudioLifecycleConfigs(
    args?: ListStudioLifecycleConfigsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListStudioLifecycleConfigsCommandOutput>;
  paginateListSubscribedWorkteams(
    args?: ListSubscribedWorkteamsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListSubscribedWorkteamsCommandOutput>;
  paginateListTags(
    args: ListTagsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListTagsCommandOutput>;
  paginateListTrainingJobs(
    args?: ListTrainingJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListTrainingJobsCommandOutput>;
  paginateListTrainingJobsForHyperParameterTuningJob(
    args: ListTrainingJobsForHyperParameterTuningJobCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListTrainingJobsForHyperParameterTuningJobCommandOutput>;
  paginateListTrainingPlans(
    args?: ListTrainingPlansCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListTrainingPlansCommandOutput>;
  paginateListTransformJobs(
    args?: ListTransformJobsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListTransformJobsCommandOutput>;
  paginateListTrialComponents(
    args?: ListTrialComponentsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListTrialComponentsCommandOutput>;
  paginateListTrials(
    args?: ListTrialsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListTrialsCommandOutput>;
  paginateListUltraServersByReservedCapacity(
    args: ListUltraServersByReservedCapacityCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListUltraServersByReservedCapacityCommandOutput>;
  paginateListUserProfiles(
    args?: ListUserProfilesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListUserProfilesCommandOutput>;
  paginateListWorkforces(
    args?: ListWorkforcesCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListWorkforcesCommandOutput>;
  paginateListWorkteams(
    args?: ListWorkteamsCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<ListWorkteamsCommandOutput>;
  paginateQueryLineage(
    args?: QueryLineageCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<QueryLineageCommandOutput>;
  paginateSearch(
    args: SearchCommandInput,
    paginationConfig?: Pick<
      PaginationConfiguration,
      Exclude<keyof PaginationConfiguration, "client">
    >
  ): Paginator<SearchCommandOutput>;
  waitUntilEndpointDeleted(
    args: DescribeEndpointCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilEndpointInService(
    args: DescribeEndpointCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilImageCreated(
    args: DescribeImageCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilImageDeleted(
    args: DescribeImageCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilImageUpdated(
    args: DescribeImageCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilImageVersionCreated(
    args: DescribeImageVersionCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilImageVersionDeleted(
    args: DescribeImageVersionCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilNotebookInstanceDeleted(
    args: DescribeNotebookInstanceCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilNotebookInstanceInService(
    args: DescribeNotebookInstanceCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilNotebookInstanceStopped(
    args: DescribeNotebookInstanceCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilProcessingJobCompletedOrStopped(
    args: DescribeProcessingJobCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilTrainingJobCompletedOrStopped(
    args: DescribeTrainingJobCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
  waitUntilTransformJobCompletedOrStopped(
    args: DescribeTransformJobCommandInput,
    waiterConfig:
      | number
      | Pick<
          WaiterConfiguration<SageMaker>,
          Exclude<keyof WaiterConfiguration<SageMaker>, "client">
        >
  ): Promise<WaiterResult>;
}
export declare class SageMaker extends SageMakerClient implements SageMaker {}
